
use strict; # useless include, but keeps perlcritic silent
use warnings;  # -"-

          # key => [qw( name                                             rfc dtls )],
our %_ciphers_iana = (
    '0x00,0x00' => [qw( TLS_NULL_WITH_NULL_NULL                         5246   Y )],
    '0x00,0x01' => [qw( TLS_RSA_WITH_NULL_MD5                           5246   Y )],
    '0x00,0x02' => [qw( TLS_RSA_WITH_NULL_SHA                           5246   Y )],
    '0x00,0x03' => [qw( TLS_RSA_EXPORT_WITH_RC4_40_MD5                  4346:6347   N )],
    '0x00,0x04' => [qw( TLS_RSA_WITH_RC4_128_MD5                        5246:6347   N )],
    '0x00,0x05' => [qw( TLS_RSA_WITH_RC4_128_SHA                        5246:6347   N )],
    '0x00,0x06' => [qw( TLS_RSA_EXPORT_WITH_RC2_CBC_40_MD5              4346   Y )],
    '0x00,0x07' => [qw( TLS_RSA_WITH_IDEA_CBC_SHA                       5469   Y )],
    '0x00,0x08' => [qw( TLS_RSA_EXPORT_WITH_DES40_CBC_SHA               4346   Y )],
    '0x00,0x09' => [qw( TLS_RSA_WITH_DES_CBC_SHA                        5469   Y )],
    '0x00,0x0A' => [qw( TLS_RSA_WITH_3DES_EDE_CBC_SHA                   5246   Y )],
    '0x00,0x0B' => [qw( TLS_DH_DSS_EXPORT_WITH_DES40_CBC_SHA            4346   Y )],
    '0x00,0x0C' => [qw( TLS_DH_DSS_WITH_DES_CBC_SHA                     5469   Y )],
    '0x00,0x0D' => [qw( TLS_DH_DSS_WITH_3DES_EDE_CBC_SHA                5246   Y )],
    '0x00,0x0E' => [qw( TLS_DH_RSA_EXPORT_WITH_DES40_CBC_SHA            4346   Y )],
    '0x00,0x0F' => [qw( TLS_DH_RSA_WITH_DES_CBC_SHA                     5469   Y )],
    '0x00,0x10' => [qw( TLS_DH_RSA_WITH_3DES_EDE_CBC_SHA                5246   Y )],
    '0x00,0x11' => [qw( TLS_DHE_DSS_EXPORT_WITH_DES40_CBC_SHA           4346   Y )],
    '0x00,0x12' => [qw( TLS_DHE_DSS_WITH_DES_CBC_SHA                    5469   Y )],
    '0x00,0x13' => [qw( TLS_DHE_DSS_WITH_3DES_EDE_CBC_SHA               5246   Y )],
    '0x00,0x14' => [qw( TLS_DHE_RSA_EXPORT_WITH_DES40_CBC_SHA           4346   Y )],
    '0x00,0x15' => [qw( TLS_DHE_RSA_WITH_DES_CBC_SHA                    5469   Y )],
    '0x00,0x16' => [qw( TLS_DHE_RSA_WITH_3DES_EDE_CBC_SHA               5246   Y )],
    '0x00,0x17' => [qw( TLS_DH_anon_EXPORT_WITH_RC4_40_MD5              4346:6347   N )],
    '0x00,0x18' => [qw( TLS_DH_anon_WITH_RC4_128_MD5                    5246:6347   N )],
    '0x00,0x19' => [qw( TLS_DH_anon_EXPORT_WITH_DES40_CBC_SHA           4346   Y )],
    '0x00,0x1A' => [qw( TLS_DH_anon_WITH_DES_CBC_SHA                    5469   Y )],
    '0x00,0x1B' => [qw( TLS_DH_anon_WITH_3DES_EDE_CBC_SHA               5246   Y )],
#       0x00,0x1C-1D     Reserved to avoid conflicts with SSLv3                                   [RFC5246]
    '0x00,0x1E' => [qw( TLS_KRB5_WITH_DES_CBC_SHA                       2712   Y )],
    '0x00,0x1F' => [qw( TLS_KRB5_WITH_3DES_EDE_CBC_SHA                  2712   Y )],
    '0x00,0x20' => [qw( TLS_KRB5_WITH_RC4_128_SHA                       2712:6347   N )],
    '0x00,0x21' => [qw( TLS_KRB5_WITH_IDEA_CBC_SHA                      2712   Y )],
    '0x00,0x22' => [qw( TLS_KRB5_WITH_DES_CBC_MD5                       2712   Y )],
    '0x00,0x23' => [qw( TLS_KRB5_WITH_3DES_EDE_CBC_MD5                  2712   Y )],
    '0x00,0x24' => [qw( TLS_KRB5_WITH_RC4_128_MD5                       2712:6347   N )],
    '0x00,0x25' => [qw( TLS_KRB5_WITH_IDEA_CBC_MD5                      2712   Y )],
    '0x00,0x26' => [qw( TLS_KRB5_EXPORT_WITH_DES_CBC_40_SHA             2712   Y )],
    '0x00,0x27' => [qw( TLS_KRB5_EXPORT_WITH_RC2_CBC_40_SHA             2712   Y )],
    '0x00,0x28' => [qw( TLS_KRB5_EXPORT_WITH_RC4_40_SHA                 2712:6347   N )],
    '0x00,0x29' => [qw( TLS_KRB5_EXPORT_WITH_DES_CBC_40_MD5             2712   Y )],
    '0x00,0x2A' => [qw( TLS_KRB5_EXPORT_WITH_RC2_CBC_40_MD5             2712   Y )],
    '0x00,0x2B' => [qw( TLS_KRB5_EXPORT_WITH_RC4_40_MD5                 2712:6347   N )],
    '0x00,0x2C' => [qw( TLS_PSK_WITH_NULL_SHA                           4785   Y )],
    '0x00,0x2D' => [qw( TLS_DHE_PSK_WITH_NULL_SHA                       4785   Y )],
    '0x00,0x2E' => [qw( TLS_RSA_PSK_WITH_NULL_SHA                       4785   Y )],
    '0x00,0x2F' => [qw( TLS_RSA_WITH_AES_128_CBC_SHA                    5246   Y )],
    '0x00,0x30' => [qw( TLS_DH_DSS_WITH_AES_128_CBC_SHA                 5246   Y )],
    '0x00,0x31' => [qw( TLS_DH_RSA_WITH_AES_128_CBC_SHA                 5246   Y )],
    '0x00,0x32' => [qw( TLS_DHE_DSS_WITH_AES_128_CBC_SHA                5246   Y )],
    '0x00,0x33' => [qw( TLS_DHE_RSA_WITH_AES_128_CBC_SHA                5246   Y )],
    '0x00,0x34' => [qw( TLS_DH_anon_WITH_AES_128_CBC_SHA                5246   Y )],
    '0x00,0x35' => [qw( TLS_RSA_WITH_AES_256_CBC_SHA                    5246   Y )],
    '0x00,0x36' => [qw( TLS_DH_DSS_WITH_AES_256_CBC_SHA                 5246   Y )],
    '0x00,0x37' => [qw( TLS_DH_RSA_WITH_AES_256_CBC_SHA                 5246   Y )],
    '0x00,0x38' => [qw( TLS_DHE_DSS_WITH_AES_256_CBC_SHA                5246   Y )],
    '0x00,0x39' => [qw( TLS_DHE_RSA_WITH_AES_256_CBC_SHA                5246   Y )],
    '0x00,0x3A' => [qw( TLS_DH_anon_WITH_AES_256_CBC_SHA                5246   Y )],
    '0x00,0x3B' => [qw( TLS_RSA_WITH_NULL_SHA256                        5246   Y )],
    '0x00,0x3C' => [qw( TLS_RSA_WITH_AES_128_CBC_SHA256                 5246   Y )],
    '0x00,0x3D' => [qw( TLS_RSA_WITH_AES_256_CBC_SHA256                 5246   Y )],
    '0x00,0x3E' => [qw( TLS_DH_DSS_WITH_AES_128_CBC_SHA256              5246   Y )],
    '0x00,0x3F' => [qw( TLS_DH_RSA_WITH_AES_128_CBC_SHA256              5246   Y )],
    '0x00,0x40' => [qw( TLS_DHE_DSS_WITH_AES_128_CBC_SHA256             5246   Y )],
    '0x00,0x41' => [qw( TLS_RSA_WITH_CAMELLIA_128_CBC_SHA               5932   Y )],
    '0x00,0x42' => [qw( TLS_DH_DSS_WITH_CAMELLIA_128_CBC_SHA            5932   Y )],
    '0x00,0x43' => [qw( TLS_DH_RSA_WITH_CAMELLIA_128_CBC_SHA            5932   Y )],
    '0x00,0x44' => [qw( TLS_DHE_DSS_WITH_CAMELLIA_128_CBC_SHA           5932   Y )],
    '0x00,0x45' => [qw( TLS_DHE_RSA_WITH_CAMELLIA_128_CBC_SHA           5932   Y )],
    '0x00,0x46' => [qw( TLS_DH_anon_WITH_CAMELLIA_128_CBC_SHA           5932   Y )],
#       0x00,0x47-4F     Reserved to avoid conflicts with deployed implementations                [Pasi_Eronen]
#       0x00,0x50-58     Reserved to avoid conflicts                                              [Pasi Eronen, <pasi.eronen&nokia.com>, 2008-04-04.
#       0x00,0x59-5C     Reserved to avoid conflicts with deployed implementations                [Pasi_Eronen]
#       0x00,0x5D-5F     Unassigned
#       0x00,0x60-66     Reserved to avoid conflicts with widely deployed implementations         [Pasi_Eronen]
    '0x00,0x67' => [qw( TLS_DHE_RSA_WITH_AES_128_CBC_SHA256             5246   Y )],
    '0x00,0x68' => [qw( TLS_DH_DSS_WITH_AES_256_CBC_SHA256              5246   Y )],
    '0x00,0x69' => [qw( TLS_DH_RSA_WITH_AES_256_CBC_SHA256              5246   Y )],
    '0x00,0x6A' => [qw( TLS_DHE_DSS_WITH_AES_256_CBC_SHA256             5246   Y )],
    '0x00,0x6B' => [qw( TLS_DHE_RSA_WITH_AES_256_CBC_SHA256             5246   Y )],
    '0x00,0x6C' => [qw( TLS_DH_anon_WITH_AES_128_CBC_SHA256             5246   Y )],
    '0x00,0x6D' => [qw( TLS_DH_anon_WITH_AES_256_CBC_SHA256             5246   Y )],
#       0x00,0x6E-83     Unassigned
    '0x00,0x84' => [qw( TLS_RSA_WITH_CAMELLIA_256_CBC_SHA               5932   Y )],
    '0x00,0x85' => [qw( TLS_DH_DSS_WITH_CAMELLIA_256_CBC_SHA            5932   Y )],
    '0x00,0x86' => [qw( TLS_DH_RSA_WITH_CAMELLIA_256_CBC_SHA            5932   Y )],
    '0x00,0x87' => [qw( TLS_DHE_DSS_WITH_CAMELLIA_256_CBC_SHA           5932   Y )],
    '0x00,0x88' => [qw( TLS_DHE_RSA_WITH_CAMELLIA_256_CBC_SHA           5932   Y )],
    '0x00,0x89' => [qw( TLS_DH_anon_WITH_CAMELLIA_256_CBC_SHA           5932   Y )],
    '0x00,0x8A' => [qw( TLS_PSK_WITH_RC4_128_SHA                        4279:6347   N )],
    '0x00,0x8B' => [qw( TLS_PSK_WITH_3DES_EDE_CBC_SHA                   4279   Y )],
    '0x00,0x8C' => [qw( TLS_PSK_WITH_AES_128_CBC_SHA                    4279   Y )],
    '0x00,0x8D' => [qw( TLS_PSK_WITH_AES_256_CBC_SHA                    4279   Y )],
    '0x00,0x8E' => [qw( TLS_DHE_PSK_WITH_RC4_128_SHA                    4279:6347   N )],
    '0x00,0x8F' => [qw( TLS_DHE_PSK_WITH_3DES_EDE_CBC_SHA               4279   Y )],
    '0x00,0x90' => [qw( TLS_DHE_PSK_WITH_AES_128_CBC_SHA                4279   Y )],
    '0x00,0x91' => [qw( TLS_DHE_PSK_WITH_AES_256_CBC_SHA                4279   Y )],
    '0x00,0x92' => [qw( TLS_RSA_PSK_WITH_RC4_128_SHA                    4279:6347   N )],
    '0x00,0x93' => [qw( TLS_RSA_PSK_WITH_3DES_EDE_CBC_SHA               4279   Y )],
    '0x00,0x94' => [qw( TLS_RSA_PSK_WITH_AES_128_CBC_SHA                4279   Y )],
    '0x00,0x95' => [qw( TLS_RSA_PSK_WITH_AES_256_CBC_SHA                4279   Y )],
    '0x00,0x96' => [qw( TLS_RSA_WITH_SEED_CBC_SHA                       4162   Y )],
    '0x00,0x97' => [qw( TLS_DH_DSS_WITH_SEED_CBC_SHA                    4162   Y )],
    '0x00,0x98' => [qw( TLS_DH_RSA_WITH_SEED_CBC_SHA                    4162   Y )],
    '0x00,0x99' => [qw( TLS_DHE_DSS_WITH_SEED_CBC_SHA                   4162   Y )],
    '0x00,0x9A' => [qw( TLS_DHE_RSA_WITH_SEED_CBC_SHA                   4162   Y )],
    '0x00,0x9B' => [qw( TLS_DH_anon_WITH_SEED_CBC_SHA                   4162   Y )],
    '0x00,0x9C' => [qw( TLS_RSA_WITH_AES_128_GCM_SHA256                 5288   Y )],
    '0x00,0x9D' => [qw( TLS_RSA_WITH_AES_256_GCM_SHA384                 5288   Y )],
    '0x00,0x9E' => [qw( TLS_DHE_RSA_WITH_AES_128_GCM_SHA256             5288   Y )],
    '0x00,0x9F' => [qw( TLS_DHE_RSA_WITH_AES_256_GCM_SHA384             5288   Y )],
    '0x00,0xA0' => [qw( TLS_DH_RSA_WITH_AES_128_GCM_SHA256              5288   Y )],
    '0x00,0xA1' => [qw( TLS_DH_RSA_WITH_AES_256_GCM_SHA384              5288   Y )],
    '0x00,0xA2' => [qw( TLS_DHE_DSS_WITH_AES_128_GCM_SHA256             5288   Y )],
    '0x00,0xA3' => [qw( TLS_DHE_DSS_WITH_AES_256_GCM_SHA384             5288   Y )],
    '0x00,0xA4' => [qw( TLS_DH_DSS_WITH_AES_128_GCM_SHA256              5288   Y )],
    '0x00,0xA5' => [qw( TLS_DH_DSS_WITH_AES_256_GCM_SHA384              5288   Y )],
    '0x00,0xA6' => [qw( TLS_DH_anon_WITH_AES_128_GCM_SHA256             5288   Y )],
    '0x00,0xA7' => [qw( TLS_DH_anon_WITH_AES_256_GCM_SHA384             5288   Y )],
    '0x00,0xA8' => [qw( TLS_PSK_WITH_AES_128_GCM_SHA256                 5487   Y )],
    '0x00,0xA9' => [qw( TLS_PSK_WITH_AES_256_GCM_SHA384                 5487   Y )],
    '0x00,0xAA' => [qw( TLS_DHE_PSK_WITH_AES_128_GCM_SHA256             5487   Y )],
    '0x00,0xAB' => [qw( TLS_DHE_PSK_WITH_AES_256_GCM_SHA384             5487   Y )],
    '0x00,0xAC' => [qw( TLS_RSA_PSK_WITH_AES_128_GCM_SHA256             5487   Y )],
    '0x00,0xAD' => [qw( TLS_RSA_PSK_WITH_AES_256_GCM_SHA384             5487   Y )],
    '0x00,0xAE' => [qw( TLS_PSK_WITH_AES_128_CBC_SHA256                 5487   Y )],
    '0x00,0xAF' => [qw( TLS_PSK_WITH_AES_256_CBC_SHA384                 5487   Y )],
    '0x00,0xB0' => [qw( TLS_PSK_WITH_NULL_SHA256                        5487   Y )],
    '0x00,0xB1' => [qw( TLS_PSK_WITH_NULL_SHA384                        5487   Y )],
    '0x00,0xB2' => [qw( TLS_DHE_PSK_WITH_AES_128_CBC_SHA256             5487   Y )],
    '0x00,0xB3' => [qw( TLS_DHE_PSK_WITH_AES_256_CBC_SHA384             5487   Y )],
    '0x00,0xB4' => [qw( TLS_DHE_PSK_WITH_NULL_SHA256                    5487   Y )],
    '0x00,0xB5' => [qw( TLS_DHE_PSK_WITH_NULL_SHA384                    5487   Y )],
    '0x00,0xB6' => [qw( TLS_RSA_PSK_WITH_AES_128_CBC_SHA256             5487   Y )],
    '0x00,0xB7' => [qw( TLS_RSA_PSK_WITH_AES_256_CBC_SHA384             5487   Y )],
    '0x00,0xB8' => [qw( TLS_RSA_PSK_WITH_NULL_SHA256                    5487   Y )],
    '0x00,0xB9' => [qw( TLS_RSA_PSK_WITH_NULL_SHA384                    5487   Y )],
    '0x00,0xBA' => [qw( TLS_RSA_WITH_CAMELLIA_128_CBC_SHA256            5932   Y )],
    '0x00,0xBB' => [qw( TLS_DH_DSS_WITH_CAMELLIA_128_CBC_SHA256         5932   Y )],
    '0x00,0xBC' => [qw( TLS_DH_RSA_WITH_CAMELLIA_128_CBC_SHA256         5932   Y )],
    '0x00,0xBD' => [qw( TLS_DHE_DSS_WITH_CAMELLIA_128_CBC_SHA256        5932   Y )],
    '0x00,0xBE' => [qw( TLS_DHE_RSA_WITH_CAMELLIA_128_CBC_SHA256        5932   Y )],
    '0x00,0xBF' => [qw( TLS_DH_anon_WITH_CAMELLIA_128_CBC_SHA256        5932   Y )],
    '0x00,0xC0' => [qw( TLS_RSA_WITH_CAMELLIA_256_CBC_SHA256            5932   Y )],
    '0x00,0xC1' => [qw( TLS_DH_DSS_WITH_CAMELLIA_256_CBC_SHA256         5932   Y )],
    '0x00,0xC2' => [qw( TLS_DH_RSA_WITH_CAMELLIA_256_CBC_SHA256         5932   Y )],
    '0x00,0xC3' => [qw( TLS_DHE_DSS_WITH_CAMELLIA_256_CBC_SHA256        5932   Y )],
    '0x00,0xC4' => [qw( TLS_DHE_RSA_WITH_CAMELLIA_256_CBC_SHA256        5932   Y )],
    '0x00,0xC5' => [qw( TLS_DH_anon_WITH_CAMELLIA_256_CBC_SHA256        5932   Y )],
#       0x00,0xC6-FE     Unassigned
    '0x00,0xFF' => [qw( TLS_EMPTY_RENEGOTIATION_INFO_SCSV               5746   Y )],
#         0x01-55,*      Unassigned
    '0x56,0x00' => [qw( TLS_FALLBACK_SCSV                               7507   Y )],
#    0x56,0x01-0xC0,0x00 Unassigned
    '0xC0,0x01' => [qw( TLS_ECDH_ECDSA_WITH_NULL_SHA                    4492   Y )],
    '0xC0,0x02' => [qw( TLS_ECDH_ECDSA_WITH_RC4_128_SHA                 4492:6347   N )],
    '0xC0,0x03' => [qw( TLS_ECDH_ECDSA_WITH_3DES_EDE_CBC_SHA            4492   Y )],
    '0xC0,0x04' => [qw( TLS_ECDH_ECDSA_WITH_AES_128_CBC_SHA             4492   Y )],
    '0xC0,0x05' => [qw( TLS_ECDH_ECDSA_WITH_AES_256_CBC_SHA             4492   Y )],
    '0xC0,0x06' => [qw( TLS_ECDHE_ECDSA_WITH_NULL_SHA                   4492   Y )],
    '0xC0,0x07' => [qw( TLS_ECDHE_ECDSA_WITH_RC4_128_SHA                4492:6347   N )],
    '0xC0,0x08' => [qw( TLS_ECDHE_ECDSA_WITH_3DES_EDE_CBC_SHA           4492   Y )],
    '0xC0,0x09' => [qw( TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA            4492   Y )],
    '0xC0,0x0A' => [qw( TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA            4492   Y )],
    '0xC0,0x0B' => [qw( TLS_ECDH_RSA_WITH_NULL_SHA                      4492   Y )],
    '0xC0,0x0C' => [qw( TLS_ECDH_RSA_WITH_RC4_128_SHA                   4492:6347   N )],
    '0xC0,0x0D' => [qw( TLS_ECDH_RSA_WITH_3DES_EDE_CBC_SHA              4492   Y )],
    '0xC0,0x0E' => [qw( TLS_ECDH_RSA_WITH_AES_128_CBC_SHA               4492   Y )],
    '0xC0,0x0F' => [qw( TLS_ECDH_RSA_WITH_AES_256_CBC_SHA               4492   Y )],
    '0xC0,0x10' => [qw( TLS_ECDHE_RSA_WITH_NULL_SHA                     4492   Y )],
    '0xC0,0x11' => [qw( TLS_ECDHE_RSA_WITH_RC4_128_SHA                  4492:6347   N )],
    '0xC0,0x12' => [qw( TLS_ECDHE_RSA_WITH_3DES_EDE_CBC_SHA             4492   Y )],
    '0xC0,0x13' => [qw( TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA              4492   Y )],
    '0xC0,0x14' => [qw( TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA              4492   Y )],
    '0xC0,0x15' => [qw( TLS_ECDH_anon_WITH_NULL_SHA                     4492   Y )],
    '0xC0,0x16' => [qw( TLS_ECDH_anon_WITH_RC4_128_SHA                  4492:6347   N )],
    '0xC0,0x17' => [qw( TLS_ECDH_anon_WITH_3DES_EDE_CBC_SHA             4492   Y )],
    '0xC0,0x18' => [qw( TLS_ECDH_anon_WITH_AES_128_CBC_SHA              4492   Y )],
    '0xC0,0x19' => [qw( TLS_ECDH_anon_WITH_AES_256_CBC_SHA              4492   Y )],
    '0xC0,0x1A' => [qw( TLS_SRP_SHA_WITH_3DES_EDE_CBC_SHA               5054   Y )],
    '0xC0,0x1B' => [qw( TLS_SRP_SHA_RSA_WITH_3DES_EDE_CBC_SHA           5054   Y )],
    '0xC0,0x1C' => [qw( TLS_SRP_SHA_DSS_WITH_3DES_EDE_CBC_SHA           5054   Y )],
    '0xC0,0x1D' => [qw( TLS_SRP_SHA_WITH_AES_128_CBC_SHA                5054   Y )],
    '0xC0,0x1E' => [qw( TLS_SRP_SHA_RSA_WITH_AES_128_CBC_SHA            5054   Y )],
    '0xC0,0x1F' => [qw( TLS_SRP_SHA_DSS_WITH_AES_128_CBC_SHA            5054   Y )],
    '0xC0,0x20' => [qw( TLS_SRP_SHA_WITH_AES_256_CBC_SHA                5054   Y )],
    '0xC0,0x21' => [qw( TLS_SRP_SHA_RSA_WITH_AES_256_CBC_SHA            5054   Y )],
    '0xC0,0x22' => [qw( TLS_SRP_SHA_DSS_WITH_AES_256_CBC_SHA            5054   Y )],
    '0xC0,0x23' => [qw( TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256         5289   Y )],
    '0xC0,0x24' => [qw( TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA384         5289   Y )],
    '0xC0,0x25' => [qw( TLS_ECDH_ECDSA_WITH_AES_128_CBC_SHA256          5289   Y )],
    '0xC0,0x26' => [qw( TLS_ECDH_ECDSA_WITH_AES_256_CBC_SHA384          5289   Y )],
    '0xC0,0x27' => [qw( TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA256           5289   Y )],
    '0xC0,0x28' => [qw( TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA384           5289   Y )],
    '0xC0,0x29' => [qw( TLS_ECDH_RSA_WITH_AES_128_CBC_SHA256            5289   Y )],
    '0xC0,0x2A' => [qw( TLS_ECDH_RSA_WITH_AES_256_CBC_SHA384            5289   Y )],
    '0xC0,0x2B' => [qw( TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256         5289   Y )],
    '0xC0,0x2C' => [qw( TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384         5289   Y )],
    '0xC0,0x2D' => [qw( TLS_ECDH_ECDSA_WITH_AES_128_GCM_SHA256          5289   Y )],
    '0xC0,0x2E' => [qw( TLS_ECDH_ECDSA_WITH_AES_256_GCM_SHA384          5289   Y )],
    '0xC0,0x2F' => [qw( TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256           5289   Y )],
    '0xC0,0x30' => [qw( TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384           5289   Y )],
    '0xC0,0x31' => [qw( TLS_ECDH_RSA_WITH_AES_128_GCM_SHA256            5289   Y )],
    '0xC0,0x32' => [qw( TLS_ECDH_RSA_WITH_AES_256_GCM_SHA384            5289   Y )],
    '0xC0,0x33' => [qw( TLS_ECDHE_PSK_WITH_RC4_128_SHA                  5489:6347   N )],
    '0xC0,0x34' => [qw( TLS_ECDHE_PSK_WITH_3DES_EDE_CBC_SHA             5489   Y )],
    '0xC0,0x35' => [qw( TLS_ECDHE_PSK_WITH_AES_128_CBC_SHA              5489   Y )],
    '0xC0,0x36' => [qw( TLS_ECDHE_PSK_WITH_AES_256_CBC_SHA              5489   Y )],
    '0xC0,0x37' => [qw( TLS_ECDHE_PSK_WITH_AES_128_CBC_SHA256           5489   Y )],
    '0xC0,0x38' => [qw( TLS_ECDHE_PSK_WITH_AES_256_CBC_SHA384           5489   Y )],
    '0xC0,0x39' => [qw( TLS_ECDHE_PSK_WITH_NULL_SHA                     5489   Y )],
    '0xC0,0x3A' => [qw( TLS_ECDHE_PSK_WITH_NULL_SHA256                  5489   Y )],
    '0xC0,0x3B' => [qw( TLS_ECDHE_PSK_WITH_NULL_SHA384                  5489   Y )],
    '0xC0,0x3C' => [qw( TLS_RSA_WITH_ARIA_128_CBC_SHA256                6209   Y )],
    '0xC0,0x3D' => [qw( TLS_RSA_WITH_ARIA_256_CBC_SHA384                6209   Y )],
    '0xC0,0x3E' => [qw( TLS_DH_DSS_WITH_ARIA_128_CBC_SHA256             6209   Y )],
    '0xC0,0x3F' => [qw( TLS_DH_DSS_WITH_ARIA_256_CBC_SHA384             6209   Y )],
    '0xC0,0x40' => [qw( TLS_DH_RSA_WITH_ARIA_128_CBC_SHA256             6209   Y )],
    '0xC0,0x41' => [qw( TLS_DH_RSA_WITH_ARIA_256_CBC_SHA384             6209   Y )],
    '0xC0,0x42' => [qw( TLS_DHE_DSS_WITH_ARIA_128_CBC_SHA256            6209   Y )],
    '0xC0,0x43' => [qw( TLS_DHE_DSS_WITH_ARIA_256_CBC_SHA384            6209   Y )],
    '0xC0,0x44' => [qw( TLS_DHE_RSA_WITH_ARIA_128_CBC_SHA256            6209   Y )],
    '0xC0,0x45' => [qw( TLS_DHE_RSA_WITH_ARIA_256_CBC_SHA384            6209   Y )],
    '0xC0,0x46' => [qw( TLS_DH_anon_WITH_ARIA_128_CBC_SHA256            6209   Y )],
    '0xC0,0x47' => [qw( TLS_DH_anon_WITH_ARIA_256_CBC_SHA384            6209   Y )],
    '0xC0,0x48' => [qw( TLS_ECDHE_ECDSA_WITH_ARIA_128_CBC_SHA256        6209   Y )],
    '0xC0,0x49' => [qw( TLS_ECDHE_ECDSA_WITH_ARIA_256_CBC_SHA384        6209   Y )],
    '0xC0,0x4A' => [qw( TLS_ECDH_ECDSA_WITH_ARIA_128_CBC_SHA256         6209   Y )],
    '0xC0,0x4B' => [qw( TLS_ECDH_ECDSA_WITH_ARIA_256_CBC_SHA384         6209   Y )],
    '0xC0,0x4C' => [qw( TLS_ECDHE_RSA_WITH_ARIA_128_CBC_SHA256          6209   Y )],
    '0xC0,0x4D' => [qw( TLS_ECDHE_RSA_WITH_ARIA_256_CBC_SHA384          6209   Y )],
    '0xC0,0x4E' => [qw( TLS_ECDH_RSA_WITH_ARIA_128_CBC_SHA256           6209   Y )],
    '0xC0,0x4F' => [qw( TLS_ECDH_RSA_WITH_ARIA_256_CBC_SHA384           6209   Y )],
    '0xC0,0x50' => [qw( TLS_RSA_WITH_ARIA_128_GCM_SHA256                6209   Y )],
    '0xC0,0x51' => [qw( TLS_RSA_WITH_ARIA_256_GCM_SHA384                6209   Y )],
    '0xC0,0x52' => [qw( TLS_DHE_RSA_WITH_ARIA_128_GCM_SHA256            6209   Y )],
    '0xC0,0x53' => [qw( TLS_DHE_RSA_WITH_ARIA_256_GCM_SHA384            6209   Y )],
    '0xC0,0x54' => [qw( TLS_DH_RSA_WITH_ARIA_128_GCM_SHA256             6209   Y )],
    '0xC0,0x55' => [qw( TLS_DH_RSA_WITH_ARIA_256_GCM_SHA384             6209   Y )],
    '0xC0,0x56' => [qw( TLS_DHE_DSS_WITH_ARIA_128_GCM_SHA256            6209   Y )],
    '0xC0,0x57' => [qw( TLS_DHE_DSS_WITH_ARIA_256_GCM_SHA384            6209   Y )],
    '0xC0,0x58' => [qw( TLS_DH_DSS_WITH_ARIA_128_GCM_SHA256             6209   Y )],
    '0xC0,0x59' => [qw( TLS_DH_DSS_WITH_ARIA_256_GCM_SHA384             6209   Y )],
    '0xC0,0x5A' => [qw( TLS_DH_anon_WITH_ARIA_128_GCM_SHA256            6209   Y )],
    '0xC0,0x5B' => [qw( TLS_DH_anon_WITH_ARIA_256_GCM_SHA384            6209   Y )],
    '0xC0,0x5C' => [qw( TLS_ECDHE_ECDSA_WITH_ARIA_128_GCM_SHA256        6209   Y )],
    '0xC0,0x5D' => [qw( TLS_ECDHE_ECDSA_WITH_ARIA_256_GCM_SHA384        6209   Y )],
    '0xC0,0x5E' => [qw( TLS_ECDH_ECDSA_WITH_ARIA_128_GCM_SHA256         6209   Y )],
    '0xC0,0x5F' => [qw( TLS_ECDH_ECDSA_WITH_ARIA_256_GCM_SHA384         6209   Y )],
    '0xC0,0x60' => [qw( TLS_ECDHE_RSA_WITH_ARIA_128_GCM_SHA256          6209   Y )],
    '0xC0,0x61' => [qw( TLS_ECDHE_RSA_WITH_ARIA_256_GCM_SHA384          6209   Y )],
    '0xC0,0x62' => [qw( TLS_ECDH_RSA_WITH_ARIA_128_GCM_SHA256           6209   Y )],
    '0xC0,0x63' => [qw( TLS_ECDH_RSA_WITH_ARIA_256_GCM_SHA384           6209   Y )],
    '0xC0,0x64' => [qw( TLS_PSK_WITH_ARIA_128_CBC_SHA256                6209   Y )],
    '0xC0,0x65' => [qw( TLS_PSK_WITH_ARIA_256_CBC_SHA384                6209   Y )],
    '0xC0,0x66' => [qw( TLS_DHE_PSK_WITH_ARIA_128_CBC_SHA256            6209   Y )],
    '0xC0,0x67' => [qw( TLS_DHE_PSK_WITH_ARIA_256_CBC_SHA384            6209   Y )],
    '0xC0,0x68' => [qw( TLS_RSA_PSK_WITH_ARIA_128_CBC_SHA256            6209   Y )],
    '0xC0,0x69' => [qw( TLS_RSA_PSK_WITH_ARIA_256_CBC_SHA384            6209   Y )],
    '0xC0,0x6A' => [qw( TLS_PSK_WITH_ARIA_128_GCM_SHA256                6209   Y )],
    '0xC0,0x6B' => [qw( TLS_PSK_WITH_ARIA_256_GCM_SHA384                6209   Y )],
    '0xC0,0x6C' => [qw( TLS_DHE_PSK_WITH_ARIA_128_GCM_SHA256            6209   Y )],
    '0xC0,0x6D' => [qw( TLS_DHE_PSK_WITH_ARIA_256_GCM_SHA384            6209   Y )],
    '0xC0,0x6E' => [qw( TLS_RSA_PSK_WITH_ARIA_128_GCM_SHA256            6209   Y )],
    '0xC0,0x6F' => [qw( TLS_RSA_PSK_WITH_ARIA_256_GCM_SHA384            6209   Y )],
    '0xC0,0x70' => [qw( TLS_ECDHE_PSK_WITH_ARIA_128_CBC_SHA256          6209   Y )],
    '0xC0,0x71' => [qw( TLS_ECDHE_PSK_WITH_ARIA_256_CBC_SHA384          6209   Y )],
    '0xC0,0x72' => [qw( TLS_ECDHE_ECDSA_WITH_CAMELLIA_128_CBC_SHA256    6367   Y )],
    '0xC0,0x73' => [qw( TLS_ECDHE_ECDSA_WITH_CAMELLIA_256_CBC_SHA384    6367   Y )],
    '0xC0,0x74' => [qw( TLS_ECDH_ECDSA_WITH_CAMELLIA_128_CBC_SHA256     6367   Y )],
    '0xC0,0x75' => [qw( TLS_ECDH_ECDSA_WITH_CAMELLIA_256_CBC_SHA384     6367   Y )],
    '0xC0,0x76' => [qw( TLS_ECDHE_RSA_WITH_CAMELLIA_128_CBC_SHA256      6367   Y )],
    '0xC0,0x77' => [qw( TLS_ECDHE_RSA_WITH_CAMELLIA_256_CBC_SHA384      6367   Y )],
    '0xC0,0x78' => [qw( TLS_ECDH_RSA_WITH_CAMELLIA_128_CBC_SHA256       6367   Y )],
    '0xC0,0x79' => [qw( TLS_ECDH_RSA_WITH_CAMELLIA_256_CBC_SHA384       6367   Y )],
    '0xC0,0x7A' => [qw( TLS_RSA_WITH_CAMELLIA_128_GCM_SHA256            6367   Y )],
    '0xC0,0x7B' => [qw( TLS_RSA_WITH_CAMELLIA_256_GCM_SHA384            6367   Y )],
    '0xC0,0x7C' => [qw( TLS_DHE_RSA_WITH_CAMELLIA_128_GCM_SHA256        6367   Y )],
    '0xC0,0x7D' => [qw( TLS_DHE_RSA_WITH_CAMELLIA_256_GCM_SHA384        6367   Y )],
    '0xC0,0x7E' => [qw( TLS_DH_RSA_WITH_CAMELLIA_128_GCM_SHA256         6367   Y )],
    '0xC0,0x7F' => [qw( TLS_DH_RSA_WITH_CAMELLIA_256_GCM_SHA384         6367   Y )],
    '0xC0,0x80' => [qw( TLS_DHE_DSS_WITH_CAMELLIA_128_GCM_SHA256        6367   Y )],
    '0xC0,0x81' => [qw( TLS_DHE_DSS_WITH_CAMELLIA_256_GCM_SHA384        6367   Y )],
    '0xC0,0x82' => [qw( TLS_DH_DSS_WITH_CAMELLIA_128_GCM_SHA256         6367   Y )],
    '0xC0,0x83' => [qw( TLS_DH_DSS_WITH_CAMELLIA_256_GCM_SHA384         6367   Y )],
    '0xC0,0x84' => [qw( TLS_DH_anon_WITH_CAMELLIA_128_GCM_SHA256        6367   Y )],
    '0xC0,0x85' => [qw( TLS_DH_anon_WITH_CAMELLIA_256_GCM_SHA384        6367   Y )],
    '0xC0,0x86' => [qw( TLS_ECDHE_ECDSA_WITH_CAMELLIA_128_GCM_SHA256    6367   Y )],
    '0xC0,0x87' => [qw( TLS_ECDHE_ECDSA_WITH_CAMELLIA_256_GCM_SHA384    6367   Y )],
    '0xC0,0x88' => [qw( TLS_ECDH_ECDSA_WITH_CAMELLIA_128_GCM_SHA256     6367   Y )],
    '0xC0,0x89' => [qw( TLS_ECDH_ECDSA_WITH_CAMELLIA_256_GCM_SHA384     6367   Y )],
    '0xC0,0x8A' => [qw( TLS_ECDHE_RSA_WITH_CAMELLIA_128_GCM_SHA256      6367   Y )],
    '0xC0,0x8B' => [qw( TLS_ECDHE_RSA_WITH_CAMELLIA_256_GCM_SHA384      6367   Y )],
    '0xC0,0x8C' => [qw( TLS_ECDH_RSA_WITH_CAMELLIA_128_GCM_SHA256       6367   Y )],
    '0xC0,0x8D' => [qw( TLS_ECDH_RSA_WITH_CAMELLIA_256_GCM_SHA384       6367   Y )],
    '0xC0,0x8E' => [qw( TLS_PSK_WITH_CAMELLIA_128_GCM_SHA256            6367   Y )],
    '0xC0,0x8F' => [qw( TLS_PSK_WITH_CAMELLIA_256_GCM_SHA384            6367   Y )],
    '0xC0,0x90' => [qw( TLS_DHE_PSK_WITH_CAMELLIA_128_GCM_SHA256        6367   Y )],
    '0xC0,0x91' => [qw( TLS_DHE_PSK_WITH_CAMELLIA_256_GCM_SHA384        6367   Y )],
    '0xC0,0x92' => [qw( TLS_RSA_PSK_WITH_CAMELLIA_128_GCM_SHA256        6367   Y )],
    '0xC0,0x93' => [qw( TLS_RSA_PSK_WITH_CAMELLIA_256_GCM_SHA384        6367   Y )],
    '0xC0,0x94' => [qw( TLS_PSK_WITH_CAMELLIA_128_CBC_SHA256            6367   Y )],
    '0xC0,0x95' => [qw( TLS_PSK_WITH_CAMELLIA_256_CBC_SHA384            6367   Y )],
    '0xC0,0x96' => [qw( TLS_DHE_PSK_WITH_CAMELLIA_128_CBC_SHA256        6367   Y )],
    '0xC0,0x97' => [qw( TLS_DHE_PSK_WITH_CAMELLIA_256_CBC_SHA384        6367   Y )],
    '0xC0,0x98' => [qw( TLS_RSA_PSK_WITH_CAMELLIA_128_CBC_SHA256        6367   Y )],
    '0xC0,0x99' => [qw( TLS_RSA_PSK_WITH_CAMELLIA_256_CBC_SHA384        6367   Y )],
    '0xC0,0x9A' => [qw( TLS_ECDHE_PSK_WITH_CAMELLIA_128_CBC_SHA256      6367   Y )],
    '0xC0,0x9B' => [qw( TLS_ECDHE_PSK_WITH_CAMELLIA_256_CBC_SHA384      6367   Y )],
    '0xC0,0x9C' => [qw( TLS_RSA_WITH_AES_128_CCM                        6655   Y )],
    '0xC0,0x9D' => [qw( TLS_RSA_WITH_AES_256_CCM                        6655   Y )],
    '0xC0,0x9E' => [qw( TLS_DHE_RSA_WITH_AES_128_CCM                    6655   Y )],
    '0xC0,0x9F' => [qw( TLS_DHE_RSA_WITH_AES_256_CCM                    6655   Y )],
    '0xC0,0xA0' => [qw( TLS_RSA_WITH_AES_128_CCM_8                      6655   Y )],
    '0xC0,0xA1' => [qw( TLS_RSA_WITH_AES_256_CCM_8                      6655   Y )],
    '0xC0,0xA2' => [qw( TLS_DHE_RSA_WITH_AES_128_CCM_8                  6655   Y )],
    '0xC0,0xA3' => [qw( TLS_DHE_RSA_WITH_AES_256_CCM_8                  6655   Y )],
    '0xC0,0xA4' => [qw( TLS_PSK_WITH_AES_128_CCM                        6655   Y )],
    '0xC0,0xA5' => [qw( TLS_PSK_WITH_AES_256_CCM                        6655   Y )],
    '0xC0,0xA6' => [qw( TLS_DHE_PSK_WITH_AES_128_CCM                    6655   Y )],
    '0xC0,0xA7' => [qw( TLS_DHE_PSK_WITH_AES_256_CCM                    6655   Y )],
    '0xC0,0xA8' => [qw( TLS_PSK_WITH_AES_128_CCM_8                      6655   Y )],
    '0xC0,0xA9' => [qw( TLS_PSK_WITH_AES_256_CCM_8                      6655   Y )],
    '0xC0,0xAA' => [qw( TLS_PSK_DHE_WITH_AES_128_CCM_8                  6655   Y )],
    '0xC0,0xAB' => [qw( TLS_PSK_DHE_WITH_AES_256_CCM_8                  6655   Y )],
    '0xC0,0xAC' => [qw( TLS_ECDHE_ECDSA_WITH_AES_128_CCM                7251   Y )],
    '0xC0,0xAD' => [qw( TLS_ECDHE_ECDSA_WITH_AES_256_CCM                7251   Y )],
    '0xC0,0xAE' => [qw( TLS_ECDHE_ECDSA_WITH_AES_128_CCM_8              7251   Y )],
    '0xC0,0xAF' => [qw( TLS_ECDHE_ECDSA_WITH_AES_256_CCM_8              7251   Y )],
#       0xC0,0xB0-FF     Unassigned
#         0xC1-CB,*      Unassigned
#       0xCC,0x00-A7     Unassigned
    '0xCC,0xA8' => [qw( TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256     ietf-tls-chacha20-poly1305-04   Y )],
    '0xCC,0xA9' => [qw( TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256   ietf-tls-chacha20-poly1305-04   Y )],
    '0xCC,0xAA' => [qw( TLS_DHE_RSA_WITH_CHACHA20_POLY1305_SHA256       ietf-tls-chacha20-poly1305-04   Y )],
    '0xCC,0xAB' => [qw( TLS_PSK_WITH_CHACHA20_POLY1305_SHA256           ietf-tls-chacha20-poly1305-04   Y )],
    '0xCC,0xAC' => [qw( TLS_ECDHE_PSK_WITH_CHACHA20_POLY1305_SHA256     ietf-tls-chacha20-poly1305-04   Y )],
    '0xCC,0xAD' => [qw( TLS_DHE_PSK_WITH_CHACHA20_POLY1305_SHA256       ietf-tls-chacha20-poly1305-04   Y )],
    '0xCC,0xAE' => [qw( TLS_RSA_PSK_WITH_CHACHA20_POLY1305_SHA256       ietf-tls-chacha20-poly1305-04   Y )],
#       0xCC,0xAF-FF     Unassigned
#         0xCD-FD,*      Unassigned
#       0xFE,0x00-FD     Unassigned
#       0xFE,0xFE-FF     Reserved to avoid conflicts with widely deployed implementations         [Pasi_Eronen]
#       0xFF,0x00-FF     Reserved for Private Use                                                 [RFC5246]
); # %_ciphers_iana

1;
