
use strict; # useless include, but keeps perlcritic silent                      
use warnings;  # -"-

           # key => [qw( ssl     kx              au      enc                 bit mac     name   tags )],
our %_ciphers_openssl_all = (
     '0xC0,0x10' => [qw( SSLv3   ECDH            RSA     None                  0 SHA1    ECDHE-RSA-NULL-SHA    )],
     '0xC0,0x06' => [qw( SSLv3   ECDH            ECDSA   None                  0 SHA1    ECDHE-ECDSA-NULL-SHA    )],
     '0xC0,0x15' => [qw( SSLv3   ECDH            None    None                  0 SHA1    AECDH-NULL-SHA    )],
     '0xC0,0x0B' => [qw( SSLv3   ECDH/RSA        ECDH    None                  0 SHA1    ECDH-RSA-NULL-SHA    )],
     '0xC0,0x01' => [qw( SSLv3   ECDH/ECDSA      ECDH    None                  0 SHA1    ECDH-ECDSA-NULL-SHA    )],
     '0x00,0x3B' => [qw( TLSv12  RSA             RSA     None                  0 SHA256  NULL-SHA256    )],
     '0x00,0x02' => [qw( SSLv3   RSA             RSA     None                  0 SHA1    NULL-SHA    )],
     '0x00,0x01' => [qw( SSLv3   RSA             RSA     None                  0 MD5     NULL-MD5    )],
'0x00,0x00,0x00' => [qw( SSLv2   RSA(512)        RSA     None                  0 MD5     NULL-MD5   export )],
     '0xCC,0x14' => [qw( TLSv12  ECDH            ECDSA   ChaCha20            256 AEAD    ECDHE-ECDSA-CHACHA20-POLY1305    )],
     '0xCC,0x13' => [qw( TLSv12  ECDH            RSA     ChaCha20            256 AEAD    ECDHE-RSA-CHACHA20-POLY1305    )],
     '0xCC,0x15' => [qw( TLSv12  DH              RSA     ChaCha20            256 AEAD    DHE-RSA-CHACHA20-POLY1305    )],
     '0xC0,0x30' => [qw( TLSv12  ECDH            RSA     AESGCM              256 AEAD    ECDHE-RSA-AES256-GCM-SHA384    )],
     '0xC0,0x2C' => [qw( TLSv12  ECDH            ECDSA   AESGCM              256 AEAD    ECDHE-ECDSA-AES256-GCM-SHA384    )],
     '0xC0,0x28' => [qw( TLSv12  ECDH            RSA     AES                 256 SHA384  ECDHE-RSA-AES256-SHA384    )],
     '0xC0,0x24' => [qw( TLSv12  ECDH            ECDSA   AES                 256 SHA384  ECDHE-ECDSA-AES256-SHA384    )],
     '0xC0,0x14' => [qw( SSLv3   ECDH            RSA     AES                 256 SHA1    ECDHE-RSA-AES256-SHA    )],
     '0xC0,0x0A' => [qw( SSLv3   ECDH            ECDSA   AES                 256 SHA1    ECDHE-ECDSA-AES256-SHA    )],
     '0xC0,0x22' => [qw( SSLv3   SRP             DSS     AES                 256 SHA1    SRP-DSS-AES-256-CBC-SHA    )],
     '0xC0,0x21' => [qw( SSLv3   SRP             RSA     AES                 256 SHA1    SRP-RSA-AES-256-CBC-SHA    )],
     '0xC0,0x20' => [qw( SSLv3   SRP             SRP     AES                 256 SHA1    SRP-AES-256-CBC-SHA    )],
     '0x00,0xA5' => [qw( TLSv12  DH/DSS          DH      AESGCM              256 AEAD    DH-DSS-AES256-GCM-SHA384    )],
     '0x00,0xA3' => [qw( TLSv12  DH              DSS     AESGCM              256 AEAD    DHE-DSS-AES256-GCM-SHA384    )],
     '0x00,0xA1' => [qw( TLSv12  DH/RSA          DH      AESGCM              256 AEAD    DH-RSA-AES256-GCM-SHA384    )],
     '0x00,0x9F' => [qw( TLSv12  DH              RSA     AESGCM              256 AEAD    DHE-RSA-AES256-GCM-SHA384    )],
     '0x00,0x6B' => [qw( TLSv12  DH              RSA     AES                 256 SHA256  DHE-RSA-AES256-SHA256    )],
     '0x00,0x6A' => [qw( TLSv12  DH              DSS     AES                 256 SHA256  DHE-DSS-AES256-SHA256    )],
     '0x00,0x69' => [qw( TLSv12  DH/RSA          DH      AES                 256 SHA256  DH-RSA-AES256-SHA256    )],
     '0x00,0x68' => [qw( TLSv12  DH/DSS          DH      AES                 256 SHA256  DH-DSS-AES256-SHA256    )],
     '0x00,0x39' => [qw( SSLv3   DH              RSA     AES                 256 SHA1    DHE-RSA-AES256-SHA    )],
     '0x00,0x38' => [qw( SSLv3   DH              DSS     AES                 256 SHA1    DHE-DSS-AES256-SHA    )],
     '0x00,0x37' => [qw( SSLv3   DH/RSA          DH      AES                 256 SHA1    DH-RSA-AES256-SHA    )],
     '0x00,0x36' => [qw( SSLv3   DH/DSS          DH      AES                 256 SHA1    DH-DSS-AES256-SHA    )],
     '0xC0,0x77' => [qw( TLSv12  ECDH            RSA     Camellia            256 SHA384  ECDHE-RSA-CAMELLIA256-SHA384    )],
     '0xC0,0x73' => [qw( TLSv12  ECDH            ECDSA   Camellia            256 SHA384  ECDHE-ECDSA-CAMELLIA256-SHA384    )],
     '0x00,0xC4' => [qw( TLSv12  DH              RSA     Camellia            256 SHA256  DHE-RSA-CAMELLIA256-SHA256    )],
     '0x00,0xC3' => [qw( TLSv12  DH              DSS     Camellia            256 SHA256  DHE-DSS-CAMELLIA256-SHA256    )],
     '0x00,0xC2' => [qw( TLSv12  DH/RSA          DH      Camellia            256 SHA256  DH-RSA-CAMELLIA256-SHA256    )],
     '0x00,0xC1' => [qw( TLSv12  DH/DSS          DH      Camellia            256 SHA256  DH-DSS-CAMELLIA256-SHA256    )],
     '0x00,0x88' => [qw( SSLv3   DH              RSA     Camellia            256 SHA1    DHE-RSA-CAMELLIA256-SHA    )],
     '0x00,0x87' => [qw( SSLv3   DH              DSS     Camellia            256 SHA1    DHE-DSS-CAMELLIA256-SHA    )],
     '0x00,0x86' => [qw( SSLv3   DH/RSA          DH      Camellia            256 SHA1    DH-RSA-CAMELLIA256-SHA    )],
     '0x00,0x85' => [qw( SSLv3   DH/DSS          DH      Camellia            256 SHA1    DH-DSS-CAMELLIA256-SHA    )],
     '0xC0,0x19' => [qw( SSLv3   ECDH            None    AES                 256 SHA1    AECDH-AES256-SHA    )],
     '0x00,0xA7' => [qw( TLSv12  DH              None    AESGCM              256 AEAD    ADH-AES256-GCM-SHA384    )],
     '0x00,0x6D' => [qw( TLSv12  DH              None    AES                 256 SHA256  ADH-AES256-SHA256    )],
     '0x00,0x3A' => [qw( SSLv3   DH              None    AES                 256 SHA1    ADH-AES256-SHA    )],
     '0x00,0xC5' => [qw( TLSv12  DH              None    Camellia            256 SHA256  ADH-CAMELLIA256-SHA256    )],
     '0x00,0x89' => [qw( SSLv3   DH              None    Camellia            256 SHA1    ADH-CAMELLIA256-SHA    )],
     '0xC0,0x32' => [qw( TLSv12  ECDH/RSA        ECDH    AESGCM              256 AEAD    ECDH-RSA-AES256-GCM-SHA384    )],
     '0xC0,0x2E' => [qw( TLSv12  ECDH/ECDSA      ECDH    AESGCM              256 AEAD    ECDH-ECDSA-AES256-GCM-SHA384    )],
     '0xC0,0x2A' => [qw( TLSv12  ECDH/RSA        ECDH    AES                 256 SHA384  ECDH-RSA-AES256-SHA384    )],
     '0xC0,0x26' => [qw( TLSv12  ECDH/ECDSA      ECDH    AES                 256 SHA384  ECDH-ECDSA-AES256-SHA384    )],
     '0xC0,0x0F' => [qw( SSLv3   ECDH/RSA        ECDH    AES                 256 SHA1    ECDH-RSA-AES256-SHA    )],
     '0xC0,0x05' => [qw( SSLv3   ECDH/ECDSA      ECDH    AES                 256 SHA1    ECDH-ECDSA-AES256-SHA    )],
     '0xC0,0x79' => [qw( TLSv12  ECDH/RSA        ECDH    Camellia            256 SHA384  ECDH-RSA-CAMELLIA256-SHA384    )],
     '0xC0,0x75' => [qw( TLSv12  ECDH/ECDSA      ECDH    Camellia            256 SHA384  ECDH-ECDSA-CAMELLIA256-SHA384    )],
     '0x00,0x9D' => [qw( TLSv12  RSA             RSA     AESGCM              256 AEAD    AES256-GCM-SHA384    )],
     '0x00,0x3D' => [qw( TLSv12  RSA             RSA     AES                 256 SHA256  AES256-SHA256    )],
     '0x00,0x35' => [qw( SSLv3   RSA             RSA     AES                 256 SHA1    AES256-SHA    )],
     '0x00,0xC0' => [qw( TLSv12  RSA             RSA     Camellia            256 SHA256  CAMELLIA256-SHA256    )],
     '0x00,0x84' => [qw( SSLv3   RSA             RSA     Camellia            256 SHA1    CAMELLIA256-SHA    )],
     '0x00,0x95' => [qw( SSLv3   RSAPSK          RSA     AES                 256 SHA1    RSA-PSK-AES256-CBC-SHA    )],
     '0x00,0x8D' => [qw( SSLv3   PSK             PSK     AES                 256 SHA1    PSK-AES256-CBC-SHA    )],
     '0xC0,0x2F' => [qw( TLSv12  ECDH            RSA     AESGCM              128 AEAD    ECDHE-RSA-AES128-GCM-SHA256    )],
     '0xC0,0x2B' => [qw( TLSv12  ECDH            ECDSA   AESGCM              128 AEAD    ECDHE-ECDSA-AES128-GCM-SHA256    )],
     '0xC0,0x27' => [qw( TLSv12  ECDH            RSA     AES                 128 SHA256  ECDHE-RSA-AES128-SHA256    )],
     '0xC0,0x23' => [qw( TLSv12  ECDH            ECDSA   AES                 128 SHA256  ECDHE-ECDSA-AES128-SHA256    )],
     '0xC0,0x13' => [qw( SSLv3   ECDH            RSA     AES                 128 SHA1    ECDHE-RSA-AES128-SHA    )],
     '0xC0,0x09' => [qw( SSLv3   ECDH            ECDSA   AES                 128 SHA1    ECDHE-ECDSA-AES128-SHA    )],
     '0xC0,0x1F' => [qw( SSLv3   SRP             DSS     AES                 128 SHA1    SRP-DSS-AES-128-CBC-SHA    )],
     '0xC0,0x1E' => [qw( SSLv3   SRP             RSA     AES                 128 SHA1    SRP-RSA-AES-128-CBC-SHA    )],
     '0xC0,0x1D' => [qw( SSLv3   SRP             SRP     AES                 128 SHA1    SRP-AES-128-CBC-SHA    )],
     '0x00,0xA4' => [qw( TLSv12  DH/DSS          DH      AESGCM              128 AEAD    DH-DSS-AES128-GCM-SHA256    )],
     '0x00,0xA2' => [qw( TLSv12  DH              DSS     AESGCM              128 AEAD    DHE-DSS-AES128-GCM-SHA256    )],
     '0x00,0xA0' => [qw( TLSv12  DH/RSA          DH      AESGCM              128 AEAD    DH-RSA-AES128-GCM-SHA256    )],
     '0x00,0x9E' => [qw( TLSv12  DH              RSA     AESGCM              128 AEAD    DHE-RSA-AES128-GCM-SHA256    )],
     '0x00,0x67' => [qw( TLSv12  DH              RSA     AES                 128 SHA256  DHE-RSA-AES128-SHA256    )],
     '0x00,0x40' => [qw( TLSv12  DH              DSS     AES                 128 SHA256  DHE-DSS-AES128-SHA256    )],
     '0x00,0x3F' => [qw( TLSv12  DH/RSA          DH      AES                 128 SHA256  DH-RSA-AES128-SHA256    )],
     '0x00,0x3E' => [qw( TLSv12  DH/DSS          DH      AES                 128 SHA256  DH-DSS-AES128-SHA256    )],
     '0x00,0x33' => [qw( SSLv3   DH              RSA     AES                 128 SHA1    DHE-RSA-AES128-SHA    )],
     '0x00,0x32' => [qw( SSLv3   DH              DSS     AES                 128 SHA1    DHE-DSS-AES128-SHA    )],
     '0x00,0x31' => [qw( SSLv3   DH/RSA          DH      AES                 128 SHA1    DH-RSA-AES128-SHA    )],
     '0x00,0x30' => [qw( SSLv3   DH/DSS          DH      AES                 128 SHA1    DH-DSS-AES128-SHA    )],
     '0xC0,0x76' => [qw( TLSv12  ECDH            RSA     Camellia            128 SHA256  ECDHE-RSA-CAMELLIA128-SHA256    )],
     '0xC0,0x72' => [qw( TLSv12  ECDH            ECDSA   Camellia            128 SHA256  ECDHE-ECDSA-CAMELLIA128-SHA256    )],
     '0x00,0xBE' => [qw( TLSv12  DH              RSA     Camellia            128 SHA256  DHE-RSA-CAMELLIA128-SHA256    )],
     '0x00,0xBD' => [qw( TLSv12  DH              DSS     Camellia            128 SHA256  DHE-DSS-CAMELLIA128-SHA256    )],
     '0x00,0xBC' => [qw( TLSv12  DH/RSA          DH      Camellia            128 SHA256  DH-RSA-CAMELLIA128-SHA256    )],
     '0x00,0xBB' => [qw( TLSv12  DH/DSS          DH      Camellia            128 SHA256  DH-DSS-CAMELLIA128-SHA256    )],
     '0x00,0x9A' => [qw( SSLv3   DH              RSA     SEED                128 SHA1    DHE-RSA-SEED-SHA    )],
     '0x00,0x99' => [qw( SSLv3   DH              DSS     SEED                128 SHA1    DHE-DSS-SEED-SHA    )],
     '0x00,0x98' => [qw( SSLv3   DH/RSA          DH      SEED                128 SHA1    DH-RSA-SEED-SHA    )],
     '0x00,0x97' => [qw( SSLv3   DH/DSS          DH      SEED                128 SHA1    DH-DSS-SEED-SHA    )],
     '0x00,0x45' => [qw( SSLv3   DH              RSA     Camellia            128 SHA1    DHE-RSA-CAMELLIA128-SHA    )],
     '0x00,0x44' => [qw( SSLv3   DH              DSS     Camellia            128 SHA1    DHE-DSS-CAMELLIA128-SHA    )],
     '0x00,0x43' => [qw( SSLv3   DH/RSA          DH      Camellia            128 SHA1    DH-RSA-CAMELLIA128-SHA    )],
     '0x00,0x42' => [qw( SSLv3   DH/DSS          DH      Camellia            128 SHA1    DH-DSS-CAMELLIA128-SHA    )],
     '0xC0,0x18' => [qw( SSLv3   ECDH            None    AES                 128 SHA1    AECDH-AES128-SHA    )],
     '0x00,0xA6' => [qw( TLSv12  DH              None    AESGCM              128 AEAD    ADH-AES128-GCM-SHA256    )],
     '0x00,0x6C' => [qw( TLSv12  DH              None    AES                 128 SHA256  ADH-AES128-SHA256    )],
     '0x00,0x34' => [qw( SSLv3   DH              None    AES                 128 SHA1    ADH-AES128-SHA    )],
     '0x00,0xBF' => [qw( TLSv12  DH              None    Camellia            128 SHA256  ADH-CAMELLIA128-SHA256    )],
     '0x00,0x9B' => [qw( SSLv3   DH              None    SEED                128 SHA1    ADH-SEED-SHA    )],
     '0x00,0x46' => [qw( SSLv3   DH              None    Camellia            128 SHA1    ADH-CAMELLIA128-SHA    )],
     '0xC0,0x31' => [qw( TLSv12  ECDH/RSA        ECDH    AESGCM              128 AEAD    ECDH-RSA-AES128-GCM-SHA256    )],
     '0xC0,0x2D' => [qw( TLSv12  ECDH/ECDSA      ECDH    AESGCM              128 AEAD    ECDH-ECDSA-AES128-GCM-SHA256    )],
     '0xC0,0x29' => [qw( TLSv12  ECDH/RSA        ECDH    AES                 128 SHA256  ECDH-RSA-AES128-SHA256    )],
     '0xC0,0x25' => [qw( TLSv12  ECDH/ECDSA      ECDH    AES                 128 SHA256  ECDH-ECDSA-AES128-SHA256    )],
     '0xC0,0x0E' => [qw( SSLv3   ECDH/RSA        ECDH    AES                 128 SHA1    ECDH-RSA-AES128-SHA    )],
     '0xC0,0x04' => [qw( SSLv3   ECDH/ECDSA      ECDH    AES                 128 SHA1    ECDH-ECDSA-AES128-SHA    )],
     '0xC0,0x78' => [qw( TLSv12  ECDH/RSA        ECDH    Camellia            128 SHA256  ECDH-RSA-CAMELLIA128-SHA256    )],
     '0xC0,0x74' => [qw( TLSv12  ECDH/ECDSA      ECDH    Camellia            128 SHA256  ECDH-ECDSA-CAMELLIA128-SHA256    )],
     '0x00,0x9C' => [qw( TLSv12  RSA             RSA     AESGCM              128 AEAD    AES128-GCM-SHA256    )],
     '0x00,0x3C' => [qw( TLSv12  RSA             RSA     AES                 128 SHA256  AES128-SHA256    )],
     '0x00,0x2F' => [qw( SSLv3   RSA             RSA     AES                 128 SHA1    AES128-SHA    )],
     '0x00,0xBA' => [qw( TLSv12  RSA             RSA     Camellia            128 SHA256  CAMELLIA128-SHA256    )],
     '0x00,0x96' => [qw( SSLv3   RSA             RSA     SEED                128 SHA1    SEED-SHA    )],
     '0x00,0x41' => [qw( SSLv3   RSA             RSA     Camellia            128 SHA1    CAMELLIA128-SHA    )],
     '0x00,0x07' => [qw( SSLv3   RSA             RSA     IDEA                128 SHA1    IDEA-CBC-SHA     )],
'0x05,0x00,0x80' => [qw( SSLv2   RSA             RSA     IDEA                128 MD5     IDEA-CBC-MD5     )],
'0x03,0x00,0x80' => [qw( SSLv2   RSA             RSA     RC2                 128 MD5     RC2-CBC-MD5     )],
     '0x00,0x94' => [qw( SSLv3   RSAPSK          RSA     AES                 128 SHA1    RSA-PSK-AES128-CBC-SHA    )],
     '0x00,0x8C' => [qw( SSLv3   PSK             PSK     AES                 128 SHA1    PSK-AES128-CBC-SHA    )],
     '0xC0,0x11' => [qw( SSLv3   ECDH            RSA     RC4                 128 SHA1    ECDHE-RSA-RC4-SHA    )],
     '0xC0,0x07' => [qw( SSLv3   ECDH            ECDSA   RC4                 128 SHA1    ECDHE-ECDSA-RC4-SHA    )],
     '0x00,0x66' => [qw( SSLv3   DH              DSS     RC4                 128 SHA1    DHE-DSS-RC4-SHA    )],
     '0xC0,0x16' => [qw( SSLv3   ECDH            None    RC4                 128 SHA1    AECDH-RC4-SHA    )],
     '0x00,0x18' => [qw( SSLv3   DH              None    RC4                 128 MD5     ADH-RC4-MD5    )],
     '0xC0,0x0C' => [qw( SSLv3   ECDH/RSA        ECDH    RC4                 128 SHA1    ECDH-RSA-RC4-SHA    )],
     '0xC0,0x02' => [qw( SSLv3   ECDH/ECDSA      ECDH    RC4                 128 SHA1    ECDH-ECDSA-RC4-SHA    )],
     '0x00,0x05' => [qw( SSLv3   RSA             RSA     RC4                 128 SHA1    RC4-SHA    )],
     '0x00,0x04' => [qw( SSLv3   RSA             RSA     RC4                 128 MD5     RC4-MD5    )],
'0x01,0x00,0x80' => [qw( SSLv2   RSA             RSA     RC4                 128 MD5     RC4-MD5    )],
     '0x00,0x92' => [qw( SSLv3   RSAPSK          RSA     RC4                 128 SHA1    RSA-PSK-RC4-SHA    )],
     '0x00,0x8A' => [qw( SSLv3   PSK             PSK     RC4                 128 SHA1    PSK-RC4-SHA    )],
     '0xC0,0x12' => [qw( SSLv3   ECDH            RSA     3DES                168 SHA1    ECDHE-RSA-DES-CBC3-SHA    )],
     '0xC0,0x08' => [qw( SSLv3   ECDH            ECDSA   3DES                168 SHA1    ECDHE-ECDSA-DES-CBC3-SHA    )],
     '0xC0,0x1C' => [qw( SSLv3   SRP             DSS     3DES                168 SHA1    SRP-DSS-3DES-EDE-CBC-SHA    )],
     '0xC0,0x1B' => [qw( SSLv3   SRP             RSA     3DES                168 SHA1    SRP-RSA-3DES-EDE-CBC-SHA    )],
     '0xC0,0x1A' => [qw( SSLv3   SRP             SRP     3DES                168 SHA1    SRP-3DES-EDE-CBC-SHA    )],
     '0x00,0x16' => [qw( SSLv3   DH              RSA     3DES                168 SHA1    EDH-RSA-DES-CBC3-SHA    )],
     '0x00,0x13' => [qw( SSLv3   DH              DSS     3DES                168 SHA1    EDH-DSS-DES-CBC3-SHA    )],
     '0x00,0x10' => [qw( SSLv3   DH/RSA          DH      3DES                168 SHA1    DH-RSA-DES-CBC3-SHA    )],
     '0x00,0x0D' => [qw( SSLv3   DH/DSS          DH      3DES                168 SHA1    DH-DSS-DES-CBC3-SHA    )],
     '0xC0,0x17' => [qw( SSLv3   ECDH            None    3DES                168 SHA1    AECDH-DES-CBC3-SHA    )],
     '0x00,0x1B' => [qw( SSLv3   DH              None    3DES                168 SHA1    ADH-DES-CBC3-SHA    )],
     '0xC0,0x0D' => [qw( SSLv3   ECDH/RSA        ECDH    3DES                168 SHA1    ECDH-RSA-DES-CBC3-SHA    )],
     '0xC0,0x03' => [qw( SSLv3   ECDH/ECDSA      ECDH    3DES                168 SHA1    ECDH-ECDSA-DES-CBC3-SHA    )],
     '0x00,0x0A' => [qw( SSLv3   RSA             RSA     3DES                168 SHA1    DES-CBC3-SHA    )],
'0x07,0x00,0xC0' => [qw( SSLv2   RSA             RSA     3DES                168 MD5     DES-CBC3-MD5    )],
     '0x00,0x93' => [qw( SSLv3   RSAPSK          RSA     3DES                168 SHA1    RSA-PSK-3DES-EDE-CBC-SHA    )],
     '0x00,0x8B' => [qw( SSLv3   PSK             PSK     3DES                168 SHA1    PSK-3DES-EDE-CBC-SHA    )],
'0x08,0x00,0x80' => [qw( SSLv2   RSA             RSA     RC4                  64 MD5     RC4-64-MD5    )],
     '0x00,0x63' => [qw( SSLv3   DH(1024)        DSS     DES                  56 SHA1    EXP1024-DHE-DSS-DES-CBC-SHA   export )],
     '0x00,0x15' => [qw( SSLv3   DH              RSA     DES                  56 SHA1    EDH-RSA-DES-CBC-SHA    )],
     '0x00,0x12' => [qw( SSLv3   DH              DSS     DES                  56 SHA1    EDH-DSS-DES-CBC-SHA    )],
     '0x00,0x0F' => [qw( SSLv3   DH/RSA          DH      DES                  56 SHA1    DH-RSA-DES-CBC-SHA    )],
     '0x00,0x0C' => [qw( SSLv3   DH/DSS          DH      DES                  56 SHA1    DH-DSS-DES-CBC-SHA    )],
     '0x00,0x1A' => [qw( SSLv3   DH              None    DES                  56 SHA1    ADH-DES-CBC-SHA    )],
     '0x00,0x62' => [qw( SSLv3   RSA(1024)       RSA     DES                  56 SHA1    EXP1024-DES-CBC-SHA   export )],
     '0x00,0x09' => [qw( SSLv3   RSA             RSA     DES                  56 SHA1    DES-CBC-SHA    )],
     '0x00,0x61' => [qw( SSLv3   RSA(1024)       RSA     RC2                  56 MD5     EXP1024-RC2-CBC-MD5   export )],
'0x06,0x00,0x40' => [qw( SSLv2   RSA             RSA     DES                  56 MD5     DES-CBC-MD5    )],
     '0x00,0x65' => [qw( SSLv3   DH(1024)        DSS     RC4                  56 SHA1    EXP1024-DHE-DSS-RC4-SHA   export )],
     '0x00,0x64' => [qw( SSLv3   RSA(1024)       RSA     RC4                  56 SHA1    EXP1024-RC4-SHA   export )],
     '0x00,0x60' => [qw( SSLv3   RSA(1024)       RSA     RC4                  56 MD5     EXP1024-RC4-MD5   export )],
     '0x00,0x14' => [qw( SSLv3   DH(512)         RSA     DES                  40 SHA1    EXP-EDH-RSA-DES-CBC-SHA   export )],
     '0x00,0x11' => [qw( SSLv3   DH(512)         DSS     DES                  40 SHA1    EXP-EDH-DSS-DES-CBC-SHA   export )],
     '0x00,0x19' => [qw( SSLv3   DH(512)         None    DES                  40 SHA1    EXP-ADH-DES-CBC-SHA   export )],
     '0x00,0x08' => [qw( SSLv3   RSA(512)        RSA     DES                  40 SHA1    EXP-DES-CBC-SHA   export )],
     '0x00,0x06' => [qw( SSLv3   RSA(512)        RSA     RC2                  40 MD5     EXP-RC2-CBC-MD5   export )],
'0x04,0x00,0x80' => [qw( SSLv2   RSA(512)        RSA     RC2                  40 MD5     EXP-RC2-CBC-MD5   export )],
     '0x00,0x17' => [qw( SSLv3   DH(512)         None    RC4                  40 MD5     EXP-ADH-RC4-MD5   export )],
     '0x00,0x03' => [qw( SSLv3   RSA(512)        RSA     RC4                  40 MD5     EXP-RC4-MD5   export )],
'0x02,0x00,0x80' => [qw( SSLv2   RSA(512)        RSA     RC4                  40 MD5     EXP-RC4-MD5   export )],
     '0x00,0x0B' => [qw( SSLv3   DH(512)         DSS     DES                  40 SHA1    EXP-DH-DSS-DES-CBC-SHA export )],
     '0x00,0x0E' => [qw( SSLv3   DH(512)         RSA     DES                  40 SHA1    EXP-DH-RSA-DES-CBC-SHA export )],
     '0x00,0x27' => [qw( SSLv3   KRB5            KRB5    RC2                  40 SHA1    EXP-KRB5-RC2-CBC-SHA  export )],
     '0x00,0x26' => [qw( SSLv3   KRB5            KRB5    DES                  40 SHA1    EXP-KRB5-DES-CBC-SHA  export )],
     '0x00,0x2A' => [qw( SSLv3   KRB5            KRB5    RC2                  40 MD5     EXP-KRB5-RC2-CBC-MD5  export )],
     '0x00,0x29' => [qw( SSLv3   KRB5            KRB5    DES                  40 MD5     EXP-KRB5-DES-CBC-MD5  export )],
     '0x00,0x28' => [qw( SSLv3   KRB5            KRB5    RC4                  40 SHA1    EXP-KRB5-RC4-SHA      export )],
     '0x00,0x2B' => [qw( SSLv3   KRB5            KRB5    RC4                  40 MD5     EXP-KRB5-RC4-MD5      export )],
     '0x00,0x21' => [qw( SSLv3   KRB5            KRB5    IDEA                128 SHA1    KRB5-IDEA-CBC-SHA    )],
     '0x00,0x25' => [qw( SSLv3   KRB5            KRB5    IDEA                128 MD5     KRB5-IDEA-CBC-MD5    )],
     '0x00,0x20' => [qw( SSLv3   KRB5            KRB5    RC4                 128 SHA1    KRB5-RC4-SHA    )],
     '0x00,0x24' => [qw( SSLv3   KRB5            KRB5    RC4                 128 MD5     KRB5-RC4-MD5    )],
     '0x00,0x1F' => [qw( SSLv3   KRB5            KRB5    3DES                168 SHA1    KRB5-DES-CBC3-SHA    )],
     '0x00,0x23' => [qw( SSLv3   KRB5            KRB5    3DES                168 MD5     KRB5-DES-CBC3-MD5    )],
     '0x00,0x1E' => [qw( SSLv3   KRB5            KRB5    DES                  56 SHA1    KRB5-DES-CBC-SHA    )],
     '0x00,0x22' => [qw( SSLv3   KRB5            KRB5    DES                  56 MD5     KRB5-DES-CBC-MD5    )],
     '0x00,0x81' => [qw( SSLv3   GOST            GOST01  GOST89              256 GOST89  GOST2001-GOST89-GOST89    )],
     '0x00,0x80' => [qw( SSLv3   GOST            GOST94  GOST89              256 GOST89  GOST94-GOST89-GOST89    )],
     '0xFF,0x03' => [qw( SSLv3   RSA             RSA     GOST89              256 GOST89  GOST-GOST89STREAM    )],
     '0xFF,0x02' => [qw( SSLv3   RSA             RSA     GOST89              256 GOST89  GOST-GOST89MAC    )],
     '0xFF,0x01' => [qw( SSLv3   RSA             RSA     GOST89              256 GOST94  GOST-GOST94    )],
     '0xFF,0x00' => [qw( SSLv3   RSA             RSA     GOST89              256 MD5     GOST-MD5    )],
     '0x00,0x83' => [qw( SSLv3   GOST            GOST01  None                  0 GOST94  GOST2001-NULL-GOST94    )],
     '0x00,0x82' => [qw( SSLv3   GOST            GOST94  None                  0 GOST94  GOST94-NULL-GOST94    )],
           # key => [qw( ssl     kx              au      enc                 bit mac     name   tags )],

); # %_ciphers_openssl_all

1;
