#!/usr/bin/perl

use strict; # useless include, but keeps perlcritic silent
use warnings;  # -"-

#
# This files is manually crafted. NOT YET in any repository!
#

=pod

=encoding utf8

=head1 NAME

Internal cipher suite definitons for O-Saft and related tools.

=head1 DESCRIPTION

This file is part of L<OSaft::Ciphers> and used for initializing data there.
It is only used when requested as external file in L<OSaft::Ciphers>. For more
details please see L<OSaft::Ciphers> itself.

=head1 SYNOPSIS

  eval {require qw{OSaft/_ciphers_osaft.pm}; } or carp ...

=head1 VARIABLES

Following variables (hashes) are defined herein:

=over 4

=item %_ciphers_osaft

Complete list of ciphers with all their descriptions, similar to output of:

   openssl ciphers -V ALL:aNULL:eNULL:EXPORT:COMPLEMENTOFALL

=item %_ciphers_names

Mapping of cipher names and cipher constant names.

=item %_ciphers_alias

Additional names for ciphers.

=back

=head1 NOTE

Perl accepts duplicate entries in hashes,  means that the last definition will
be used. No notice will be shown.
So the check, if the keys for ciphers in  C<%ciphers>  are unique, needs to be
done manually, for example with:

    awk -F"'" '/^ *$/{next}/%_ciphers_osaft/{p=1;next}/^)$/if(p==1){{exit}}
                ($1~/#/){next}(p==1){print $2}
              ' OSaft/_ciphers_osaft.pm | sort | uniq -d

    awk -F"'" '/^ *$/{next}/%_ciphers_names/{p=1;next}/^)$/if(p==1){{exit}}
                ($1~/#/){next}(p==1){print $2}
              ' OSaft/_ciphers_osaft.pm | sort | uniq -d

(to be improved in many ways:)

=head1 SEE ALSO

L<OSaft::Ciphers>

=head1 AUTHOR

28-may-16 Achim Hoffmann

=cut


#	Alle Spalten sollten in Leerzeichen eingeschlossen sein,
#	damit man mit awk die Datei wieder sauber durchsuchen kann.
#	Wenn keine "tags" da sind, fehlt der Wert. In den "tags" wird : als
#	Trenner verwendet.
#	bei hex-Werten nur upper case
#	key ist i.d.R. die hex-Constante (wie von "openssl ciphers -V" gezeigt)
#
#	folgende Unterschiede eingearbeitet (Kommentar # unklar)
#		xxdiff 20160417-local/yeast+ciphers_-V.txt 20160530-local/yeast+ciphers_-V.txt
#		https://www.bro.org/sphinx/_downloads/consts10.bro
#
#       Es fehlt noch:
#		https://wolfssl.com/wolfSSL//Docs-wolfssl-manual-4-features_files/widget3_markup.html
#		http://mirror.ufs.ac.za/misc/openvas-nvt-feed/secpod_ssl_ciphers.inc
#
#	TODO:
#		* in cipher_alias sind viele  DH_anon_  die sonst  ADH_  heissen
#		  das ist in cfg{regex} schon bekannt, kann also generiert werden
#		* in cipher_alias sind viele  _CBC_  die sonst ohne vorkommen
#		  _CBC_ ist eigentlich besser
#		* in cipher_alias sind viele _EDE_CBC: die sonst nur _CBC_ heissen
#		  _DES_192_CBC3_ und _3DES_CBC_ und _3DES_EDE_CBC_ sind identisch


our %_ciphers_osaft = (
    #? internal list, additions to %_ciphers_openssl
    # /opt/tools/openssl-chacha/bin/openssl ciphers -V ALL:eNULL:LOW:EXP \
    # values  -?-  are unknown yet
    #!#----------------+-------+----------+-----+-------+----+------+------+------,
    #!# key     => [qw( ssl     keyx       auth  enc     bits mac    sec    tags)],
    #!#----------------+-------+----------+-----+-------+----+------+------+------,
'0x00,0x00,0x00' => [qw( SSLv2  NULL       None  None       0 MD5    weak   )], # O-Saft dummy
'0x01,0x00,0x80' => [qw( SSLv2  RSA        RSA   RC4      128 MD5    weak   )], # openssl: MEDIUM
'0x02,0x00,0x80' => [qw( SSLv2  RSA(512)   RSA   RC4       40 MD5    WEAK   export )],
'0x03,0x00,0x80' => [qw( SSLv2  RSA        RSA   RC2      128 MD5    weak   openssl-1.0.2d )],
'0x04,0x00,0x80' => [qw( SSLv2  RSA(512)   RSA   RC2       40 MD5    WEAK   export:openssl-1.0.2d )],
'0x05,0x00,0x80' => [qw( SSLv2  RSA        RSA   IDEA     128 MD5    weak   )],
'0x06,0x00,0x40' => [qw( SSLv2  RSA        RSA   DES       56 MD5    weak   )],
'0x06,0x01,0x40' => [qw( SSLv2  RSA        RSA   DES       56 SHA1   weak   )],
'0x07,0x00,0xC0' => [qw( SSLv2  RSA        RSA   3DES     168 MD5    weak   )],
'0x07,0x01,0xC0' => [qw( SSLv2  RSA        RSA   3DES     168 SHA1   weak   )],
'0x08,0x00,0x80' => [qw( SSLv2  RSA        RSA   RC4       64 MD5    weak   )],
'0xFF,0x08,0x00' => [qw( SSLv2  RSA        RSA   DES       64 MD5    weak   )],
'0xFF,0x08,0x10' => [qw( SSLv2  -?-        None  None       0 -?-    weak   openssl_SSLeay_testing )],
    '0x00,0x00' => [qw( SSLv3   NULL       None  None       0 MD5    weak   )], # O-Saft dummy
#   '0x00,0x01' => [qw( SSLv3   RSA(512)   RSA   None       0 MD5    weak   export )], # unklar ??
    '0x00,0x01' => [qw( SSLv3   RSA        RSA   None       0 MD5    weak   export )],
    '0x00,0x02' => [qw( SSLv3   RSA        RSA   None       0 SHA1   weak   )],
    '0x00,0x03' => [qw( SSLv3   RSA(512)   RSA   RC4       40 MD5    WEAK   export )],
    '0x00,0x04' => [qw( SSLv3   RSA        RSA   RC4      128 MD5    weak   )], # openssl: MEDIUM
    '0x00,0x05' => [qw( SSLv3   RSA        RSA   RC4      128 SHA1   weak   )], # openssl: MEDIUM
    '0x00,0x06' => [qw( SSLv3   RSA(512)   RSA   RC2       40 MD5    WEAK   export )],
    '0x00,0x07' => [qw( SSLv2   RSA        RSA   IDEA     128 SHA1   weak   )],
    '0x00,0x08' => [qw( SSLv3   RSA(512)   RSA   DES       40 SHA1   WEAK   export )],
    '0x00,0x09' => [qw( SSLv3   RSA        RSA   DES       56 SHA1   weak   )],
    '0x00,0x0A' => [qw( SSLv2   RSA        RSA   3DES     168 SHA1   weak   )],
    '0x00,0x10' => [qw( SSLv3   DH         RSA   3DES     168 SHA1   weak   )], # unklar
    '0x00,0x11' => [qw( SSLv3   DH(512)    DSS   DES       40 SHA1   WEAK   export )],
    '0x00,0x12' => [qw( SSLv3   DH         DSS   DES       56 SHA1   weak   )],
    '0x00,0x13' => [qw( SSLv3   DH         DSS   3DES     168 SHA1   weak   )],
    '0x00,0x14' => [qw( SSLv3   DH(512)    RSA   DES       40 SHA1   WEAK   export )],
    '0x00,0x15' => [qw( SSLv3   DH         RSA   DES       56 SHA1   weak   )],
    '0x00,0x16' => [qw( SSLv3   DH         RSA   3DES     168 SHA1   weak   )],
    '0x00,0x17' => [qw( SSLv3   DH(512)    None  RC4       40 MD5    weak   export )],
    '0x00,0x18' => [qw( SSLv3   DH         None  RC4      128 MD5    weak   )], # openssl: MEDIUM
    '0x00,0x19' => [qw( SSLv3   DH(512)    None  DES       40 SHA1   weak   export )],
    '0x00,0x1A' => [qw( SSLv3   DH         None  DES       56 SHA1   weak   )], # openssl: LOW
    '0x00,0x1B' => [qw( SSLv3   DH         None  3DES     168 SHA1   weak   )], # openssl: HIGH
    '0x00,0x1C' => [qw( SSLv3   FZA        KEA   None       0 SHA1   weak   openssl-1.0.1g )], # from ssl/s3_lib.c
    '0x00,0x1D' => [qw( SSLv3   FZA        KEA   FZA        0 SHA1   MEDIUM openssl-1.0.1g )], # from ssl/s3_lib.c
#             /---- lower case E as it is a duplicate!
    '0x00,0x1e' => [qw( SSLv3   FZA        KEA   RC4      128 SHA1   WEAK   openssl-1.0.1g )], # from ssl/s3_lib.c
    '0x00,0x1E' => [qw( SSLv3   KRB5       KRB5  DES       56 SHA1   weak   openssl-1.0.1g )],
    '0x00,0x1F' => [qw( SSLv3   KRB5       KRB5  3DES     168 SHA1   weak   openssl-1.0.1g )],
    '0x00,0x20' => [qw( SSLv3   KRB5       KRB5  RC4      128 SHA1   weak   openssl-1.0.1g )],
    '0x00,0x21' => [qw( SSLv3   KRB5       KRB5  IDEA     128 SHA1   weak   openssl-1.0.1g )],
    '0x00,0x22' => [qw( SSLv3   KRB5       KRB5  DES       56 MD5    weak   openssl-1.0.1g )],
    '0x00,0x23' => [qw( SSLv3   KRB5       KRB5  3DES     168 MD5    weak   openssl-1.0.1g )],
    '0x00,0x24' => [qw( SSLv3   KRB5       KRB5  RC4      128 MD5    weak   openssl-1.0.1g )],
    '0x00,0x25' => [qw( SSLv3   KRB5       KRB5  IDEA     128 MD5    weak   openssl-1.0.1g )],
    '0x00,0x26' => [qw( SSLv3   KRB5       KRB5  DES       40 SHA1   WEAK   export:openssl-1.0.1g )],
    '0x00,0x27' => [qw( SSLv3   KRB5       KRB5  RC2       40 SHA1   WEAK   export:openssl-1.0.1g )],
    '0x00,0x28' => [qw( SSLv3   KRB5       KRB5  RC4       40 SHA1   WEAK   export:openssl-1.0.1g )],
    '0x00,0x29' => [qw( SSLv3   KRB5       KRB5  DES       40 MD5    WEAK   export:openssl-1.0.1g )],
    '0x00,0x2A' => [qw( SSLv3   KRB5       KRB5  RC2       40 MD5    WEAK   export:openssl-1.0.1g )],
    '0x00,0x2B' => [qw( SSLv3   KRB5       KRB5  RC4       40 MD5    WEAK   export:openssl-1.0.1g )],
    '0x00,0x2F' => [qw( SSLv3   RSA        RSA   AES      128 SHA1   HIGH   )],
    '0x00,0x30' => [qw( SSLv3   DH         DSS   AES      128 SHA1   medium )],
    '0x00,0x31' => [qw( SSLv3   DH         RSA   AES      128 SHA1   medium )],
    '0x00,0x32' => [qw( SSLv3   DH         DSS   AES      128 SHA1   HIGH   )],
    '0x00,0x33' => [qw( SSLv3   DH         RSA   AES      128 SHA1   HIGH   )],
    '0x00,0x34' => [qw( SSLv3   DH         None  AES      128 SHA1   weak   openssl-1.0.1c )], # openssl: HIGH
    '0x00,0x35' => [qw( SSLv3   RSA        RSA   AES      256 SHA1   HIGH   )],
    '0x00,0x36' => [qw( SSLv3   DH         DSS   AES      256 SHA1   medium )],
    '0x00,0x37' => [qw( SSLv3   DH         RSA   AES      256 SHA1   medium )],
    '0x00,0x38' => [qw( SSLv3   DH         DSS   AES      256 SHA1   HIGH   )],
    '0x00,0x39' => [qw( SSLv3   DH         RSA   AES      256 SHA1   HIGH   )],
    '0x00,0x3A' => [qw( SSLv3   DH         None  AES      256 SHA1   weak   )], # openssl: HIGH
    '0x00,0x3B' => [qw( TLSv12  RSA        RSA   None       0 SHA256 weak   openssl-1.0.1c )],
    '0x00,0x3C' => [qw( TLSv12  RSA        RSA   AES      128 SHA256 HIGH   openssl-1.0.1c )],
    '0x00,0x3D' => [qw( TLSv12  RSA        RSA   AES      256 SHA256 HIGH   openssl-1.0.1c )],
    '0x00,0x3E' => [qw( TLSv12  DH         DSS   AES      128 SHA256 high   )],
    '0x00,0x3F' => [qw( TLSv12  DH         RSA   AES      128 SHA256 high   )],
    '0x00,0x40' => [qw( TLSv12  DH         DSS   AES      128 SHA256 HIGH   openssl-1.0.1c )],
    '0x00,0x41' => [qw( SSLv3   RSA        RSA   CAMELLIA 128 SHA1   HIGH   )],
    '0x00,0x42' => [qw( SSLv3   DSS        DH    CAMELLIA 128 SHA1   HIGH   openssl-1.0.2d )],
    '0x00,0x43' => [qw( SSLv3   DH         RSA   CAMELLIA 128 SHA1   HIGH   openssl-1.0.2d )],
    '0x00,0x44' => [qw( SSLv3   DH         DSS   CAMELLIA 128 SHA1   HIGH   )],
    '0x00,0x45' => [qw( SSLv3   DH         RSA   CAMELLIA 128 SHA1   HIGH   )],
    '0x00,0x46' => [qw( SSLv3   DH         None  CAMELLIA 128 SHA1   weak   )], # openssl: HIGH
    '0x00,0x60' => [qw( SSLv3   RSA(1024)  RSA   RC4       56 MD5    WEAK   export )],
    '0x00,0x61' => [qw( SSLv3   RSA(1024)  RSA   RC2       56 MD5    WEAK   export )],
    '0x00,0x62' => [qw( SSLv3   RSA(1024)  RSA   DES       56 SHA1   WEAK   export )],
    '0x00,0x63' => [qw( SSLv3   DH(1024)   DSS   DES       56 SHA1   WEAK   export )],
    '0x00,0x64' => [qw( SSLv3   RSA(1024)  RSA   RC4       56 SHA1   WEAK   export )],
    '0x00,0x65' => [qw( SSLv3   DH(1024)   DSS   RC4       56 SHA1   WEAK   export )],
    '0x00,0x66' => [qw( SSLv3   DH         DSS   RC4      128 SHA1   weak   )],
    '0x00,0x67' => [qw( TLSv12  DH         RSA   AES      128 SHA256 HIGH   openssl-1.0.1c )],
    '0x00,0x68' => [qw( TLSv12  DH         DSS   AES      256 SHA256 high   )],
    '0x00,0x69' => [qw( TLSv12  DH         RSA   AES      256 SHA256 high   )],
    '0x00,0x6A' => [qw( TLSv12  DH         DSS   AES      256 SHA256 HIGH   openssl-1.0.1c )],
    '0x00,0x6B' => [qw( TLSv12  DH         RSA   AES      256 SHA256 HIGH   openssl-1.0.1c )],
    '0x00,0x6C' => [qw( TLSv12  DH         None  AES      128 SHA256 weak   openssl-1.0.1c )], # openssl: HIGH
    '0x00,0x6D' => [qw( TLSv12  DH         None  AES      256 SHA256 weak   openssl-1.0.1c )], # openssl: HIGH
    '0x00,0x72' => [qw( TLSv12  ECDH       ECDSA CAMELLIA 128 SHA256 HIGH   )],
    '0x00,0x73' => [qw( TLSv12  ECDH       ECDSA CAMELLIA 256 SHA384 HIGH   )],
    '0x00,0x74' => [qw( TLSv12  ECDH       ECDSA CAMELLIA 128 SHA256 HIGH   )],
    '0x00,0x75' => [qw( TLSv12  ECDH       ECDSA CAMELLIA 256 SHA384 HIGH   )],
    '0x00,0x76' => [qw( TLSv12  ECDH       RSA   CAMELLIA 128 SHA256 HIGH   )],
    '0x00,0x77' => [qw( TLSv12  ECDH       RSA   CAMELLIA 256 SHA384 HIGH   )],
    '0x00,0x78' => [qw( TLSv12  ECDH       RSA   CAMELLIA 128 SHA256 HIGH   )],
    '0x00,0x79' => [qw( TLSv12  ECDH       RSA   CAMELLIA 256 SHA384 HIGH   )],
    '0x00,0x80' => [qw( SSLv3   VKO        GOST94 GOST89  256 GOST89  -?-   )],
    '0x00,0x81' => [qw( SSLv3   VKO        GOST01 GOST89  256 GOST89  -?-   )],
    '0x00,0x82' => [qw( SSLv3   VKO        GOST94 None      0 GOST94  -?-   )],
    '0x00,0x83' => [qw( SSLv3   VKO        GOST01 None      0 GOST94  -?-   )],
    '0x00,0x84' => [qw( SSLv3   RSA        RSA   CAMELLIA 256 SHA1   HIGH   )],
    '0x00,0x85' => [qw( SSLv3   DSS        DH    CAMELLIA 256 SHA1   HIGH   openssl-1.0.2d)], # openssl 1.0.2-chacha; auth=DH ??
    '0x00,0x86' => [qw( SSLv3   RSA        DH    CAMELLIA 256 SHA1   HIGH   openssl-1.0.2d)], # openssl 1.0.2-chacha; auth=DH ??
    '0x00,0x87' => [qw( SSLv3   DH         DSS   CAMELLIA 256 SHA1   HIGH   )],
    '0x00,0x88' => [qw( SSLv3   DH         RSA   CAMELLIA 256 SHA1   HIGH   )],
    '0x00,0x89' => [qw( SSLv3   DH         None  CAMELLIA 256 SHA1   weak   )], # openssl: HIGH
    '0x00,0x8A' => [qw( SSLv3   PSK        PSK   RC4      128 SHA1   MEDIUM )], # unklar: auth=DH/PSK
    '0x00,0x8B' => [qw( SSLv3   PSK        PSK   3DES     168 SHA1   weak   )], # unklar: auth=DH/PSK
    '0x00,0x8C' => [qw( SSLv3   PSK        PSK   AES      128 SHA1   HIGH   )], # unklar: auth=DH/PSK
    '0x00,0x8D' => [qw( SSLv3   PSK        PSK   AES      256 SHA1   HIGH   )], # unklar: auth=DH/PSK
    '0x00,0x92' => [qw( SSLv3   RSAPSK     RSA   RC4      128 SHA1   MEDIUM )],
    '0x00,0x93' => [qw( SSLv3   RSAPSK     RSA   3DES     168 SHA1   weak   )],
    '0x00,0x94' => [qw( SSLv3   RSAPSK     AES   AES      128 SHA1   HIGH   )],
    '0x00,0x95' => [qw( SSLv3   RSAPSK     AES   RSA      256 SHA1   HIGH   )],
    '0x00,0x96' => [qw( SSLv3   RSA        RSA   SEED     128 SHA1   MEDIUM OSX )],
    '0x00,0x97' => [qw( SSLv3   DH         DSS   SEED     128 SHA1   medium )],
    '0x00,0x98' => [qw( SSLv3   DH         RSA   SEED     128 SHA1   medium )],
    '0x00,0x99' => [qw( SSLv3   DH         DSS   SEED     128 SHA1   MEDIUM OSX )],
    '0x00,0x9A' => [qw( SSLv3   DH         RSA   SEED     128 SHA1   MEDIUM OSX )],
    '0x00,0x9B' => [qw( SSLv3   DH         None  SEED     128 SHA1   weak   OSX )], # openssl: MEDIUM
    '0x00,0x9C' => [qw( TLSv12  RSA        RSA   AESGCM   128 AEAD   HIGH   openssl-1.0.1c )],
    '0x00,0x9D' => [qw( TLSv12  RSA        RSA   AESGCM   256 AEAD   HIGH   openssl-1.0.1c )],
    '0x00,0x9E' => [qw( TLSv12  DH         RSA   AESGCM   128 AEAD   HIGH   openssl-1.0.1c )],
    '0x00,0x9F' => [qw( TLSv12  DH         RSA   AESGCM   256 AEAD   HIGH   openssl-1.0.1c )],
#    0x00,0xA0 .. 0x00,0xAF  siehe unten
    '0x00,0xB0' => [qw( TLSv12  PSK        PSK   None     0   SHA256 weak   )],
    '0x00,0xB1' => [qw( TLSv12  PSK        PSK   None     0   SHA384 weak   )],
    '0x00,0xB2' => [qw( TLSv12  DHE        PSK   AES      128 SHA256 -?-    )],
    '0x00,0xB3' => [qw( TLSv12  DHE        PSK   AES      256 SHA384 -?-    )],
    '0x00,0xB4' => [qw( TLSv12  DHE        PSK   None     0   SHA256 weak   )],
    '0x00,0xB5' => [qw( TLSv12  DHE        PSK   None     0   SHA384 weak   )],
    '0x00,0xB6' => [qw( TLSv12  RSA        PSK   AES      128 SHA256 -?-    )],
    '0x00,0xB7' => [qw( TLSv12  RSA        PSK   AES      256 SHA384 -?-    )],
    '0x00,0xB8' => [qw( TLSv12  RSA        PSK   None     0   SHA256 weak   )],
    '0x00,0xB9' => [qw( TLSv12  RSA        PSK   None     0   SHA384 weak   )],
    '0x00,0xBA' => [qw( TLSv12  RSA        RSA   CAMELLIA 128 SHA256 HIGH   openssl-1.0.2d )],
    '0x00,0xBB' => [qw( TLSv12  DSS        DH    CAMELLIA 128 SHA256 HIGH   openssl-1.0.2d )],
    '0x00,0xBC' => [qw( TLSv12  DH         RSA   CAMELLIA 128 SHA256 HIGH   openssl-1.0.2d )],
    '0x00,0xBD' => [qw( TLSv12  DH         DSS   CAMELLIA 128 SHA256 HIGH   openssl-1.0.2d )],
    '0x00,0xBE' => [qw( TLSv12  DH         RSA   CAMELLIA 128 SHA256 HIGH   openssl-1.0.2d )],
    '0x00,0xBF' => [qw( TLSv12  DH         None  CAMELLIA 128 SHA256 weak   openssl-1.0.2d )], # openssl: HIGH
    '0x00,0xC0' => [qw( TLSv12  RSA        RSA   CAMELLIA 256 SHA256 HIGH   openssl-1.0.2d )],
    '0x00,0xC1' => [qw( TLSv12  DSS        DH    CAMELLIA 256 SHA256 HIGH   openssl-1.0.2d )], # openssl 1.0.2-chacha; auth=DH ??
    '0x00,0xC2' => [qw( TLSv12  RSA        DH    CAMELLIA 256 SHA256 HIGH   openssl-1.0.2d )], # openssl 1.0.2-chacha; auth=DH ??
    '0x00,0xC3' => [qw( TLSv12  DH         DSS   CAMELLIA 256 SHA256 HIGH   openssl-1.0.2d )],
    '0x00,0xC4' => [qw( TLSv12  DH         RSA   CAMELLIA 256 SHA256 HIGH   openssl-1.0.2d )],
    '0x00,0xC5' => [qw( TLSv12  DH         None  CAMELLIA 256 SHA256 weak   openssl-1.0.2d )], # openssl: HIGH
    '0xC0,0x01' => [qw( SSLv3   ECDH/ECDSA ECDH  None       0 SHA1   weak   )],
    '0xC0,0x02' => [qw( SSLv3   ECDH/ECDSA ECDH  RC4      128 SHA1   weak   )], # openssl: MEDIUM
    '0xC0,0x03' => [qw( SSLv3   ECDH/ECDSA ECDH  3DES     168 SHA1   weak   )],
    '0xC0,0x04' => [qw( SSLv3   ECDH/ECDSA ECDH  AES      128 SHA1   HIGH   )],
    '0xC0,0x05' => [qw( SSLv3   ECDH/ECDSA ECDH  AES      256 SHA1   HIGH   )],
    '0xC0,0x06' => [qw( SSLv3   ECDH       ECDSA None       0 SHA1   weak   )],
    '0xC0,0x07' => [qw( SSLv3   ECDH       ECDSA RC4      128 SHA1   weak   )], # openssl: MEDIUM
    '0xC0,0x08' => [qw( SSLv3   ECDH       ECDSA 3DES     168 SHA1   weak   )],
    '0xC0,0x09' => [qw( SSLv3   ECDH       ECDSA AES      128 SHA1   HIGH   )],
    '0xC0,0x0A' => [qw( SSLv3   ECDH       ECDSA AES      256 SHA1   HIGH   )], # unklar: ECDH?
    '0xC0,0x0B' => [qw( SSLv3   ECDH/RSA   ECDH  None       0 SHA1   weak   )],
    '0xC0,0x0C' => [qw( SSLv3   ECDH/RSA   ECDH  RC4      128 SHA1   weak   )], # openssl: MEDIUM
    '0xC0,0x0D' => [qw( SSLv3   ECDH/RSA   ECDH  3DES     168 SHA1   weak   )],
    '0xC0,0x0E' => [qw( SSLv3   ECDH/RSA   ECDH  AES      128 SHA1   HIGH   )],
    '0xC0,0x0F' => [qw( SSLv3   ECDH/RSA   ECDH  AES      256 SHA1   HIGH   )],
    '0xC0,0x10' => [qw( SSLv3   ECDH       RSA   None       0 SHA1   weak   )],
    '0xC0,0x11' => [qw( SSLv3   ECDH       RSA   RC4      128 SHA1   weak   )], # openssl: MEDIUM
    '0xC0,0x12' => [qw( SSLv3   ECDH       RSA   3DES     168 SHA1   weak   )],
    '0xC0,0x13' => [qw( SSLv3   ECDH       RSA   AES      128 SHA1   HIGH   )],
    '0xC0,0x14' => [qw( SSLv3   ECDH       RSA   AES      256 SHA1   HIGH   )],
    '0xC0,0x15' => [qw( SSLv3   ECDH       None  None       0 SHA1   weak   )],
    '0xC0,0x16' => [qw( SSLv3   ECDH       None  RC4      128 SHA1   weak   )], # openssl: MEDIUM
    '0xC0,0x17' => [qw( SSLv3   ECDH       None  3DES     168 SHA1   weak   )],
    '0xC0,0x18' => [qw( SSLv3   ECDH       None  AES      128 SHA1   weak   )],
    '0xC0,0x19' => [qw( SSLv3   ECDH       None  AES      256 SHA1   weak   )],
    '0xC0,0x1A' => [qw( SSLv3   SRP        None  3DES     168 SHA1   weak   openssl-1.0.1c )], # openssl: HIGH
    '0xC0,0x1B' => [qw( SSLv3   SRP        RSA   3DES     168 SHA1   weak   openssl-1.0.1c )],
    '0xC0,0x1C' => [qw( SSLv3   SRP        DSS   3DES     168 SHA1   weak   openssl-1.0.1c )],
    '0xC0,0x1D' => [qw( SSLv3   SRP        None  AES      128 SHA1   HIGH   openssl-1.0.1c )], # openssl: HIGH
    '0xC0,0x1E' => [qw( SSLv3   SRP        RSA   AES      128 SHA1   HIGH   openssl-1.0.1c )],
    '0xC0,0x1F' => [qw( SSLv3   SRP        DSS   AES      128 SHA1   HIGH   openssl-1.0.1c )],
    '0xC0,0x20' => [qw( SSLv3   SRP        None  AES      256 SHA1   HIGH   openssl-1.0.1c )], # openssl: HIGH
    '0xC0,0x21' => [qw( SSLv3   SRP        RSA   AES      256 SHA1   HIGH   openssl-1.0.1c )],
    '0xC0,0x22' => [qw( SSLv3   SRP        DSS   AES      256 SHA1   HIGH   openssl-1.0.1c )],
    '0xC0,0x23' => [qw( TLSv12  ECDH       ECDSA AES      128 SHA256 HIGH   openssl-1.0.1c )],
    '0xC0,0x24' => [qw( TLSv12  ECDH       ECDSA AES      256 SHA384 HIGH   openssl-1.0.1c )],
    '0xC0,0x25' => [qw( TLSv12  ECDH/ECDSA ECDH  AES      128 SHA256 HIGH   openssl-1.0.1c )],
    '0xC0,0x26' => [qw( TLSv12  ECDH/ECDSA ECDH  AES      256 SHA384 HIGH   openssl-1.0.1c )],
    '0xC0,0x27' => [qw( TLSv12  ECDH       RSA   AES      128 SHA256 HIGH   openssl-1.0.1c )],
    '0xC0,0x28' => [qw( TLSv12  ECDH       RSA   AES      256 SHA384 HIGH   openssl-1.0.1c )],
    '0xC0,0x29' => [qw( TLSv12  ECDH/RSA   ECDH  AES      128 SHA256 HIGH   openssl-1.0.1c )],
    '0xC0,0x2A' => [qw( TLSv12  ECDH/RSA   ECDH  AES      256 SHA384 HIGH   openssl-1.0.1c )],
    '0xC0,0x2B' => [qw( TLSv12  ECDH       ECDSA AESGCM   128 AEAD   HIGH   openssl-1.0.1c )],
    '0xC0,0x2C' => [qw( TLSv12  ECDH       ECDSA AESGCM   256 AEAD   HIGH   openssl-1.0.1c )],
    '0xC0,0x2D' => [qw( TLSv12  ECDH/ECDSA ECDH  AESGCM   128 AEAD   HIGH   openssl-1.0.1c )],
    '0xC0,0x2E' => [qw( TLSv12  ECDH/ECDSA ECDH  AESGCM   256 AEAD   HIGH   openssl-1.0.1c )],
    '0xC0,0x2F' => [qw( TLSv12  ECDH       RSA   AESGCM   128 AEAD   HIGH   openssl-1.0.1c )],
    '0xC0,0x30' => [qw( TLSv12  ECDH       RSA   AESGCM   256 AEAD   HIGH   openssl-1.0.1c )],
    '0xC0,0x31' => [qw( TLSv12  ECDH/RSA   ECDH  AESGCM   128 AEAD   HIGH   openssl-1.0.1c )],
    '0xC0,0x32' => [qw( TLSv12  ECDH/RSA   ECDH  AESGCM   256 AEAD   HIGH   openssl-1.0.1c )],
    '0xC0,0x33' => [qw( TLSv12  ECDHE      PSK   RC4      128 SHA    weak   )],
    '0xC0,0x34' => [qw( TLSv12  ECDHE      PSK   3DES     192 SHA    weak   )],
    '0xC0,0x35' => [qw( TLSv12  ECDHE      PSK   AES      128 SHA    high   )],
    '0xC0,0x36' => [qw( TLSv12  ECDHE      PSK   AES      256 SHA    high   )],
    '0xC0,0x37' => [qw( TLSv12  ECDHE      PSK   AES      128 SHA256 high   )],
    '0xC0,0x38' => [qw( TLSv12  ECDHE      PSK   AES      256 SHA384 high   )],
    '0xC0,0x39' => [qw( TLSv12  ECDHE      PSK   None       0 SHA    weak   )],
    '0xC0,0x3A' => [qw( TLSv12  ECDHE      PSK   None       0 SHA256 weak   )],
    '0xC0,0x3B' => [qw( TLSv12  ECDHE      PSK   None       0 SHA384 weak   )],
    '0xC0,0x3C' => [qw( TLSv12  RSA        RSA   ARIA     128 SHA256 -?-    )],
    '0xC0,0x3D' => [qw( TLSv12  RSA        RSA   ARIA     256 SHA384 -?-    )],
    '0xC0,0x3E' => [qw( TLSv12  DH         DSS   ARIA     128 SHA256 -?-    )],
    '0xC0,0x3F' => [qw( TLSv12  DH         DSS   ARIA     256 SHA384 -?-    )],
    '0xC0,0x40' => [qw( TLSv12  DH         RSA   ARIA     128 SHA256 -?-    )],
    '0xC0,0x41' => [qw( TLSv12  DH         RSA   ARIA     256 SHA384 -?-    )],
    '0xC0,0x42' => [qw( TLSv12  DHE        DSS   ARIA     128 SHA256 -?-    )], # unklar
    '0xC0,0x43' => [qw( TLSv12  DHE        DSS   ARIA     256 SHA384 -?-    )], # unklar
    '0xC0,0x44' => [qw( TLSv12  DHE        RSA   ARIA     128 SHA256 -?-    )], # unklar
    '0xC0,0x45' => [qw( TLSv12  DHE        RSA   ARIA     256 SHA384 -?-    )], # unklar
    '0xC0,0x46' => [qw( TLSv12  DH         None  ARIA     128 SHA256 -?-    )], # unklar
    '0xC0,0x47' => [qw( TLSv12  DH         None  ARIA     256 SHA384 -?-    )], # unklar
    '0xC0,0x48' => [qw( TLSv12  ECDHE      ECDSA ARIA     128 SHA256 -?-    )],
    '0xC0,0x49' => [qw( TLSv12  ECDHE      ECDSA ARIA     256 SHA384 -?-    )],
    '0xC0,0x4A' => [qw( TLSv12  ECDH       ECDSA ARIA     128 SHA256 -?-    )],
    '0xC0,0x4B' => [qw( TLSv12  ECDH       ECDSA ARIA     256 SHA384 -?-    )],
    '0xC0,0x4C' => [qw( TLSv12  ECDHE      RSA   ARIA     128 SHA256 -?-    )],
    '0xC0,0x4D' => [qw( TLSv12  ECDHE      RSA   ARIA     256 SHA384 -?-    )],
    '0xC0,0x4E' => [qw( TLSv12  ECDH       RSA   ARIA     128 SHA256 -?-    )],
    '0xC0,0x4F' => [qw( TLSv12  ECDH       RSA   ARIA     256 SHA384 -?-    )],
    '0xC0,0x50' => [qw( TLSv12  RSA        RSA   ARIAGCM  128 SHA256 -?-    )],
    '0xC0,0x51' => [qw( TLSv12  RSA        RSA   ARIAGCM  256 SHA384 -?-    )],
    '0xC0,0x52' => [qw( TLSv12  DHE        RSA   ARIAGCM  128 SHA256 -?-    )], # unklar
    '0xC0,0x53' => [qw( TLSv12  DHE        RSA   ARIAGCM  256 SHA384 -?-    )], # unklar
    '0xC0,0x54' => [qw( TLSv12  DH         RSA   ARIAGCM  128 SHA256 -?-    )],
    '0xC0,0x55' => [qw( TLSv12  DH         RSA   ARIAGCM  256 SHA384 -?-    )],
    '0xC0,0x56' => [qw( TLSv12  DHE        DSS   ARIAGCM  128 SHA256 -?-    )], # unklar
    '0xC0,0x57' => [qw( TLSv12  DHE        DSS   ARIAGCM  256 SHA384 -?-    )], # unklar
    '0xC0,0x58' => [qw( TLSv12  DH         DSS   ARIAGCM  128 SHA256 -?-    )],
    '0xC0,0x59' => [qw( TLSv12  DH         DSS   ARIAGCM  256 SHA384 -?-    )],
    '0xC0,0x5A' => [qw( TLSv12  DH         None  ARIAGCM  128 SHA256 -?-    )],
    '0xC0,0x5B' => [qw( TLSv12  DH         None  ARIAGCM  256 SHA384 -?-    )],
    '0xC0,0x5C' => [qw( TLSv12  ECDHE      ECDSA ARIAGCM  128 SHA256 -?-    )],
    '0xC0,0x5D' => [qw( TLSv12  ECDHE      ECDSA ARIAGCM  256 SHA384 -?-    )],
    '0xC0,0x5E' => [qw( TLSv12  ECDH       ECDSA ARIAGCM  128 SHA256 -?-    )],
    '0xC0,0x5F' => [qw( TLSv12  ECDH       ECDSA ARIAGCM  256 SHA384 -?-    )],
    '0xC0,0x60' => [qw( TLSv12  ECDHE      RSA   ARIAGCM  128 SHA256 -?-    )],
    '0xC0,0x61' => [qw( TLSv12  ECDHE      RSA   ARIAGCM  256 SHA384 -?-    )],
    '0xC0,0x62' => [qw( TLSv12  ECDH       RSA   ARIAGCM  128 SHA256 -?-    )],
    '0xC0,0x63' => [qw( TLSv12  ECDH       RSA   ARIAGCM  256 SHA384 -?-    )],
    '0xC0,0x64' => [qw( TLSv12  PSK        PSK   ARIA     128 SHA256 -?-    )],
    '0xC0,0x65' => [qw( TLSv12  PSK        PSK   ARIA     256 SHA384 -?-    )],
    '0xC0,0x66' => [qw( TLSv12  DHE        PSK   ARIA     128 SHA256 -?-    )], # unklar
    '0xC0,0x67' => [qw( TLSv12  DHE        PSK   ARIA     256 SHA384 -?-    )], # unklar
    '0xC0,0x68' => [qw( TLSv12  RSA        PSK   ARIA     128 SHA256 -?-    )],
    '0xC0,0x69' => [qw( TLSv12  RSA        PSK   ARIA     256 SHA384 -?-    )],
    '0xC0,0x6A' => [qw( TLSv12  PSK        PSK   ARIAGCM  128 SHA256 -?-    )],
    '0xC0,0x6B' => [qw( TLSv12  PSK        PSK   ARIAGCM  256 SHA384 -?-    )],
    '0xC0,0x6C' => [qw( TLSv12  DHE        PSK   ARIAGCM  128 SHA256 -?-    )], # unklar
    '0xC0,0x6D' => [qw( TLSv12  DHE        PSK   ARIAGCM  256 SHA384 -?-    )], # unklar
    '0xC0,0x6E' => [qw( TLSv12  RSA        PSK   ARIAGCM  128 SHA256 -?-    )],
    '0xC0,0x6F' => [qw( TLSv12  RSA        PSK   ARIAGCM  256 SHA384 -?-    )],
    '0xC0,0x70' => [qw( TLSv12  ECDHE      PSK   ARIA     128 SHA256 -?-    )],
    '0xC0,0x71' => [qw( TLSv12  ECDHE      PSK   ARIA     256 SHA384 -?-    )],
    '0xC0,0x72' => [qw( TLSv12  ECDH       ECDSA CAMELLIA 128 SHA256 HIGH   openssl-1.0.2d )],
    '0xC0,0x73' => [qw( TLSv12  ECDH       ECDSA CAMELLIA 256 SHA384 HIGH   openssl-1.0.2d )],
    '0xC0,0x74' => [qw( TLSv12  ECDH/ECDSA ECDH  CAMELLIA 128 SHA256 HIGH   openssl-1.0.2d )],
    '0xC0,0x75' => [qw( TLSv12  ECDH/ECDSA ECDH  CAMELLIA 256 SHA384 HIGH   openssl-1.0.2d )],
    '0xC0,0x76' => [qw( TLSv12  ECDH       RSA   CAMELLIA 128 SHA256 HIGH   openssl-1.0.2d )],
    '0xC0,0x77' => [qw( TLSv12  ECDH       RSA   CAMELLIA 256 SHA384 HIGH   openssl-1.0.2d )],
    '0xC0,0x78' => [qw( TLSv12  ECDH/RSA   ECDH  CAMELLIA 128 SHA256 HIGH   openssl-1.0.2d )],
    '0xC0,0x79' => [qw( TLSv12  ECDH/RSA   ECDH  CAMELLIA 256 SHA384 HIGH   openssl-1.0.2d )],
    '0xC0,0x7A' => [qw( TLSv12  RSA        RSA   CAMELLIAGCM 128 SHA256 high )], # unklar
    '0xC0,0x7B' => [qw( TLSv12  RSA        RSA   CAMELLIAGCM 256 SHA384 high )], # -"-
    '0xC0,0x7C' => [qw( TLSv12  DHE        RSA   CAMELLIAGCM 128 SHA256 high )], # -"-
    '0xC0,0x7D' => [qw( TLSv12  DHE        RSA   CAMELLIAGCM 256 SHA384 high )],
    '0xC0,0x7E' => [qw( TLSv12  DH         RSA   CAMELLIAGCM 128 SHA256 high )],
    '0xC0,0x7F' => [qw( TLSv12  DH         RSA   CAMELLIAGCM 256 SHA384 high )],
    '0xC0,0x80' => [qw( TLSv12  DHE        DSS   CAMELLIAGCM 128 SHA256 high )],
    '0xC0,0x81' => [qw( TLSv12  DHE        DSS   CAMELLIAGCM 256 SHA384 high )],
    '0xC0,0x82' => [qw( TLSv12  DH         DSS   CAMELLIAGCM 128 SHA256 high )],
    '0xC0,0x83' => [qw( TLSv12  DH         DSS   CAMELLIAGCM 256 SHA384 high )],
    '0xC0,0x84' => [qw( TLSv12  ADH        DSS   CAMELLIAGCM 128 SHA256 high )],
    '0xC0,0x85' => [qw( TLSv12  ADH        DSS   CAMELLIAGCM 256 SHA384 high )],
    '0xC0,0x86' => [qw( TLSv12  ECDHE      ECDSA CAMELLIAGCM 128 SHA256 high )],
    '0xC0,0x87' => [qw( TLSv12  ECDHE      ECDSA CAMELLIAGCM 256 SHA384 high )],
    '0xC0,0x88' => [qw( TLSv12  ECDH       ECDSA CAMELLIAGCM 128 SHA256 high )],
    '0xC0,0x89' => [qw( TLSv12  ECDH       ECDSA CAMELLIAGCM 256 SHA384 high )],
    '0xC0,0x8A' => [qw( TLSv12  ECDHE      RSA   CAMELLIAGCM 128 SHA256 high )],
    '0xC0,0x8B' => [qw( TLSv12  ECDHE      RSA   CAMELLIAGCM 256 SHA384 high )],
    '0xC0,0x8C' => [qw( TLSv12  ECDH       RSA   CAMELLIAGCM 128 SHA256 high )],
    '0xC0,0x8D' => [qw( TLSv12  ECDH       RSA   CAMELLIAGCM 256 SHA384 high )],
    '0xC0,0x8E' => [qw( TLSv12  RSA        PSK   CAMELLIAGCM 128 SHA256 high )],
    '0xC0,0x8F' => [qw( TLSv12  RSA        PSK   CAMELLIAGCM 256 SHA38  high )],
    '0xC0,0x90' => [qw( TLSv12  DHE        PSK   CAMELLIAGCM 128 SHA25  high )],
    '0xC0,0x91' => [qw( TLSv12  DHE        PSK   CAMELLIAGCM 256 SHA38  high )],
    '0xC0,0x92' => [qw( TLSv12  RSA        PSK   CAMELLIAGCM 128 SHA256 high )],
    '0xC0,0x93' => [qw( TLSv12  RSA        PSK   CAMELLIAGCM 256 SHA384 high )],
    '0xC0,0x94' => [qw( TLSv12  PSK        PSK   CAMELLIA 128 SHA256 high   )],
    '0xC0,0x95' => [qw( TLSv12  PSK        PSK   CAMELLIA 256 SHA384 high   )],
    '0xC0,0x96' => [qw( TLSv12  DHE        PSK   CAMELLIA 128 SHA256 high   )],
    '0xC0,0x97' => [qw( TLSv12  DHE        PSK   CAMELLIA 256 SHA38  high   )],
    '0xC0,0x98' => [qw( TLSv12  RSA        PSK   CAMELLIA 128 SHA25  high   )],
    '0xC0,0x99' => [qw( TLSv12  RSA        PSK   CAMELLIA 256 SHA38  high   )],
    '0xC0,0x9A' => [qw( TLSv12  ECDHE      PSK   CAMELLIA 128 SHA256 high   )],
    '0xC0,0x9B' => [qw( TLSv12  ECDHE      PSK   CAMELLIA 256 SHA384 high   )], # -"-
    '0xC0,0x9C' => [qw( TLSv12  RSA        RSA   AESCCM   128 AEAD   high   )],
    '0xC0,0x9D' => [qw( TLSv12  RSA        RSA   AESCCM   256 AEAD   high   )],
    '0xC0,0x9E' => [qw( TLSv12  DH         RSA   AESCCM   128 AEAD   high   )],
    '0xC0,0x9F' => [qw( TLSv12  DH         RSA   AESCCM   256 AEAD   high   )],
    '0xC0,0xA0' => [qw( TLSv12  RSA        RSA   AESCCM   128 AEAD   high   )],
    '0xC0,0xA1' => [qw( TLSv12  RSA        RSA   AESCCM   256 AEAD   high   )],
    '0xC0,0xA2' => [qw( TLSv12  DH         RSA   AESCCM   128 AEAD   high   )],
    '0xC0,0xA3' => [qw( TLSv12  DH         RSA   AESCCM   256 AEAD   high   )],
    '0xC0,0xA4' => [qw( TLSv12  PSK        PSK   AESCCM   128 AEAD   high   )],
    '0xC0,0xA5' => [qw( TLSv12  PSK        PSK   AESCCM   256 AEAD   high   )],
    '0xC0,0xA6' => [qw( TLSv12  DHE        RSA   AESCCM   128 AEAD   high   )],
    '0xC0,0xA7' => [qw( TLSv12  DHE        RSA   AESCCM   256 AEAD   high   )],
    '0xC0,0xA8' => [qw( TLSv12  PSK        PSK   AESCCM   128 AEAD   high   )],
    '0xC0,0xA9' => [qw( TLSv12  PSK        PSK   AESCCM   256 AEAD   high   )],
    '0xC0,0xAA' => [qw( TLSv12  DHE        RSA   AESCCM   128 AEAD   high   )],
    '0xC0,0xAB' => [qw( TLSv12  DHE        RSA   AESCCM   256 AEAD   high   )],
    '0xC0,0xAC' => [qw( TLSv12  ECDH       ECDSA AESCCM   128 AEAD   high   )],
    '0xC0,0xAD' => [qw( TLSv12  ECDH       ECDSA AESCCM   256 AEAD   high   )],
    '0xC0,0xAE' => [qw( TLSv12  ECDH       ECDSA AESCCM   128 AEAD   high   )], # unklar
    '0xC0,0xAF' => [qw( TLSv12  ECDH       ECDSA AESCCM   256 AEAD   high   )], # unklar
    # from: http://botan.randombit.net/doxygen/tls__suite__info_8cpp_source.html
    #/ RSA_WITH_AES_128_CCM           (0xC09C, "RSA",   "RSA",  "AES-128/CCM",   16, 4, "AEAD", 0, "SHA-256");
    #/ RSA_WITH_AES_256_CCM           (0xC09D, "RSA",   "RSA",  "AES-256/CCM",   32, 4, "AEAD", 0, "SHA-256");
    #/ DHE_RSA_WITH_AES_128_CCM       (0xC09E, "RSA",   "DH",   "AES-128/CCM",   16, 4, "AEAD", 0, "SHA-256");
    #/ DHE_RSA_WITH_AES_256_CCM       (0xC09F, "RSA",   "DH",   "AES-256/CCM",   32, 4, "AEAD", 0, "SHA-256");
    #/ PSK_WITH_AES_128_CCM           (0xC0A5, "",      "PSK",  "AES-256/CCM",   32, 4, "AEAD", 0, "SHA-256");
    #/ PSK_WITH_AES_256_CCM           (0xC0A4, "",      "PSK",  "AES-128/CCM",   16, 4, "AEAD", 0, "SHA-256");
    #/ ECDHE_ECDSA_WITH_AES_128_CCM   (0xC0AC, "ECDSA", "ECDH", "AES-128/CCM",   16, 4, "AEAD", 0, "SHA-256");
    #/ ECDHE_ECDSA_WITH_AES_256_CCM   (0xC0AD, "ECDSA", "ECDH", "AES-256/CCM",   32, 4, "AEAD", 0, "SHA-256");
    #/ RSA_WITH_AES_128_CCM_8         (0xC0A0, "RSA",   "RSA",  "AES-128/CCM-8", 16, 4, "AEAD", 0, "SHA-256");
    #/ RSA_WITH_AES_256_CCM_8         (0xC0A1, "RSA",   "RSA",  "AES-256/CCM-8", 32, 4, "AEAD", 0, "SHA-256");
    #/ DHE_RSA_WITH_AES_128_CCM_8     (0xC0A2, "RSA",   "DH",   "AES-128/CCM-8", 16, 4, "AEAD", 0, "SHA-256");
    #/ DHE_RSA_WITH_AES_256_CCM_8     (0xC0A3, "RSA",   "DH",   "AES-256/CCM-8", 32, 4, "AEAD", 0, "SHA-256");
    #/ PSK_WITH_AES_128_CCM_8         (0xC0A8, "",      "PSK",  "AES-128/CCM-8", 16, 4, "AEAD", 0, "SHA-256");
    #/ PSK_WITH_AES_256_CCM_8         (0xC0A9, "",      "PSK",  "AES-256/CCM-8", 32, 4, "AEAD", 0, "SHA-256");
    #/ ECDHE_ECDSA_WITH_AES_128_CCM_8 (0xC0AE, "ECDSA", "ECDH", "AES-128/CCM-8", 16, 4, "AEAD", 0, "SHA-256");
    #/ ECDHE_ECDSA_WITH_AES_256_CCM_8 (0xC0AF, "ECDSA", "ECDH", "AES-256/CCM-8", 32, 4, "AEAD", 0, "SHA-256");
    '0xCC,0x13' => [qw( TLSv12  ECDH       RSA   ChaCha20-Poly1305 256 AEAD HIGH old:openssl-1.0.2d:new_0xCC:0xA8 )], # old
    '0xCC,0x14' => [qw( TLSv12  ECDH       ECDSA ChaCha20-Poly1305 256 AEAD HIGH old:openssl-1.0.2d:new_0xCC:0xA9 )], # old
    '0xCC,0x15' => [qw( TLSv12  DH         RSA   ChaCha20-Poly1305 256 AEAD HIGH old:openssl-1.0.2d:new_0xCC:0xAA )], # old
    # NOTE: 0xCC,0x13 and 0xCC,0x14 and 0xCC,0x15 also in:
    #       tools.ietf.org/html/draft-agl-tls-chacha20poly1305-04
    #       https://community.qualys.com/thread/12169
    # NOTE: ChaCha20-Poly1305 aka CHACHA20/POLY1305
    #!#----------------+-------+----------+-----+-------+----+------+------+------,

    # from http://tools.ietf.org/html/draft-mavrogiannopoulos-chacha-tls-01
    '0xCC,0x20' => [qw( TLSv12  RSA        RSA   ChaCha20 256 SHA1   HIGH )],
    '0xCC,0x21' => [qw( TLSv12  ECDH       RSA   ChaCha20 256 SHA1   HIGH )],
    '0xCC,0x22' => [qw( TLSv12  ECDH       RSA   ChaCha20 256 SHA1   HIGH )],
    '0xCC,0x23' => [qw( TLSv12  DH         RSA   ChaCha20 256 SHA1   HIGH )],
    '0xCC,0x24' => [qw( TLSv12  DH         PSK   ChaCha20 256 SHA1   HIGH )],
    '0xCC,0x25' => [qw( TLSv12  PSK        PSK   ChaCha20 256 SHA1   HIGH )],
    '0xCC,0x26' => [qw( TLSv12  ECDH       RSA   ChaCha20 256 SHA1   HIGH )],
    '0xCC,0x27' => [qw( TLSv12  RSAPSK     RSA   ChaCha20 256 SHA1   HIGH )],

    # from # http://tools.ietf.org/html/draft-mavrogiannopoulos-chacha-tls-05
    '0xCC,0xA1' => [qw( TLSv12  ECDH       RSA   ChaCha20-Poly1305 256 AEAD HIGH openssl-1.0.2 )], # unklar
    '0xCC,0xA2' => [qw( TLSv12  ECDH       ECDSA ChaCha20-Poly1305 256 AEAD HIGH openssl-1.0.2 )], # unklar
    '0xCC,0xA3' => [qw( TLSv12  DH         RSA   ChaCha20-Poly1305 256 AEAD HIGH )], # unklar
    '0xCC,0xA4' => [qw( TLSv12  DH         PSK   ChaCha20-Poly1305 256 AEAD HIGH )], # unklar
    '0xCC,0xA5' => [qw( TLSv12  PSK        PSK   ChaCha20-Poly1305 256 AEAD HIGH )], # unklar
    '0xCC,0xA6' => [qw( TLSv12  ECDHEPSK   ECDHE ChaCha20-Poly1305 256 AEAD HIGH )], # unklar
    '0xCC,0xA7' => [qw( TLSv12  DH         RSA   ChaCha20-Poly1305 256 AEAD HIGH )], # unklar

    # from https://tools.ietf.org/html/draft-ietf-tls-chacha20-poly1305-04 (16. Dec 2015)
    #!#----------------+-------+----------+-----+-------+----+------+------+------,
    '0xCC,0xA8' => [qw( TLSv12  ECDH       RSA   ChaCha20-Poly1305 256 AEAD HIGH older:0xCC:0x13 )],
    '0xCC,0xA9' => [qw( TLSv12  ECDH       ECDSA ChaCha20-Poly1305 256 AEAD HIGH older:0xCC:0x14 )],
    '0xCC,0xAA' => [qw( TLSv12  DH         RSA   ChaCha20-Poly1305 256 AEAD HIGH older:0xCC:0x15 )],
    '0xCC,0xAB' => [qw( TLSv12  PSK        PSK   ChaCha20-Poly1305 256 AEAD HIGH )],
    '0xCC,0xAC' => [qw( TLSv12  ECDHEPSK   ECDHE ChaCha20-Poly1305 256 AEAD HIGH )],
    '0xCC,0xAD' => [qw( TLSv12  DHEPSK     DHE   ChaCha20-Poly1305 256 AEAD HIGH )],
    '0xCC,0xAE' => [qw( TLSv12  RSAPSK     RSA   ChaCha20-Poly1305 256 AEAD HIGH )],

    # FIXME: all following
    #!#----------------+-------+----------+-----+-------+----+------+------+------,
    #!# key     => [qw( ssl     keyx       auth  enc     bits mac    sec    tags)],
    #!#----------------+-------+----------+-----+-------+----+------+------+------,
    '0x00,0x90' => [qw( TLSv12  DHE        PSK   AES      128 SHA1   -?-    )],
    '0x00,0x91' => [qw( TLSv12  DHE        PSK   AES      256 SHA1   -?-    )],
    '0x00,0x0B' => [qw( SSLv3   DH(512)    DSS   DES       40 SHA1   weak   export )], # unklar
    '0x00,0x0C' => [qw( SSLv3   DH(512)    DSS   DES       64 SHA1   weak   )], # unklar
#   '0x00,0x0C' => [qw( SSLv3   DH         DSS   DES       56 SHA1   weak   )], # unklar ??
#   '0x00,0x0C' => [qw( SSLv3   DH/DSS     DH    DES       56 SHA1   weak   openssl-1.0.2.d )], # unklar ??
    '0x00,0x0D' => [qw( SSLv3   DH(512)    DSS   3DES      64 SHA1   weak   )], # unklar
#   '0x00,0x0D' => [qw( SSLv3   DH         DSS   3DES     168 SHA1   weak   )], # unklar ??
    '0x00,0x0E' => [qw( SSLv3   DH(512)    RSA   DES       40 SHA1   weak   export )], # unklar
    '0x00,0x0F' => [qw( SSLv3   DH(512)    RSA   DES       64 SHA1   weak   )], # unklar
#   '0x00,0x0F' => [qw( SSLv3   DH         RSA   DES       56 SHA1   weak   )], # unklar ??
#   '0x00,0x0F' => [qw( SSLv3   DH/RSA     DH    DES       56 SHA1   weak   openssl-1.0.2.d )], # unklar ??
    '0x00,0x2C' => [qw( SSLv3   DH         PSK   None       0 SHA1   weak   )],
    '0x00,0x2D' => [qw( TLSv12  DHE        PSK   None       0 SHA1   weak   )],
    '0x00,0x2E' => [qw( TLSv12  RSA        PSK   None       0 SHA1   weak   )],
    '0x00,0x8E' => [qw( TLSv12  DHE        PSK   RC4      128 SHA1   medium )],
    '0x00,0x8F' => [qw( TLSv12  DHE        PSK   3DES     168 SHA1   weak   )],
    '0x00,0xA0' => [qw( TLSv12  DH         RSA   AESGCM   128 AEAD   high   )], # unklar
    '0x00,0xA1' => [qw( TLSv12  DH         RSA   AESGCM   256 AEAD   high   )], # unklar
    '0x00,0xA2' => [qw( TLSv12  DH         DSS   AESGCM   128 AEAD   HIGH   openssl-1.0.1c )], # unklar
    '0x00,0xA3' => [qw( TLSv12  DH         DSS   AESGCM   256 AEAD   HIGH   openssl-1.0.1c )], # unklar
    '0x00,0xA4' => [qw( TLSv12  DH         DSS   AESGCM   128 AEAD   high   )], # unklar
    '0x00,0xA5' => [qw( TLSv12  DH         DSS   AESGCM   256 AEAD   high   )], # unklar
    '0x00,0xA6' => [qw( TLSv12  DH         None  AESGCM   128 AEAD   weak   openssl-1.0.1c )], # openssl: HIGH # unklar
    '0x00,0xA7' => [qw( TLSv12  DH         None  AESGCM   256 AEAD   weak   openssl-1.0.1c )], # openssl: HIGH # unklar
    '0x00,0xA8' => [qw( TLSv12  PSK        PSK   AESGCM   128 AEAD   -?-    openssl-1.0.1c )], # ubklar
    '0x00,0xA9' => [qw( TLSv12  PSK        PSK   AESGCM   256 AEAD   -?-    openssl-1.0.1c )], # ubklar
    '0x00,0xAA' => [qw( TLSv12  DHE        PSK   AESGCM   128 SHA256 -?-    )],
    '0x00,0xAB' => [qw( TLSv12  DHE        PSK   AESGCM   256 SHA384 -?-    )],
    '0x00,0xAC' => [qw( TLSv12  RSA        PSK   AESGCM   128 SHA256 -?-    )],
    '0x00,0xAD' => [qw( TLSv12  RSA        PSK   AESGCM   256 SHA384 -?-    )],
    '0x00,0xAE' => [qw( TLSv12  RSA        PSK   AES      128 SHA256 -?-    )],
    '0x00,0xAF' => [qw( TLSv12  RSA        PSK   AES      256 SHA384 -?-    )],

    # from ssl/s3_lib.c
    '0xFE,0xE0' => [qw( SSLv3  RSA_FIPS    RSA_FIPS  3DES 168 SHA1   weak   openssl-1.0.1g )], # unklar
    '0xFE,0xE1' => [qw( SSLv3  RSA_FIPS    RSA_FIPS  DES   56 SHA1   weak   openssl-1.0.1g )], # unklar
    '0xFE,0xFE' => [qw( SSLv3  RSA_FIPS    RSA_FIPS  DES   56 SHA1   weak   openssl-1.0.1g )], # unklar
    '0xFE,0xFF' => [qw( SSLv3  RSA_FIPS    RSA_FIPS  3DES 168 SHA1   weak   openssl-1.0.1g )], # unklar

    # following found somewhere, but not identified
    'osaft-001' => [qw( SSLv3  RSA         DSS   RC4       64 MD5    weak   EXP-RC4-64-MD5_(from_RSA_BSAFE_SSL-C) )], # unklar
    'osaft-002' => [qw( SSLv3  DHE         DSS   RC4       56 SHA    WEAK   EXP-EDH-DSS-RC4-56-SHA_(from_RSA_BSAFE_SSL-C):)], # unklar

    # from: https://www.bro.org/sphinx/_downloads/consts10.bro (but uses SSL_ prefix)
    '0xFF,0x80' => [qw( SSLv3   RSA(512)   RSA   RC2       40 MD5    WEAK   )], # see 0x00,0x06
    '0xFF,0x81' => [qw( SSLv2   RSA        RSA   IDEA     128 SHA1   weak   )], # see 0x00,0x07
    '0xFF,0x82' => [qw( SSLv3   RSA(512)   RSA   DES       40 SHA1   weak   )], # see 0x00,0x08
    '0xFF,0x83' => [qw( SSLv3   RSA        RSA   DES       56 SHA1   weak   )], # see 0x00,0x09

    # from: https://chromium.googlesource.com/chromium/src/net/+/master/ssl/ssl_cipher_suite_names_unittest.cc
    '0x16,0xB7' => [qw( TLSv12  CECPQ1     RSA   ChaCha20-Poly1305 256 SHA256 high  )],
    '0x16,0xB8' => [qw( TLSv12  CECPQ1     ECDSA ChaCha20-POLY1305 256 SHA256 high  )],
    '0x16,0xB9' => [qw( TLSv12  CECPQ1     RSA   AESGCM   256 SHA384  high  )],
    '0x16,0xBA' => [qw( TLSv12  CECPQ1     ECDSA AESGCM   256 SHA384  high  )],

    # dummies to keep some checks quiet, values are not used
    '0x00,0xFF' => [qw( TLSv12  -?-        -?-   -?-        0 -?-    -?     )],
    '0x56,0x00' => [qw( TLSv12  -?-        -?-   -?-        0 -?-    -?     )],
    #!#----------------+-------+----------+-----+-------+----+------+------+------,

); # %_ciphers_osaft

our %_ciphers_names = (
    #
    #!#----------+-------------------------------------+--------------------------+
    #!# key     => [qw( SSLv2 cipher suite name         cipher suite value (SSL_CK_ prefix missing))],
    #!#----------+-------------------------------------+--------------------------+
'0x00,0x00,0x00' => [qw( NULL-MD5                       NULL_WITH_MD5               )],
'0x01,0x00,0x80' => [qw( RC4-MD5                        RC4_128_WITH_MD5            )],
'0x02,0x00,0x80' => [qw( EXP-RC4-MD5                    RC4_128_EXPORT40_WITH_MD5   )],
'0x03,0x00,0x80' => [qw( RC2-CBC-MD5                    RC2_128_CBC_WITH_MD5        )],
'0x04,0x00,0x80' => [qw( EXP-RC2-CBC-MD5                RC2_128_CBC_EXPORT40_WITH_MD5 )],
'0x05,0x00,0x80' => [qw( IDEA-CBC-MD5                   IDEA_128_CBC_WITH_MD5       )],
'0x06,0x00,0x40' => [qw( DES-CBC-MD5                    DES_64_CBC_WITH_MD5         )],
'0x06,0x01,0x40' => [qw( DES-CBC-SHA                    DES_64_CBC_WITH_SHA         )],
'0x07,0x00,0xC0' => [qw( DES-CBC3-MD5                   DES_192_EDE3_CBC_WITH_MD5   )],
'0x07,0x01,0xC0' => [qw( DES-CBC3-SHA                   DES_192_EDE3_CBC_WITH_SHA   )],
'0x08,0x00,0x80' => [qw( RC4-64-MD5                     RC4_64_WITH_MD5             )],
'0xFF,0x08,0x00' => [qw( DES-CFB-M1                     DES_64_CFB64_WITH_MD5_1     )],
'0xFF,0x08,0x10' => [qw( NULL                           NULL                        )],
'0x80,0x00,0x01' => [qw( PCT_SSL_CERT_TYPE              PCT1_CERT_X509              )],
'0x80,0x00,0x03' => [qw( PCT_SSL_CERT_TYPE              PCT1_CERT_X509_CHAIN        )],
'0x81,0x00,0x01' => [qw( PCT_SSL_HASH_TYPE              PCT1_HASH_MD5               )],
'0x81,0x00,0x03' => [qw( PCT_SSL_HASH_TYPE              PCT1_HASH_SHA               )],
'0x82,0x00,0x03' => [qw( PCT_SSL_EXCH_TYPE              PCT1_EXCH_RSA_PKCS1         )],
'0x82,0x30,0x04' => [qw( PCT_SSL_CIPHER_TYPE_1ST_HALF   PCT1_CIPHER_RC4             )],
'0x84,0x28,0x40' => [qw( PCT_SSL_CIPHER_TYPE_2ND_HALF   PCT1_ENC_BITS_40|PCT1_MAC_BITS_128  )],
'0x84,0x80,0x40' => [qw( PCT_SSL_CIPHER_TYPE_2ND_HALF   PCT1_ENC_BITS_128|PCT1_MAC_BITS_128 )],
'0x8F,0x80,0x01' => [qw( PCT_SSL_COMPAT                 PCT_VERSION_1               )],

    #!#----------+-------------------------------------+--------------------------+
    #!# key     => [qw( SSLv3/TLS cipher suite name     cipher suite value (TLS_ prefix missing) )],
    #!#----------+-------------------------------------+--------------------------+
    '0x00,0x00' => [qw( NULL-NULL                       NULL_WITH_MD5           )], # O-Saft dummy
    '0x00,0x01' => [qw( NULL-MD5                        RSA_NULL_MD5            )],
    '0x00,0x02' => [qw( NULL-SHA                        RSA_NULL_SHA            )],
    '0x00,0x03' => [qw( EXP-RC4-MD5                     RSA_RC4_40_MD5          )],
    '0x00,0x04' => [qw( RC4-MD5                         RSA_RC4_128_MD5         )],
    '0x00,0x05' => [qw( RC4-SHA                         RSA_RC4_128_SHA         )],
    '0x00,0x06' => [qw( EXP-RC2-CBC-MD5                 RSA_RC2_40_MD5          )],
    '0x00,0x07' => [qw( IDEA-CBC-SHA                    RSA_IDEA_128_SHA        )],
    '0x00,0x08' => [qw( EXP-DES-CBC-SHA                 RSA_DES_40_CBC_SHA      )],
    '0x00,0x09' => [qw( DES-CBC-SHA                     RSA_DES_64_CBC_SHA      )], # unklar, muesste RSA_DES_56_CBC_SHA sein
    '0x00,0x0A' => [qw( DES-CBC3-SHA                    RSA_DES_192_CBC3_SHA    )],
    '0x00,0x0B' => [qw( EXP-DH-DSS-DES-CBC-SHA          DH_DSS_DES_40_CBC_SHA   )],
    '0x00,0x0C' => [qw( DH-DSS-DES-CBC-SHA              DH_DSS_DES_64_CBC_SHA   )],
    '0x00,0x0D' => [qw( DH-DSS-DES-CBC3-SHA             DH_DSS_DES_192_CBC3_SHA )],
    '0x00,0x0E' => [qw( EXP-DH-RSA-DES-CBC-SHA          DH_RSA_DES_40_CBC_SHA   )],
    '0x00,0x0F' => [qw( DH-RSA-DES-CBC-SHA              DH_RSA_DES_64_CBC_SHA   )],
    '0x00,0x10' => [qw( DH-RSA-DES-CBC3-SHA             DH_RSA_DES_192_CBC3_SHA )],
    '0x00,0x11' => [qw( EXP-EDH-DSS-DES-CBC-SHA         EDH_DSS_DES_40_CBC_SHA  )],
    '0x00,0x12' => [qw( EDH-DSS-DES-CBC-SHA             EDH_DSS_DES_64_CBC_SHA  )],
    '0x00,0x13' => [qw( EDH-DSS-DES-CBC3-SHA            EDH_DSS_DES_192_CBC3_SHA )],
    '0x00,0x14' => [qw( EXP-EDH-RSA-DES-CBC-SHA         EDH_RSA_DES_40_CBC_SHA  )],
    '0x00,0x15' => [qw( EDH-RSA-DES-CBC-SHA             EDH_RSA_DES_64_CBC_SHA  )],
    '0x00,0x16' => [qw( EDH-RSA-DES-CBC3-SHA            EDH_RSA_DES_192_CBC3_SHA )],
    '0x00,0x17' => [qw( EXP-ADH-RC4-MD5                 ADH_RC4_40_MD5          )],
    '0x00,0x18' => [qw( ADH-RC4-MD5                     ADH_RC4_128_MD5         )],
    '0x00,0x19' => [qw( EXP-ADH-DES-CBC-SHA             ADH_DES_40_CBC_SHA      )],
    '0x00,0x1A' => [qw( ADH-DES-CBC-SHA                 ADH_DES_64_CBC_SHA      )],
    '0x00,0x1B' => [qw( ADH-DES-CBC3-SHA                ADH_DES_192_CBC_SHA     )],
    '0x00,0x1C' => [qw( FZA-NULL-SHA                    FZA_DMS_NULL_SHA        )],
    '0x00,0x1D' => [qw( FZA-FZA-SHA                     FZA_DMS_FZA_SHA         )],
    '0x00,0x1e' => [qw( FZA-RC4-SHA                     FZA_DMS_RC4_SHA         )],
    '0x00,0x1E' => [qw( KRB5-DES-CBC-SHA                KRB5_DES_64_CBC_SHA     )],
    '0x00,0x1F' => [qw( KRB5-DES-CBC3-SHA               KRB5_DES_192_CBC3_SHA   )],
    '0x00,0x20' => [qw( KRB5-RC4-SHA                    KRB5_RC4_128_SHA        )],
    '0x00,0x21' => [qw( KRB5-IDEA-CBC-SHA               KRB5_IDEA_128_CBC_SHA   )],
    '0x00,0x22' => [qw( KRB5-DES-CBC-MD5                KRB5_DES_64_CBC_MD5     )],
    '0x00,0x23' => [qw( KRB5-DES-CBC3-MD5               KRB5_DES_192_CBC3_MD5   )],
    '0x00,0x24' => [qw( KRB5-RC4-MD5                    KRB5_RC4_128_MD5        )],
    '0x00,0x25' => [qw( KRB5-IDEA-CBC-MD5               KRB5_IDEA_128_CBC_MD5   )],
    '0x00,0x26' => [qw( EXP-KRB5-DES-CBC-SHA            KRB5_DES_40_CBC_SHA     )],
    '0x00,0x27' => [qw( EXP-KRB5-RC2-CBC-SHA            KRB5_RC2_40_CBC_SHA     )],
    '0x00,0x28' => [qw( EXP-KRB5-RC4-SHA                KRB5_RC4_40_SHA         )],
    '0x00,0x29' => [qw( EXP-KRB5-DES-CBC-MD5            KRB5_DES_40_CBC_MD5     )],
    '0x00,0x2A' => [qw( EXP-KRB5-RC2-CBC-MD5            KRB5_RC2_40_CBC_MD5     )],
    '0x00,0x2B' => [qw( EXP-KRB5-RC4-MD5                KRB5_RC4_40_MD5         )],
    '0x00,0x2C' => [qw( PSK-SHA                         PSK_WITH_NULL_SHA       )],
    '0x00,0x2D' => [qw( DHE-PSK-SHA                     DHE_PSK_WITH_NULL_SHA   )],
    '0x00,0x2E' => [qw( RSA-PSK-SHA                     RSA_PSK_WITH_NULL_SHA   )],
    '0x00,0x2F' => [qw( AES128-SHA                      RSA_WITH_AES_128_SHA    )],
    '0x00,0x30' => [qw( DH-DSS-AES128-SHA               DH_DSS_WITH_AES_128_SHA )],
    '0x00,0x31' => [qw( DH-RSA-AES128-SHA               DH_RSA_WITH_AES_128_SHA )],
    '0x00,0x32' => [qw( DHE-DSS-AES128-SHA              DHE_DSS_WITH_AES_128_CBC_SHA    )],
    '0x00,0x33' => [qw( DHE-RSA-AES128-SHA              DHE_RSA_WITH_AES_128_CBC_SHA    )],
    '0x00,0x34' => [qw( ADH-AES128-SHA                  ADH_WITH_AES_128_SHA            )],
    '0x00,0x35' => [qw( AES256-SHA                      RSA_WITH_AES_256_SHA            )],
    '0x00,0x36' => [qw( DH-DSS-AES256-SHA               DH_DSS_WITH_AES_256_SHA         )],
    '0x00,0x37' => [qw( DH-RSA-AES256-SHA               DH_RSA_WITH_AES_256_SHA         )],
    '0x00,0x38' => [qw( DHE-DSS-AES256-SHA              DHE_DSS_WITH_AES_256_CBC_SHA    )],
    '0x00,0x39' => [qw( DHE-RSA-AES256-SHA              DHE_RSA_WITH_AES_256_CBC_SHA    )],
    '0x00,0x3A' => [qw( ADH-AES256-SHA                  ADH_WITH_AES_256_SHA            )],
    '0x00,0x3B' => [qw( NULL-SHA256                     RSA_WITH_NULL_SHA256            )],
    '0x00,0x3C' => [qw( AES128-SHA256                   RSA_WITH_AES_128_SHA256         )],
    '0x00,0x3D' => [qw( AES256-SHA256                   RSA_WITH_AES_256_SHA256         )],
    '0x00,0x3E' => [qw( DH-DSS-AES128-SHA256            DH_DSS_WITH_AES_128_SHA256      )],
    '0x00,0x3F' => [qw( DH-RSA-AES128-SHA256            DH_RSA_WITH_AES_128_SHA256      )],
    '0x00,0x40' => [qw( DHE-DSS-AES128-SHA256           DHE_DSS_WITH_AES_128_SHA256     )],
    '0x00,0x41' => [qw( CAMELLIA128-SHA                 RSA_WITH_CAMELLIA_128_CBC_SHA   )],
    '0x00,0x42' => [qw( DH-DSS-CAMELLIA128-SHA          DH_DSS_WITH_CAMELLIA_128_CBC_SHA    )],
    '0x00,0x43' => [qw( DH-RSA-CAMELLIA128-SHA          DH_RSA_WITH_CAMELLIA_128_CBC_SHA    )],
    '0x00,0x44' => [qw( DHE-DSS-CAMELLIA128-SHA         DHE_DSS_WITH_CAMELLIA_128_CBC_SHA   )],
    '0x00,0x45' => [qw( DHE-RSA-CAMELLIA128-SHA         DHE_RSA_WITH_CAMELLIA_128_CBC_SHA   )],
    '0x00,0x46' => [qw( ADH-CAMELLIA128-SHA             ADH_WITH_CAMELLIA_128_CBC_SHA       )],
#{  following 6 seen somewhere, probably SSLv3
    '0x00,0x47' => [qw( ECDH_ECDSA_WITH_NULL_SHA        ECDH_ECDSA_WITH_NULL_SHA            )], # same as 0xC0,0x01
    '0x00,0x48' => [qw( ECDH_ECDSA_WITH_RC4_128_SHA     ECDH_ECDSA_WITH_RC4_128_SHA         )], # same as 0xC0,0x02
    '0x00,0x49' => [qw( ECDH_ECDSA_WITH_DES_CBC_SHA     ECDH_ECDSA_WITH_DES_CBC_SHA         )], # unknown
    '0x00,0x4A' => [qw( ECDH_ECDSA_WITH_3DES_EDE_CBC_SHA   ECDH_ECDSA_WITH_3DES_EDE_CBC_SHA )], # same as 0xC0,0x03
    '0x00,0x4B' => [qw( ECDH_ECDSA_WITH_AES_128_CBC_SHA ECDH_ECDSA_WITH_AES_128_CBC_SHA     )], # same as 0xC0,0x04
    '0x00,0x4C' => [qw( ECDH_ECDSA_WITH_AES_256_CBC_SHA ECDH_ECDSA_WITH_AES_256_CBC_SHA     )], # same as 0xC0,0x05
#}
#   '0x00,0x4D' ..
#   '0x00,0x5F'
    '0x00,0x60' => [qw( EXP1024-RC4-MD5                 RSA_EXPORT1024_WITH_RC4_56_MD5      )],
    '0x00,0x61' => [qw( EXP1024-RC2-CBC-MD5             RSA_EXPORT1024_WITH_RC2_CBC_56_MD5  )],
    '0x00,0x62' => [qw( EXP1024-DES-CBC-SHA             RSA_EXPORT1024_WITH_DES_CBC_SHA     )],
    '0x00,0x63' => [qw( EXP1024-DHE-DSS-DES-CBC-SHA     DHE_DSS_EXPORT1024_WITH_DES_CBC_SHA )],
    '0x00,0x64' => [qw( EXP1024-RC4-SHA                 RSA_EXPORT1024_WITH_RC4_56_SHA      )],
    '0x00,0x65' => [qw( EXP1024-DHE-DSS-RC4-SHA         DHE_DSS_EXPORT1024_WITH_RC4_56_SHA  )],
    '0x00,0x66' => [qw( DHE-DSS-RC4-SHA                 DHE_DSS_WITH_RC4_128_SHA            )],
    '0x00,0x67' => [qw( DHE-RSA-AES128-SHA256           DHE_RSA_WITH_AES_128_SHA256         )],
    '0x00,0x68' => [qw( DH-DSS-AES256-SHA256            DH_DSS_WITH_AES_256_SHA256          )],
    '0x00,0x69' => [qw( DH-RSA-AES256-SHA256            DH_RSA_WITH_AES_256_SHA256          )],
    '0x00,0x6A' => [qw( DHE-DSS-AES256-SHA256           DHE_DSS_WITH_AES_256_SHA256         )],
    '0x00,0x6B' => [qw( DHE-RSA-AES256-SHA256           DHE_RSA_WITH_AES_256_SHA256         )],
    '0x00,0x6C' => [qw( ADH-AES128-SHA256               ADH_WITH_AES_128_SHA256             )],
    '0x00,0x6D' => [qw( ADH-AES256-SHA256               ADH_WITH_AES_256_SHA256             )],
    '0x00,0x72' => [qw( ECDHE-ECDSA-CAMELLIA128-SHA256  ECDHE_ECDSA_WITH_CAMELLIA_128_CBC_SHA256 )],
    '0x00,0x73' => [qw( ECDHE-ECDSA-CAMELLIA256-SHA384  ECDHE_ECDSA_WITH_CAMELLIA_256_CBC_SHA384 )],
    '0x00,0x74' => [qw( ECDH-ECDSA-CAMELLIA128-SHA256   ECDH_ECDSA_WITH_CAMELLIA_128_CBC_SHA256  )],
    '0x00,0x75' => [qw( ECDH-ECDSA-CAMELLIA256-SHA384   ECDH_ECDSA_WITH_CAMELLIA_256_CBC_SHA384  )],
    '0x00,0x76' => [qw( ECDHE-RSA-CAMELLIA128-SHA256    ECDHE_RSA_WITH_CAMELLIA_128_CBC_SHA256   )],
    '0x00,0x77' => [qw( ECDHE-RSA-CAMELLIA256-SHA384    ECDHE_RSA_WITH_CAMELLIA_256_CBC_SHA384   )],
    '0x00,0x78' => [qw( ECDH-RSA-CAMELLIA128-SHA256     ECDH_RSA_WITH_CAMELLIA_128_CBC_SHA256    )],
    '0x00,0x79' => [qw( ECDH-RSA-CAMELLIA256-SHA384     ECDH_RSA_WITH_CAMELLIA_256_CBC_SHA384    )],
    '0x00,0x80' => [qw( GOST94-GOST89-GOST89            GOSTR341094_WITH_28147_CNT_IMIT     )],
    '0x00,0x81' => [qw( GOST2001-GOST89-GOST89          GOSTR341001_WITH_28147_CNT_IMIT     )],
    '0x00,0x82' => [qw( GOST94-NULL-GOST94              GOSTR341094_WITH_NULL_GOSTR3411     )],
    '0x00,0x83' => [qw( GOST2001-NULL-GOST94            GOSTR341001_WITH_NULL_GOSTR3411     )],
    '0x00,0x84' => [qw( CAMELLIA256-SHA                 RSA_WITH_CAMELLIA_256_CBC_SHA       )],
    '0x00,0x85' => [qw( DH-DSS-CAMELLIA256-SHA          DH_DSS_WITH_CAMELLIA_256_CBC_SHA    )],
    '0x00,0x86' => [qw( DH-RSA-CAMELLIA256-SHA          DH_RSA_WITH_CAMELLIA_256_CBC_SHA    )],
    '0x00,0x87' => [qw( DHE-DSS-CAMELLIA256-SHA         DHE_DSS_WITH_CAMELLIA_256_CBC_SHA   )],
    '0x00,0x88' => [qw( DHE-RSA-CAMELLIA256-SHA         DHE_RSA_WITH_CAMELLIA_256_CBC_SHA   )],
    '0x00,0x89' => [qw( ADH-CAMELLIA256-SHA             ADH_WITH_CAMELLIA_256_CBC_SHA   )],
    '0x00,0x8A' => [qw( PSK-RC4-SHA                     PSK_WITH_RC4_128_SHA            )],
    '0x00,0x8B' => [qw( PSK-3DES-SHA                    PSK_WITH_3DES_EDE_CBC_SHA       )],
    '0x00,0x8C' => [qw( PSK-AES128-CBC-SHA              PSK_WITH_AES_128_CBC_SHA        )],
    '0x00,0x8D' => [qw( PSK-AES256-CBC-SHA              PSK_WITH_AES_256_CBC_SHA        )],
    '0x00,0x8E' => [qw( DHE-PSK-RC4-SHA                 DHE_PSK_WITH_RC4_128_SHA        )],
    '0x00,0x8F' => [qw( DHE-PSK-3DES-SHA                DHE_PSK_WITH_3DES_EDE_CBC_SHA   )],
    '0x00,0x90' => [qw( DHE-PSK-AES128-SHA              DHE_PSK_WITH_AES_128_CBC_SHA    )],
    '0x00,0x91' => [qw( DHE-PSK-AES256-SHA              DHE_PSK_WITH_AES_256_CBC_SHA    )],
    '0x00,0x92' => [qw( RSA-PSK-RC4-SHA                 RSA_PSK_WITH_RC4_128_SHA        )],
    '0x00,0x93' => [qw( RSA-PSK-3DES-SHA                RSA_PSK_WITH_3DES_EDE_CBC_SHA   )],
    '0x00,0x94' => [qw( RSA-PSK-AES128-SHA              RSA_PSK_WITH_AES_128_CBC_SHA    )],
    '0x00,0x95' => [qw( RSA-PSK-AES256-SHA              RSA_PSK_WITH_AES_256_CBC_SHA    )],
    '0x00,0x96' => [qw( SEED-SHA                        RSA_WITH_SEED_SHA               )],
    '0x00,0x97' => [qw( DH-DSS-SEED-SHA                 DH_DSS_WITH_SEED_SHA            )],
    '0x00,0x98' => [qw( DH-RSA-SEED-SHA                 DH_RSA_WITH_SEED_SHA            )],
    '0x00,0x99' => [qw( DHE-DSS-SEED-SHA                DHE_DSS_WITH_SEED_SHA           )],
    '0x00,0x9A' => [qw( DHE-RSA-SEED-SHA                DHE_RSA_WITH_SEED_SHA           )],
    '0x00,0x9B' => [qw( ADH-SEED-SHA                    ADH_WITH_SEED_SHA               )],
    '0x00,0x9C' => [qw( AES128-GCM-SHA256               RSA_WITH_AES_128_GCM_SHA256     )],
    '0x00,0x9D' => [qw( AES256-GCM-SHA384               RSA_WITH_AES_256_GCM_SHA384     )],
    '0x00,0x9E' => [qw( DHE-RSA-AES128-GCM-SHA256       DHE_RSA_WITH_AES_128_GCM_SHA256 )],
    '0x00,0x9F' => [qw( DHE-RSA-AES256-GCM-SHA384       DHE_RSA_WITH_AES_256_GCM_SHA384 )],
    '0x00,0xA0' => [qw( DH-RSA-AES128-GCM-SHA256        DH_RSA_WITH_AES_128_GCM_SHA256  )],
    '0x00,0xA1' => [qw( DH-RSA-AES256-GCM-SHA384        DH_RSA_WITH_AES_256_GCM_SHA384  )],
    '0x00,0xA2' => [qw( DHE-DSS-AES128-GCM-SHA256       DHE_DSS_WITH_AES_128_GCM_SHA256 )],
    '0x00,0xA3' => [qw( DHE-DSS-AES256-GCM-SHA384       DHE_DSS_WITH_AES_256_GCM_SHA384 )],
    '0x00,0xA4' => [qw( DH-DSS-AES128-GCM-SHA256        DH_DSS_WITH_AES_128_GCM_SHA256  )],
    '0x00,0xA5' => [qw( DH-DSS-AES256-GCM-SHA384        DH_DSS_WITH_AES_256_GCM_SHA384  )],
    '0x00,0xA6' => [qw( ADH-AES128-GCM-SHA256           ADH_WITH_AES_128_GCM_SHA256     )],
    '0x00,0xA7' => [qw( ADH-AES256-GCM-SHA384           ADH_WITH_AES_256_GCM_SHA384     )],
    '0x00,0xA8' => [qw( PSK-AES128-GCM-SHA256           PSK_WITH_AES_128_GCM_SHA256     )],
    '0x00,0xA9' => [qw( PSK-AES256-GCM-SHA384           PSK_WITH_AES_256_GCM_SHA384     )],
    '0x00,0xAA' => [qw( DHE-PSK-AES128-GCM-SHA256       DHE_PSK_WITH_AES_128_GCM_SHA256 )],
    '0x00,0xAB' => [qw( DHE-PSK-AES256-GCM-SHA384       DHE_PSK_WITH_AES_256_GCM_SHA384 )],
    '0x00,0xAC' => [qw( RSA-PSK-AES128-GCM-SHA256       RSA_PSK_WITH_AES_128_GCM_SHA256 )],
    '0x00,0xAD' => [qw( RSA-PSK-AES256-GCM-SHA384       RSA_PSK_WITH_AES_256_GCM_SHA384 )],
    '0x00,0xAE' => [qw( PSK-AES128-SHA256               PSK_WITH_AES_128_CBC_SHA256     )],
    '0x00,0xAF' => [qw( PSK-AES256-SHA384               PSK_WITH_AES_256_CBC_SHA384     )],
    '0x00,0xB0' => [qw( PSK-SHA256                      PSK_WITH_NULL_SHA256            )],
    '0x00,0xB1' => [qw( PSK-SHA384                      PSK_WITH_NULL_SHA384            )],
    '0x00,0xB2' => [qw( DHE-PSK-AES128-SHA256           DHE_PSK_WITH_AES_128_CBC_SHA256 )],
    '0x00,0xB3' => [qw( DHE-PSK-AES256-SHA384           DHE_PSK_WITH_AES_256_CBC_SHA384 )],
    '0x00,0xB4' => [qw( DHE-PSK-SHA256                  DHE_PSK_WITH_NULL_SHA256        )],
    '0x00,0xB5' => [qw( DHE-PSK-SHA384                  DHE_PSK_WITH_NULL_SHA384        )],
    '0x00,0xB6' => [qw( RSA-PSK-AES128-SHA256           RSA_PSK_WITH_AES_128_CBC_SHA256 )],
    '0x00,0xB7' => [qw( RSA-PSK-AES256-SHA384           RSA_PSK_WITH_AES_256_CBC_SHA384 )],
    '0x00,0xB8' => [qw( RSA-PSK-SHA256                  RSA_PSK_WITH_NULL_SHA256        )],
    '0x00,0xB9' => [qw( RSA-PSK-SHA384                  RSA_PSK_WITH_NULL_SHA384        )],
    '0x00,0xBA' => [qw( CAMELLIA128-SHA256              RSA_WITH_CAMELLIA_128_CBC_SHA256    )],
    '0x00,0xBB' => [qw( DH-DSS-CAMELLIA128-SHA256       DH_DSS_WITH_CAMELLIA_128_CBC_SHA256 )],
    '0x00,0xBC' => [qw( DH-RSA-CAMELLIA128-SHA256       DH_RSA_WITH_CAMELLIA_128_CBC_SHA256 )],
    '0x00,0xBD' => [qw( DHE-DSS-CAMELLIA128-SHA256      DHE_DSS_WITH_CAMELLIA_128_CBC_SHA256    )],
    '0x00,0xBE' => [qw( DHE-RSA-CAMELLIA128-SHA256      DHE_RSA_WITH_CAMELLIA_128_CBC_SHA256    )],
    '0x00,0xBF' => [qw( ADH-CAMELLIA128-SHA256          ADH_WITH_CAMELLIA_128_CBC_SHA256    )],
    '0x00,0xC0' => [qw( CAMELLIA256-SHA256              RSA_WITH_CAMELLIA_256_CBC_SHA256    )],
    '0x00,0xC1' => [qw( DH-DSS-CAMELLIA256-SHA256       DH_DSS_WITH_CAMELLIA_256_CBC_SHA256 )],
    '0x00,0xC2' => [qw( DH-RSA-CAMELLIA256-SHA256       DH_RSA_WITH_CAMELLIA_256_CBC_SHA256 )],
    '0x00,0xC3' => [qw( DHE-DSS-CAMELLIA256-SHA256      DHE_DSS_WITH_CAMELLIA_256_CBC_SHA256    )],
    '0x00,0xC4' => [qw( DHE-RSA-CAMELLIA256-SHA256      DHE_RSA_WITH_CAMELLIA_256_CBC_SHA256    )],
    '0x00,0xC5' => [qw( ADH-CAMELLIA256-SHA256          ADH_WITH_CAMELLIA_256_CBC_SHA256    )],
#   '0x00,0xC6' ..
#   '0xC0,0x00'
    '0xC0,0x01' => [qw( ECDH-ECDSA-NULL-SHA             ECDH_ECDSA_WITH_NULL_SHA            )],
    '0xC0,0x02' => [qw( ECDH-ECDSA-RC4-SHA              ECDH_ECDSA_WITH_RC4_128_SHA         )],
    '0xC0,0x03' => [qw( ECDH-ECDSA-DES-CBC3-SHA         ECDH_ECDSA_WITH_DES_192_CBC3_SHA    )],
    '0xC0,0x04' => [qw( ECDH-ECDSA-AES128-SHA           ECDH_ECDSA_WITH_AES_128_CBC_SHA     )],
    '0xC0,0x05' => [qw( ECDH-ECDSA-AES256-SHA           ECDH_ECDSA_WITH_AES_256_CBC_SHA     )],
    '0xC0,0x06' => [qw( ECDHE-ECDSA-NULL-SHA            ECDHE_ECDSA_WITH_NULL_SHA           )],
    '0xC0,0x07' => [qw( ECDHE-ECDSA-RC4-SHA             ECDHE_ECDSA_WITH_RC4_128_SHA        )],
    '0xC0,0x08' => [qw( ECDHE-ECDSA-DES-CBC3-SHA        ECDHE_ECDSA_WITH_DES_192_CBC3_SHA   )],
    '0xC0,0x09' => [qw( ECDHE-ECDSA-AES128-SHA          ECDHE_ECDSA_WITH_AES_128_CBC_SHA    )],
    '0xC0,0x0A' => [qw( ECDHE-ECDSA-AES256-SHA          ECDHE_ECDSA_WITH_AES_256_CBC_SHA    )],
    '0xC0,0x0B' => [qw( ECDH-RSA-NULL-SHA               ECDH_RSA_WITH_NULL_SHA              )],
    '0xC0,0x0C' => [qw( ECDH-RSA-RC4-SHA                ECDH_RSA_WITH_RC4_128_SHA           )],
    '0xC0,0x0D' => [qw( ECDH-RSA-DES-CBC3-SHA           ECDH_RSA_WITH_DES_192_CBC3_SHA      )],
    '0xC0,0x0E' => [qw( ECDH-RSA-AES128-SHA             ECDH_RSA_WITH_AES_128_CBC_SHA       )],
    '0xC0,0x0F' => [qw( ECDH-RSA-AES256-SHA             ECDH_RSA_WITH_AES_256_CBC_SHA       )],
    '0xC0,0x10' => [qw( ECDHE-RSA-NULL-SHA              ECDHE_RSA_WITH_NULL_SHA             )],
    '0xC0,0x11' => [qw( ECDHE-RSA-RC4-SHA               ECDHE_RSA_WITH_RC4_128_SHA          )],
    '0xC0,0x12' => [qw( ECDHE-RSA-DES-CBC3-SHA          ECDHE_RSA_WITH_DES_192_CBC3_SHA     )],
    '0xC0,0x13' => [qw( ECDHE-RSA-AES128-SHA            ECDHE_RSA_WITH_AES_128_CBC_SHA      )],
    '0xC0,0x14' => [qw( ECDHE-RSA-AES256-SHA            ECDHE_RSA_WITH_AES_256_CBC_SHA      )],
    '0xC0,0x15' => [qw( AECDH-NULL-SHA                  ECDH_anon_WITH_NULL_SHA             )],
    '0xC0,0x16' => [qw( AECDH-RC4-SHA                   ECDH_anon_WITH_RC4_128_SHA          )],
    '0xC0,0x17' => [qw( AECDH-DES-CBC3-SHA              ECDH_anon_WITH_DES_192_CBC3_SHA     )],
    '0xC0,0x18' => [qw( AECDH-AES128-SHA                ECDH_anon_WITH_AES_128_CBC_SHA      )],
    '0xC0,0x19' => [qw( AECDH-AES256-SHA                ECDH_anon_WITH_AES_256_CBC_SHA      )],
    '0xC0,0x1A' => [qw( SRP-3DES-EDE-CBC-SHA            SRP_SHA_WITH_3DES_EDE_CBC_SHA       )],
    '0xC0,0x1B' => [qw( SRP-RSA-3DES-EDE-CBC-SHA        SRP_SHA_RSA_WITH_3DES_EDE_CBC_SHA   )],
    '0xC0,0x1C' => [qw( SRP-DSS-3DES-EDE-CBC-SHA        SRP_SHA_DSS_WITH_3DES_EDE_CBC_SHA   )],
    '0xC0,0x1D' => [qw( SRP-AES-128-CBC-SHA             SRP_SHA_WITH_AES_128_CBC_SHA        )],
    '0xC0,0x1E' => [qw( SRP-RSA-AES-128-CBC-SHA         SRP_SHA_RSA_WITH_AES_128_CBC_SHA    )],
    '0xC0,0x1F' => [qw( SRP-DSS-AES-128-CBC-SHA         SRP_SHA_DSS_WITH_AES_128_CBC_SHA    )],
    '0xC0,0x20' => [qw( SRP-AES-256-CBC-SHA             SRP_SHA_WITH_AES_256_CBC_SHA        )],
    '0xC0,0x21' => [qw( SRP-RSA-AES-256-CBC-SHA         SRP_SHA_RSA_WITH_AES_256_CBC_SHA    )],
    '0xC0,0x22' => [qw( SRP-DSS-AES-256-CBC-SHA         SRP_SHA_DSS_WITH_AES_256_CBC_SHA    )],
    '0xC0,0x23' => [qw( ECDHE-ECDSA-AES128-SHA256       ECDHE_ECDSA_WITH_AES_128_SHA256     )],
    '0xC0,0x24' => [qw( ECDHE-ECDSA-AES256-SHA384       ECDHE_ECDSA_WITH_AES_256_SHA384     )],
    '0xC0,0x25' => [qw( ECDH-ECDSA-AES128-SHA256        ECDH_ECDSA_WITH_AES_128_SHA256      )],
    '0xC0,0x26' => [qw( ECDH-ECDSA-AES256-SHA384        ECDH_ECDSA_WITH_AES_256_SHA384      )],
    '0xC0,0x27' => [qw( ECDHE-RSA-AES128-SHA256         ECDHE_RSA_WITH_AES_128_SHA256       )],
    '0xC0,0x28' => [qw( ECDHE-RSA-AES256-SHA384         ECDHE_RSA_WITH_AES_256_SHA384       )],
    '0xC0,0x29' => [qw( ECDH-RSA-AES128-SHA256          ECDH_RSA_WITH_AES_128_SHA256        )],
    '0xC0,0x2A' => [qw( ECDH-RSA-AES256-SHA384          ECDH_RSA_WITH_AES_256_SHA384        )],
    '0xC0,0x2B' => [qw( ECDHE-ECDSA-AES128-GCM-SHA256   ECDHE_ECDSA_WITH_AES_128_GCM_SHA256 )],
    '0xC0,0x2C' => [qw( ECDHE-ECDSA-AES256-GCM-SHA384   ECDHE_ECDSA_WITH_AES_256_GCM_SHA384 )],
    '0xC0,0x2D' => [qw( ECDH-ECDSA-AES128-GCM-SHA256    ECDH_ECDSA_WITH_AES_128_GCM_SHA256  )],
    '0xC0,0x2E' => [qw( ECDH-ECDSA-AES256-GCM-SHA384    ECDH_ECDSA_WITH_AES_256_GCM_SHA384  )],
    '0xC0,0x2F' => [qw( ECDHE-RSA-AES128-GCM-SHA256     ECDHE_RSA_WITH_AES_128_GCM_SHA256   )],
    '0xC0,0x30' => [qw( ECDHE-RSA-AES256-GCM-SHA384     ECDHE_RSA_WITH_AES_256_GCM_SHA384   )],
    '0xC0,0x31' => [qw( ECDH-RSA-AES128-GCM-SHA256      ECDH_RSA_WITH_AES_128_GCM_SHA256    )],
    '0xC0,0x32' => [qw( ECDH-RSA-AES256-GCM-SHA384      ECDH_RSA_WITH_AES_256_GCM_SHA384    )],
    '0xC0,0x33' => [qw( ECDHE-PSK-RC4-128-SHA           ECDHE_PSK_WITH_RC4_128_SHA          )],
    '0xC0,0x34' => [qw( ECDHE-PSK-3DES-EDE-CBC-SHA      ECDHE_PSK_WITH_3DES_EDE_CBC_SHA     )],
    '0xC0,0x35' => [qw( ECDHE-PSK-AES-128-CBC-SHA       ECDHE_PSK_WITH_AES_128_CBC_SHA      )],
    '0xC0,0x36' => [qw( ECDHE-PSK-AES-256-CBC-SHA       ECDHE_PSK_WITH_AES_256_CBC_SHA      )],
    '0xC0,0x37' => [qw( ECDHE-PSK-AES-128-CBC-SHA256    ECDHE_PSK_WITH_AES_128_CBC_SHA256   )],
    '0xC0,0x38' => [qw( ECDHE-PSK-AES-256-CBC-SHA384    ECDHE_PSK_WITH_AES_256_CBC_SHA384   )],
    '0xC0,0x39' => [qw( ECDHE-PSK-NULL-SHA              ECDHE_PSK_WITH_NULL_SHA             )],
    '0xC0,0x3A' => [qw( ECDHE-PSK-NULL-SHA256           ECDHE_PSK_WITH_NULL_SHA256          )],
    '0xC0,0x3B' => [qw( ECDHE-PSK-NULL-SHA384           ECDHE_PSK_WITH_NULL_SHA384          )],
    '0xC0,0x3C' => [qw( RSA-ARIA128-SHA256              RSA_WITH_ARIA_128_CBC_SHA256        )],
    '0xC0,0x3D' => [qw( RSA-ARIA256-SHA384              RSA_WITH_ARIA_256_CBC_SHA384        )],
    '0xC0,0x3E' => [qw( DH-DSS-ARIA128-SHA256           DH_DSS_WITH_ARIA_128_CBC_SHA256     )],
    '0xC0,0x3F' => [qw( DH-DSS-ARIA256-SHA384           DH_DSS_WITH_ARIA_256_CBC_SHA384     )],
    '0xC0,0x40' => [qw( DH-RSA-ARIA128-SHA256           DH_RSA_WITH_ARIA_128_CBC_SHA256     )],
    '0xC0,0x41' => [qw( DH-RSA-ARIA256-SHA384           DH_RSA_WITH_ARIA_256_CBC_SHA384     )],
    '0xC0,0x42' => [qw( DHE-DSS-ARIA128-SHA256          DHE_DSS_WITH_ARIA_128_CBC_SHA256    )],
    '0xC0,0x43' => [qw( DHE-DSS-ARIA256-SHA384          DHE_DSS_WITH_ARIA_256_CBC_SHA384    )],
    '0xC0,0x44' => [qw( DHE-RSA-ARIA128-SHA256          DHE_RSA_WITH_ARIA_128_CBC_SHA256    )],
    '0xC0,0x45' => [qw( DHE-RSA-ARIA256-SHA384          DHE_RSA_WITH_ARIA_256_CBC_SHA384    )],
    '0xC0,0x46' => [qw( ADH-ARIA128-SHA256              DH_anon_WITH_ARIA_128_CBC_SHA256    )],
    '0xC0,0x47' => [qw( ADH-ARIA256-SHA384              DH_anon_WITH_ARIA_256_CBC_SHA384    )],
    '0xC0,0x48' => [qw( ECDHE-ECDSA-ARIA128-SHA256      ECDHE_ECDSA_WITH_ARIA_128_CBC_SHA256 )],
    '0xC0,0x49' => [qw( ECDHE-ECDSA-ARIA256-SHA384      ECDHE_ECDSA_WITH_ARIA_256_CBC_SHA384 )],
    '0xC0,0x4A' => [qw( ECDH-ECDSA-ARIA128-SHA256       ECDH_ECDSA_WITH_ARIA_128_CBC_SHA256 )],
    '0xC0,0x4B' => [qw( ECDH-ECDSA-ARIA256-SHA384       ECDH_ECDSA_WITH_ARIA_256_CBC_SHA384 )],
    '0xC0,0x4C' => [qw( ECDHE-RSA-ARIA128-SHA256        ECDHE_RSA_WITH_ARIA_128_CBC_SHA256  )],
    '0xC0,0x4D' => [qw( ECDHE-RSA-ARIA256-SHA384        ECDHE_RSA_WITH_ARIA_256_CBC_SHA384  )],
    '0xC0,0x4E' => [qw( ECDH-RSA-ARIA128-SHA256         ECDH_RSA_WITH_ARIA_128_CBC_SHA256   )],
    '0xC0,0x4F' => [qw( ECDH-RSA-ARIA256-SHA384         ECDH_RSA_WITH_ARIA_256_CBC_SHA384   )],
    '0xC0,0x50' => [qw( RSA-ARIA128-GCM-SHA256          RSA_WITH_ARIA_128_GCM_SHA256        )]    ,
    '0xC0,0x51' => [qw( RSA-ARIA256-GCM-SHA384          RSA_WITH_ARIA_256_GCM_SHA384        )],
    '0xC0,0x52' => [qw( DHE-RSA-ARIA128-GCM-SHA256      DHE_RSA_WITH_ARIA_128_GCM_SHA256    )],
    '0xC0,0x53' => [qw( DHE-RSA-ARIA256-GCM-SHA384      DHE_RSA_WITH_ARIA_256_GCM_SHA384    )],
    '0xC0,0x54' => [qw( DH-RSA-ARIA128-GCM-SHA256       DH_RSA_WITH_ARIA_128_GCM_SHA256     )],
    '0xC0,0x55' => [qw( DH-RSA-ARIA256-GCM-SHA384       DH_RSA_WITH_ARIA_256_GCM_SHA384     )],
    '0xC0,0x56' => [qw( DHE-DSS-ARIA128-GCM-SHA256      DHE_DSS_WITH_ARIA_128_GCM_SHA256    )],
    '0xC0,0x57' => [qw( DHE-DSS-ARIA256-GCM-SHA384      DHE_DSS_WITH_ARIA_256_GCM_SHA384    )],
    '0xC0,0x58' => [qw( DH-DSS-ARIA128-GCM-SHA256       DH_DSS_WITH_ARIA_128_GCM_SHA256     )],
    '0xC0,0x59' => [qw( DH-DSS-ARIA256-GCM-SHA384       DH_DSS_WITH_ARIA_256_GCM_SHA384     )],
    '0xC0,0x5A' => [qw( ADH-ARIA128-GCM-SHA256          DH_anon_WITH_ARIA_128_GCM_SHA256    )],
    '0xC0,0x5B' => [qw( ADH-ARIA256-GCM-SHA384          DH_anon_WITH_ARIA_256_GCM_SHA384    )],
    '0xC0,0x5C' => [qw( ECDHE-ECDSA-ARIA128-GCM-SHA256  ECDHE_ECDSA_WITH_ARIA_128_GCM_SHA256 )],
    '0xC0,0x5D' => [qw( ECDHE-ECDSA-ARIA256-GCM-SHA384  ECDHE_ECDSA_WITH_ARIA_256_GCM_SHA384 )],
    '0xC0,0x5E' => [qw( ECDH-ECDSA-ARIA128-GCM-SHA256   ECDH_ECDSA_WITH_ARIA_128_GCM_SHA256 )],
    '0xC0,0x5F' => [qw( ECDH-ECDSA-ARIA256-GCM-SHA384   ECDH_ECDSA_WITH_ARIA_256_GCM_SHA384 )],
    '0xC0,0x60' => [qw( ECDHE-RSA-ARIA128-GCM-SHA256    ECDHE_RSA_WITH_ARIA_128_GCM_SHA256  )],
    '0xC0,0x61' => [qw( ECDHE-RSA-ARIA256-GCM-SHA384    ECDHE_RSA_WITH_ARIA_256_GCM_SHA384  )],
    '0xC0,0x62' => [qw( ECDH-RSA-ARIA128-GCM-SHA256     ECDH_RSA_WITH_ARIA_128_GCM_SHA256   )],
    '0xC0,0x63' => [qw( ECDH-RSA-ARIA256-GCM-SHA384     ECDH_RSA_WITH_ARIA_256_GCM_SHA384   )],
    '0xC0,0x64' => [qw( PSK-ARIA128-SHA-56              PSK_WITH_ARIA_128_CBC_SHA256        )],
    '0xC0,0x65' => [qw( PSK-ARIA256-SHA384              PSK_WITH_ARIA_256_CBC_SHA384        )],
    '0xC0,0x66' => [qw( DHE-PSK-ARIA128-SHA256          DHE_PSK_WITH_ARIA_128_CBC_SHA256    )],
    '0xC0,0x67' => [qw( DHE-PSK-ARIA256-SHA384          DHE_PSK_WITH_ARIA_256_CBC_SHA384    )],
    '0xC0,0x68' => [qw( RSA-PSK-ARIA128-SHA256          RSA_PSK_WITH_ARIA_128_CBC_SHA256    )],
    '0xC0,0x69' => [qw( RSA-PSK-ARIA256-SHA384          RSA_PSK_WITH_ARIA_256_CBC_SHA384    )],
    '0xC0,0x6A' => [qw( PSK-ARIA128-GCM-SHA256          PSK_WITH_ARIA_128_GCM_SHA256        )],
    '0xC0,0x6B' => [qw( PSK-ARIA256-GCM-SHA384          PSK_WITH_ARIA_256_GCM_SHA384        )],
    '0xC0,0x6C' => [qw( DHE-PSK-ARIA128-GCM-SHA256      DHE_PSK_WITH_ARIA_128_GCM_SHA256    )],
    '0xC0,0x6D' => [qw( DHE-PSK-ARIA256-GCM-SHA384      DHE_PSK_WITH_ARIA_256_GCM_SHA384    )],
    '0xC0,0x6E' => [qw( RSA-PSK-ARIA128-GCM-SHA256      RSA_PSK_WITH_ARIA_128_GCM_SHA256    )],
    '0xC0,0x6F' => [qw( RSA-PSK-ARIA256-GCM-SHA384      RSA_PSK_WITH_ARIA_256_GCM_SHA384    )],
    '0xC0,0x70' => [qw( ECDHE-PSK-ARIA128-SHA256        ECDHE_PSK_WITH_ARIA_128_CBC_SHA256  )],
    '0xC0,0x71' => [qw( ECDHE-PSK-ARIA256-SHA384        ECDHE_PSK_WITH_ARIA_256_CBC_SHA384  )],
    '0xC0,0x72' => [qw( ECDHE-ECDSA-CAMELLIA128-SHA256  ECDHE_ECDSA_WITH_CAMELLIA_128_CBC_SHA256 )],
    '0xC0,0x73' => [qw( ECDHE-ECDSA-CAMELLIA256-SHA384  ECDHE_ECDSA_WITH_CAMELLIA_256_CBC_SHA384 )],
    '0xC0,0x74' => [qw( ECDH-ECDSA-CAMELLIA128-SHA256   ECDH_ECDSA_WITH_CAMELLIA_128_CBC_SHA256 )],
    '0xC0,0x75' => [qw( ECDH-ECDSA-CAMELLIA256-SHA384   ECDH_ECDSA_WITH_CAMELLIA_256_CBC_SHA384 )],
    '0xC0,0x76' => [qw( ECDHE-RSA-CAMELLIA128-SHA256    ECDHE_RSA_WITH_CAMELLIA_128_CBC_SHA256  )],
    '0xC0,0x77' => [qw( ECDHE-RSA-CAMELLIA256-SHA384    ECDHE_RSA_WITH_CAMELLIA_256_CBC_SHA384  )],
    '0xC0,0x78' => [qw( ECDH-RSA-CAMELLIA128-SHA256     ECDH_RSA_WITH_CAMELLIA_128_CBC_SHA256   )],
    '0xC0,0x79' => [qw( ECDH-RSA-CAMELLIA256-SHA384     ECDH_RSA_WITH_CAMELLIA_256_CBC_SHA384   )],
    '0xC0,0x7A' => [qw( RSA-CAMELLIA128-GCM-SHA256      RSA_WITH_CAMELLIA_128_GCM_SHA256        )],
    '0xC0,0x7B' => [qw( RSA-CAMELLIA256-GCM-SHA384      RSA_WITH_CAMELLIA_256_GCM_SHA384        )],
    '0xC0,0x7C' => [qw( DHE-RSA-CAMELLIA128-GCM-SHA256  DHE_RSA_WITH_CAMELLIA_128_GCM_SHA256    )],
    '0xC0,0x7D' => [qw( DHE-RSA-CAMELLIA256-GCM-SHA384  DHE_RSA_WITH_CAMELLIA_256_GCM_SHA384    )],
    '0xC0,0x7E' => [qw( DH-RSA-CAMELLIA128-GCM-SHA256   DH_RSA_WITH_CAMELLIA_128_GCM_SHA256     )],
    '0xC0,0x7F' => [qw( DH-RSA-CAMELLIA256-GCM-SHA384   DH_RSA_WITH_CAMELLIA_256_GCM_SHA384     )],
    '0xC0,0x80' => [qw( DHE-DSS-CAMELLIA128-GCM-SHA256  DHE_DSS_WITH_CAMELLIA_128_GCM_SHA256    )],
    '0xC0,0x81' => [qw( DHE-DSS-CAMELLIA256-GCM-SHA384  DHE_DSS_WITH_CAMELLIA_256_GCM_SHA384    )],
    '0xC0,0x82' => [qw( DH-DSS-CAMELLIA128-GCM-SHA256   DH_DSS_WITH_CAMELLIA_128_GCM_SHA256     )],
    '0xC0,0x83' => [qw( DH-DSS-CAMELLIA256-GCM-SHA384   DH_DSS_WITH_CAMELLIA_256_GCM_SHA384     )],
    '0xC0,0x84' => [qw( ADH-DSS-CAMELLIA128-GCM-SHA256  ADH_DSS_WITH_CAMELLIA_128_GCM_SHA256    )],
    '0xC0,0x85' => [qw( ADH-DSS-CAMELLIA256-GCM-SHA384  ADH_DSS_WITH_CAMELLIA_256_GCM_SHA384    )],
    '0xC0,0x86' => [qw( ECDHE-ECDSA-CAMELLIA128-GCM-SHA256  ECDHE_ECDSA_WITH_CAMELLIA_128_GCM_SHA256 )],
    '0xC0,0x87' => [qw( ECDHE-ECDSA-CAMELLIA256-GCM-SHA384  ECDHE_ECDSA_WITH_CAMELLIA_256_GCM_SHA384 )],
    '0xC0,0x88' => [qw( ECDH-ECDSA-CAMELLIA128-GCM-SHA256   ECDH_ECDSA_WITH_CAMELLIA_128_GCM_SHA256 )],
    '0xC0,0x89' => [qw( ECDH-ECDSA-CAMELLIA256-GCM-SHA384   ECDH_ECDSA_WITH_CAMELLIA_256_GCM_SHA384 )],
    '0xC0,0x8A' => [qw( ECDHE-RSA-CAMELLIA128-GCM-SHA256    ECDHE_RSA_WITH_CAMELLIA_128_GCM_SHA256  )],
    '0xC0,0x8B' => [qw( ECDHE-RSA-CAMELLIA256-GCM-SHA384    ECDHE_RSA_WITH_CAMELLIA_256_GCM_SHA384  )],
    '0xC0,0x8C' => [qw( ECDH-RSA-CAMELLIA128-GCM-SHA256 ECDH_RSA_WITH_CAMELLIA_128_GCM_SHA256   )],
    '0xC0,0x8D' => [qw( ECDH-RSA-CAMELLIA256-GCM-SHA384 ECDH_RSA_WITH_CAMELLIA_256_GCM_SHA384   )],
    '0xC0,0x8E' => [qw( PSK-CAMELLIA128-GCM-SHA256      PSK_WITH_CAMELLIA_128_GCM_SHA256        )],
    '0xC0,0x8F' => [qw( PSK-CAMELLIA256-GCM-SHA38       PSK_WITH_CAMELLIA_256_GCM_SHA3844       )],
    '0xC0,0x90' => [qw( DHE-PSK-CAMELLIA128-GCM-SHA25   DHE_PSK_WITH_CAMELLIA_128_GCM_SHA2566   )],
    '0xC0,0x91' => [qw( DHE-PSK-CAMELLIA256-GCM-SHA38   DHE_PSK_WITH_CAMELLIA_256_GCM_SHA3844   )],
    '0xC0,0x92' => [qw( RSA-PSK-CAMELLIA128-GCM-SHA256  RSA_PSK_WITH_CAMELLIA_128_GCM_SHA256    )],
    '0xC0,0x93' => [qw( RSA-PSK-CAMELLIA256-GCM-SHA384  RSA_PSK_WITH_CAMELLIA_256_GCM_SHA384    )],
    '0xC0,0x94' => [qw( PSK-CAMELLIA128-SHA256          PSK_WITH_CAMELLIA_128_CBC_SHA256        )],
    '0xC0,0x95' => [qw( PSK-CAMELLIA256-SHA384          PSK_WITH_CAMELLIA_256_CBC_SHA384        )],
    '0xC0,0x96' => [qw( DHE-PSK-CAMELLIA128-SHA256      DHE_PSK_WITH_CAMELLIA_128_CBC_SHA256    )],
    '0xC0,0x97' => [qw( DHE-PSK-CAMELLIA256-SHA38       DHE_PSK_WITH_CAMELLIA_256_CBC_SHA3844   )],
    '0xC0,0x98' => [qw( RSA-PSK-CAMELLIA128-SHA25       RSA_PSK_WITH_CAMELLIA_128_CBC_SHA2566   )],
    '0xC0,0x99' => [qw( RSA-PSK-CAMELLIA256-SHA38       RSA_PSK_WITH_CAMELLIA_256_CBC_SHA3844   )],
    '0xC0,0x9A' => [qw( ECDHE-PSK-CAMELLIA128-SHA256    ECDHE_PSK_WITH_CAMELLIA_128_CBC_SHA256  )],
    '0xC0,0x9B' => [qw( ECDHE-PSK-CAMELLIA256-SHA384    ECDHE_PSK_WITH_CAMELLIA_256_CBC_SHA384  )],
    '0xC0,0x9C' => [qw( RSA-AES128-CCM                  RSA_WITH_AES_128_CCM            )],
    '0xC0,0x9D' => [qw( RSA-AES256-CCM                  RSA_WITH_AES_256_CCM            )],
    '0xC0,0x9E' => [qw( DHE-RSA-AES128-CCM              DHE_RSA_WITH_AES_128_CCM        )],
    '0xC0,0x9F' => [qw( DHE-RSA-AES256-CCM              DHE_RSA_WITH_AES_256_CCM        )],
    '0xC0,0xA0' => [qw( RSA-AES128-CCM8                 RSA_WITH_AES_128_CCM_8          )],
    '0xC0,0xA1' => [qw( RSA-AES256-CCM8                 RSA_WITH_AES_256_CCM_8          )],
    '0xC0,0xA2' => [qw( DHE-RSA-AES128-CCM8             DHE_RSA_WITH_AES_128_CCM_8      )],
    '0xC0,0xA3' => [qw( DHE-RSA-AES256-CCM8             DHE_RSA_WITH_AES_256_CCM_8      )],
    '0xC0,0xA4' => [qw( PSK-RSA-AES128-CCM              PSK_WITH_AES_128_CCM            )],
    '0xC0,0xA5' => [qw( PSK-RSA-AES256-CCM              PSK_WITH_AES_256_CCM            )],
    '0xC0,0xA6' => [qw( DHE-PSK-AES128-CCM              DHE_PSK_WITH_AES_128_CCM        )],
    '0xC0,0xA7' => [qw( DHE-PSK-AES256-CCM              DHE_PSK_WITH_AES_256_CCM        )],
    '0xC0,0xA8' => [qw( PSK-RSA-AES128-CCM8             PSK_WITH_AES_128_CCM_8          )],
    '0xC0,0xA9' => [qw( PSK-RSA-AES256-CCM8             PSK_WITH_AES_256_CCM_8          )],
    '0xC0,0xAA' => [qw( DHE-PSK-AES128-CCM8             DHE_PSK_WITH_AES_128_CCM_8      )],
    '0xC0,0xAB' => [qw( DHE-PSK-AES256-CCM8             DHE_PSK_WITH_AES_256_CCM_8      )],
    '0xC0,0xAC' => [qw( ECDHE-RSA-AES128-CCM            ECDHE_ECDSA_WITH_AES_128_CCM    )],
    '0xC0,0xAD' => [qw( ECDHE-RSA-AES256-CCM            ECDHE_ECDSA_WITH_AES_256_CCM    )],
    '0xC0,0xAE' => [qw( ECDHE-RSA-AES128-CCM8           ECDHE_ECDSA_WITH_AES_128_CCM_8  )],
    '0xC0,0xAF' => [qw( ECDHE-RSA-AES256-CCM8           ECDHE_ECDSA_WITH_AES_256_CCM_8  )],
    '0xCC,0x12' => [qw( RSA-CHACHA20-POLY1305           RSA_WITH_CHACHA20_POLY1305      )],
    '0xCC,0x13' => [qw( ECDHE-RSA-CHACHA20-POLY1305-SHA256      ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256   )], # see 0xCC,0xA8
    '0xCC,0x14' => [qw( ECDHE-ECDSA-CHACHA20-POLY1305-SHA256    ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256 )], # see 0xCC,0xA9
    '0xCC,0x15' => [qw( DHE-RSA-CHACHA20-POLY1305-SHA256        DHE_RSA_WITH_CHACHA20_POLY1305_SHA256     )], # see 0xCC,0xAA
    '0xCC,0x16' => [qw( DHE-PSK-CHACHA20-POLY1305               DHE_PSK_WITH_CHACHA20_POLY1305     )], # see 0xCC,0xA4
    '0xCC,0x17' => [qw( PSK-CHACHA20-POLY1305                   PSK_WITH_CHACHA20_POLY1305         )], # see 0xCC,0xA5
    '0xCC,0x18' => [qw( ECDHE-PSK-CHACHA20-POLY1305             ECDHE_PSK_WITH_CHACHA20_POLY1305   )], # see 0xCC,0xA6
    '0xCC,0x19' => [qw( RSA-PSK-CHACHA20-POLY1305               RSA_PSK_WITH_CHACHA20_POLY1305     )], # see 0xCC,0xA7
    '0xCC,0x20' => [qw( RSA-CHACHA20-SHA                RSA_WITH_CHACHA20_SHA           )],    
    '0xCC,0x21' => [qw( ECDHE-RSA-CHACHA20-SHA          ECDHE_RSA_WITH_CHACHA20_SHA     )],
    '0xCC,0x22' => [qw( ECDHE-ECDSA-CHACHA20-SHA        ECDHE_ECDSA_WITH_CHACHA20_SHA   )],
    '0xCC,0x23' => [qw( DHE-RSA-CHACHA20-SHA            DHE_RSA_WITH_CHACHA20_SHA       )],
    '0xCC,0x24' => [qw( DHE-PSK-CHACHA20-SHA            DHE_PSK_WITH_CHACHA20_SHA       )],
    '0xCC,0x25' => [qw( PSK-CHACHA20-SHA                PSK_WITH_CHACHA20_SHA           )],    
    '0xCC,0x26' => [qw( ECDHE-PSK-CHACHA20-SHA          ECDHE_PSK_WITH_CHACHA20_SHA     )],
    '0xCC,0x27' => [qw( RSA-PSK-CHACHA20-SHA            RSA_PSK_WITH_CHACHA20_SHA       )],
    '0xCC,0xA1' => [qw( ECDHE-RSA-CHACHA20-POLY1305'    ECDHE_RSA_WITH_CHACHA20_POLY1305 )],
    '0xCC,0xA2' => [qw( ECDHE-ECDSA-CHACHA20-POLY1305   ECDHE_ECDSA_WITH_CHACHA20_POLY1305  )],
    '0xCC,0xA3' => [qw( DHE-RSA-CHACHA20-POLY1305       DHE_RSA_WITH_CHACHA20_POLY1305  )],
    '0xCC,0xA4' => [qw( DHE-PSK-CHACHA20-POLY1305       DHE_PSK_WITH_CHACHA20_POLY1305  )],
    '0xCC,0xA5' => [qw( PSK-CHACHA20-POLY1305           PSK_WITH_CHACHA20_POLY1305      )],
    '0xCC,0xA6' => [qw( ECDHE-PSK-CHACHA20-POLY1305     ECDHE_PSK_WITH_CHACHA20_POLY1305 )],
    '0xCC,0xA7' => [qw( RSA-PSK-CHACHA20-POLY1305       RSA_PSK_WITH_CHACHA20_POLY1305  )],
    '0xCC,0xA8' => [qw( ECDHE-RSA-CHACHA20-POLY1305-SHA256      ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256   )],
    '0xCC,0xA9' => [qw( ECDHE-ECDSA-CHACHA20-POLY1305-SHA256    ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256 )],
    '0xCC,0xAA' => [qw( DHE-RSA-CHACHA20-POLY1305-SHA256        DHE_RSA_WITH_CHACHA20_POLY1305_SHA256   )],
    '0xCC,0xAB' => [qw( PSK-CHACHA20-POLY1305-SHA256            PSK_WITH_CHACHA20_POLY1305_SHA256       )],
    '0xCC,0xAC' => [qw( ECDHE-PSK-CHACHA20-POLY1305-SHA256      ECDHE_PSK_WITH_CHACHA20_POLY1305_SHA256 )],
    '0xCC,0xAD' => [qw( DHE-PSK-CHACHA20-POLY1305-SHA256        DHE_PSK_WITH_CHACHA20_POLY1305_SHA256   )],
    '0xCC,0xAE' => [qw( RSA-PSK-CHACHA20-POLY1305-SHA256        RSA_PSK_WITH_CHACHA20_POLY1305_SHA256   )],
    #!#----------+-------------------------------------+--------------------------+

    # from: https://www.bro.org/sphinx/_downloads/consts10.bro (but uses SSL_ prefix)
    '0xFE,0xE0' => [qw( RSA-FIPS-3DES-EDE-SHA-2         RSA_FIPS_WITH_3DES_EDE_CBC_SHA_2  )],
    '0xFE,0xE1' => [qw( RSA-FIPS-DES-CBC-SHA-2          RSA_FIPS_WITH_DES_CBC_SHA_2       )],
    '0xFE,0xFE' => [qw( RSA-FIPS-DES-CBC-SHA            RSA_FIPS_WITH_DES_CBC_SHA         )],
    '0xFE,0xFF' => [qw( RSA-FIPS-3DES-EDE-SHA           RSA_FIPS_WITH_3DES_EDE_CBC_SHA    )],
    '0xFF,0x80' => [qw( RSA-RC2-CBC-MD5                 RSA_WITH_RC2_CBC_MD5              )], # see 0x00,0x06
    '0xFF,0x81' => [qw( RSA-IDEA-CBC-MD5                RSA_WITH_IDEA_CBC_MD5             )], # see 0x00,0x07
    '0xFF,0x82' => [qw( RSA-DES-CBC-MD5                 RSA_WITH_DES_CBC_MD5              )], # see 0x00,0x08
    '0xFF,0x83' => [qw( RSA-3DES-EDE-MD5                RSA_WITH_3DES_EDE_CBC_MD5         )], # see 0x00,0x09

    #!#----------+-------------------------------------+--------------------------+
#   '0xFF,0x00' => [qw( GOST94-NULL-GOST94              GOSTR341001_WITH_NULL_GOSTR3411   )], # unklar
       # unklar, siehe 0x00,0x82 und muesste sein  GOSTR341094_WITH_NULL_GOSTR3411
    '0xFF,0x00' => [qw( GOST-MD5                        GOSTR341094_RSA_WITH_28147_CNT_MD5 )], # unklar
    '0xFF,0x01' => [qw( GOST-GOST94                     RSA_WITH_28147_CNT_GOST94         )], # unklar
#   '0xFF,0x01' => [qw( GOST2001-NULL-GOST94            GOSTR341001_WITH_NULL_GOSTR3411   )], # unklar
       # unklar, siehe 0x00,0x83; und Nummer doppelt
    '0xFF,0x02' => [qw( GOST-GOST89MAC                  -?- )], # unklar
    '0xFF,0x03' => [qw( GOST-GOST89STREAM               -?- )], # unklar
    #!#----------+-------------------------------------+--------------------------+
    # from: https://chromium.googlesource.com/chromium/src/net/+/master/ssl/ssl_cipher_suite_names_unittest.cc
    '0x16,0xB7' => [qw( CECPQ1-RSA-CHACHA20-POLY1305-SHA256     CECPQ1_RSA_WITH_CHACHA20_POLY1305_SHA256   )],
    '0x16,0xB8' => [qw( CECPQ1-ECDSA-CHACHA20-POLY1305-SHA256   CECPQ1_ECDSA_WITH_CHACHA20_POLY1305_SHA256 )],
    '0x16,0xB9' => [qw( CECPQ1-RSA-AES256-GCM-SHA384    CECPQ1_RSA_WITH_AES_256_GCM_SHA384   )],
    '0x16,0xBA' => [qw( CECPQ1-ECDSA-AES256-GCM-SHA384  CECPQ1_ECDSA_WITH_AES_256_GCM_SHA384 )],
    #!#----------+-------------------------------------+--------------------------+

    '0x00,0xFF' => [qw( INFO_SCSV                       EMPTY_RENEGOTIATION_INFO_SCSV     )], # IANA und NSS
    '0x56,0x00' => [qw( SCSV                            TLS_FALLBACK_SCSV)],    # IANA und NSS # FIXME: according http://tools.ietf.org/html/7507.html

    'osaft-001' => [qw( EXP-RC4-64-MD5                  RCA_RC4_64_MD5          )], # unklar
    'osaft-002' => [qw( EXP-EDH-DSS-RC4-56-SHA          EDH_DSS_RC4_65_SHA      )], # unklar

); # %_ciphers_names

our %_ciphers_alias = ( # TODO: list not yet used
    #!#----------+-------------------------------------+-----------------------,
    #!# constant =>     cipher suite name alias        # comment (where found)
    #!#----------+-------------------------------------+-----------------------,
'0x03,0x00,0x80' => [qw( RC2-MD5                )],    # from older openssl
'0x04,0x00,0x80' => [qw( EXP-RC2-MD5            )],    # from older openssl and sslaudit.ini
    '0x00,0x12' => [qw( EDH-DSS-CBC-SHA         )],    # from sslaudit.ini and mozilla
    '0x00,0x1D' => [qw( FZA-FZA-CBC-SHA         )],    #
    '0x00,0x32' => [qw( EDH-DSS-AES128-SHA      )],    # from RSA BSAFE SSL-C
    '0x00,0x2C' => [qw( PSK-NULL-SHA            )],    # from older openssl
    '0x00,0x2D' => [qw( DHE-PSK-NULL-SHA        )],    # -"-
    '0x00,0x2E' => [qw( RSA-PSK-NULL-SHA        )],    # -"-
    '0x00,0x32' => [qw( EDH-DSS-AES128-SHA      )],    # -"-
    '0x00,0x33' => [qw( EDH-RSA-AES128-SHA      )],    # -"-
    '0x00,0x38' => [qw( EDH-DSS-AES256-SHA      )],    # -"-
    '0x00,0x39' => [qw( EDH-RSA-AES256-SHA      )],    # -"-
    '0x00,0x62' => [qw( EXP-DES-56-SHA          )],    # -"-
    '0x00,0x63' => [qw( EXP-EDH-DSS-DES-56-SHA  )],    # -"-
    '0x00,0x64' => [qw( EXP-RC4-56-SHA          )],    # -"-
    '0x00,0x65' => [qw( EXP-EDH-DSS-RC4-56-SHA  )],    # -"-
    '0x00,0x66' => [qw( EDH-DSS-RC4-SHA         )],    # from RSA BSAFE SSL-C
    '0x00,0x8B' => [qw( PSK-3DES-EDE-CBC-SHA    )],    # ??
    '0x00,0x8F' => [qw( DHE-PSK-3DES-EDE-CBC-SHA )],   # ??
    '0x00,0x93' => [qw( RSA-PSK-3DES-EDE-CBC-SHA )],   # ??
    '0x00,0x94' => [qw( RSA-PSK-AES128-CBC-SHA  )],    #
    '0x00,0x95' => [qw( RSA-PSK-AES256-CBC-SHA  )],    #
    '0x00,0x9B' => [qw( DHanon-SEED-SHA         )],    #
    '0xC0,0xA0' => [qw( RSA-AES128-CCM-8        )],    # ?? some java
    '0xC0,0xA1' => [qw( RSA-AES256-CCM-8        )],    # -"-
    '0xC0,0xA2' => [qw( DHE-RSA-AES128-CCM-8    )],    # -"-
    '0xC0,0xA3' => [qw( DHE-RSA-AES256-CCM-8    )],    # -"-
    '0xC0,0xA6' => [qw( DHE-PSK-RSA-AES128-CCM  )],    # probably a typo somewhere
    '0xC0,0xA7' => [qw( DHE-PSK-RSA-AES256-CCM  )],    # probably a typo somewhere
    '0xC0,0xA8' => [qw( PSK-RSA-AES128-CCM-8    )],    # ?? some java
    '0xC0,0xA9' => [qw( PSK-RSA-AES256-CCM-8    )],    # ?? some java
    '0xC0,0xAA' => [qw( DHE-PSK-RSA-AES128-CCM8 )],    # probably a typo somewhere
    '0xC0,0xAB' => [qw( DHE-PSK-RSA-AES256-CCM8 )],    # probably a typo somewhere
    '0xC0,0xAE' => [qw( ECDHE-RSA-AES128-CCM-8  )],    # ?? some java
    '0xC0,0xAF' => [qw( ECDHE-RSA-AES256-CCM-8  )],    # ?? some java
    '0xCC,0x13' => [qw( ECDHE-RSA-CHACHA20-POLY1305 )],# openssl 1.0.2
    '0xCC,0x14' => [qw( ECDHE-ECDSA-CHACHA20-POLY1305 )], # -"-
    '0xCC,0x15' => [qw( DHE-RSA-CHACHA20-POLY1305   )],# -"-
    '0xCC,0xAE' => [qw( PSK-RSA-CHACHA20-POLY1305   )],# probably a typo somewhere
    #!#----------+-------------------------------------+--------------------------+

    # alias ?
# following are cipher suite constant values;
# alias for them not yet implemented hence key with perfix C, or D
#    anon is same as ANON or Anon
  'C,0x00,0x00' => [qw( NULL_WITH_NULL_NULL         )],
  'D,0x00,0x00' => [qw( NULL_NULL_NULL              )],# seen in openvas sources
  'C,0x00,0x01' => [qw( RSA_WITH_NULL_MD5           )],
  'D,0x00,0x01' => [qw( RSA_NULL_MD5                )],# seen in openvas sources
  'C,0x00,0x02' => [qw( RSA_WITH_NULL_SHA           )],
  'D,0x00,0x01' => [qw( RSA_NULL_SHA                )],# seen in openvas sources
  'C,0x00,0x03' => [qw( RSA_EXPORT_WITH_RC4_40_MD5  )],
  'D,0x00,0x03' => [qw( RSA_WITH_RC4_40_MD5         )],
  'C,0x00,0x04' => [qw( RSA_WITH_RC4_128_MD5        )],
  'C,0x00,0x05' => [qw( RSA_WITH_RC4_128_SHA        )],
  'C,0x00,0x06' => [qw( RSA_EXPORT_WITH_RC2_CBC_40_MD5      )],
  'D,0x00,0x06' => [qw( RSA_WITH_RC2_40_MD5                 )],
  'C,0x00,0x07' => [qw( RSA_WITH_IDEA_CBC_SHA               )],
  'C,0x00,0x08' => [qw( RSA_EXPORT_WITH_DES40_CBC_SHA       )],
  'C,0x00,0x09' => [qw( RSA_WITH_DES_CBC_SHA                )],
  'C,0x00,0x0A' => [qw( RSA_WITH_3DES_EDE_CBC_SHA           )],
  'C,0x00,0x0B' => [qw( DH_DSS_EXPORT_WITH_DES40_CBC_SHA    )],
  'C,0x00,0x0C' => [qw( DH_DSS_WITH_DES_CBC_SHA             )],
  'C,0x00,0x0D' => [qw( DH_DSS_WITH_3DES_EDE_CBC_SHA        )],
  'C,0x00,0x0E' => [qw( DH_RSA_EXPORT_WITH_DES40_CBC_SHA    )],
  'C,0x00,0x0F' => [qw( DH_RSA_WITH_DES_CBC_SHA             )],
  'C,0x00,0x10' => [qw( DH_RSA_WITH_3DES_EDE_CBC_SHA        )],
  'C,0x00,0x11' => [qw( DHE_DSS_EXPORT_WITH_DES40_CBC_SHA   )],
  'C,0x00,0x12' => [qw( DHE_DSS_WITH_DES_CBC_SHA            )],
  'C,0x00,0x13' => [qw( DHE_DSS_WITH_3DES_EDE_CBC_SHA       )],
  'C,0x00,0x14' => [qw( DHE_RSA_EXPORT_WITH_DES40_CBC_SHA   )],
  'C,0x00,0x15' => [qw( DHE_RSA_WITH_DES_CBC_SHA            )],
  'C,0x00,0x16' => [qw( DHE_RSA_WITH_3DES_EDE_CBC_SHA       )],
  'C,0x00,0x17' => [qw( DH_anon_EXPORT_WITH_RC4_40_MD5      )],
  'C,0x00,0x18' => [qw( DH_anon_WITH_RC4_128_MD5            )],
  'C,0x00,0x19' => [qw( DH_anon_EXPORT_WITH_DES40_CBC_SHA   )],
  'C,0x00,0x1A' => [qw( DH_anon_WITH_DES_CBC_SHA        )],
  'C,0x00,0x1B' => [qw( DH_anon_WITH_3DES_EDE_CBC_SHA   )],
  'C,0x00,0x1C' => [qw( FORTEZZA_KEA_WITH_NULL_SHA      )], # has SSL_ prefix
  'C,0x00,0x1D' => [qw( FORTEZZA_KEA_WITH_WITH_FORTEZZA_CBC_SHA )], # has SSL_ prefix
  'C,0x00,0x1E' => [qw( KRB5_WITH_DES_CBC_SHA           )],
  'C,0x00,0x1F' => [qw( KRB5_WITH_3DES_EDE_CBC_SHA      )],
  'C,0x00,0x20' => [qw( KRB5_WITH_RC4_128_SHA           )],
  'C,0x00,0x21' => [qw( KRB5_WITH_IDEA_CBC_SHA          )],
  'C,0x00,0x22' => [qw( KRB5_WITH_DES_CBC_MD5           )],
  'C,0x00,0x23' => [qw( KRB5_WITH_3DES_EDE_CBC_MD5      )],
  'C,0x00,0x24' => [qw( KRB5_WITH_RC4_128_MD5           )],
  'C,0x00,0x25' => [qw( KRB5_WITH_IDEA_CBC_MD5          )],
  'C,0x00,0x26' => [qw( KRB5_WITH_EXPORT_WITH_DES_CBC_40_SHA    )],
  'C,0x00,0x27' => [qw( KRB5_WITH_EXPORT_WITH_RC2_CBC_40_SHA    )],
  'C,0x00,0x28' => [qw( KRB5_WITH_EXPORT_WITH_RC4_40_SHA        )],
  'C,0x00,0x29' => [qw( KRB5_WITH_EXPORT_WITH_DES_CBC_40_MD5    )],
  'C,0x00,0x2A' => [qw( KRB5_WITH_EXPORT_WITH_RC2_CBC_40_MD5    )],
  'C,0x00,0x2B' => [qw( KRB5_WITH_EXPORT_WITH_RC4_40_MD5        )],
  'C,0x00,0x2F' => [qw( RSA_WITH_AES_128_CBC_SHA        )],
  'C,0x00,0x30' => [qw( DH_DSS_WITH_AES_128_CBC_SHA     )],
  'C,0x00,0x31' => [qw( DH_RSA_WITH_AES_128_CBC_SHA     )],
  'C,0x00,0x32' => [qw( DHE_DSS_WITH_AES_128_SHA        )], # from older openssl
  'C,0x00,0x33' => [qw( DHE_RSA_WITH_AES_128_SHA        )], # from older openssl
  'C,0x00,0x34' => [qw( DH_anon_WITH_AES_128_CBC_SHA    )],
  'C,0x00,0x35' => [qw( RSA_WITH_AES_256_CBC_SHA        )],
  'C,0x00,0x38' => [qw( DHE_DSS_WITH_AES_256_SHA        )], # from older openssl
  'C,0x00,0x39' => [qw( DHE_RSA_WITH_AES_256_SHA        )], # from older openssl
  'C,0x00,0x40' => [qw( DHE_DSS_WITH_AES_128_CBC_SHA256 )],
  'C,0x00,0x46' => [qw( DH_anon_WITH_CAMELLIA_128_CBC_SHA )],
  'C,0x00,0x67' => [qw( DHE_RSA_WITH_AES_128_CBC_SHA256 )],
  'C,0x00,0x68' => [qw( DH_DSS_WITH_AES_256_CBC_SHA256  )],
  'C,0x00,0x69' => [qw( DH_RSA_WITH_AES_256_CBC_SHA256  )],
  'C,0x00,0x6A' => [qw( DHE_DSS_WITH_AES_256_CBC_SHA256 )],
  'C,0x00,0x6B' => [qw( DHE_RSA_WITH_AES_256_CBC_SHA256 )],
  'C,0x00,0x6C' => [qw( DH_anon_WITH_AES_128_CBC_SHA256 )],
  'C,0x00,0x6D' => [qw( DH_anon_WITH_AES_256_CBC_SHA256 )],
  'C,0x00,0x89' => [qw( DH_anon_WITH_CAMELLIA_256_CBC_SHA )],
  'C,0x00,0x96' => [qw( RSA_PSK_WITH_SEED_CBC_SHA       )],
  'C,0x00,0x97' => [qw( DH_DSS_WITH_SEED_CBC_SHA        )],
  'C,0x00,0x98' => [qw( DH_RSA_WITH_SEED_CBC_SHA        )],
  'C,0x00,0x99' => [qw( DHE_DSS_WITH_SEED_CBC_SHA       )],
  'C,0x00,0x9A' => [qw( DHE_RSA_WITH_SEED_CBC_SHA       )],
  'C,0x00,0x9B' => [qw( DH_anon_WITH_SEED_CBC_SHA       )],
  'C,0x00,0xA6' => [qw( DH_anon_WITH_AES_128_GCM_SHA256 )],
  'C,0x00,0xA7' => [qw( DH_anon_WITH_AES_256_GCM_SHA384 )],
  'C,0xC0,0xAA' => [qw( PSK_DHE_WITH_AES_128_CCM_8      )], # from openssl
  'C,0xC0,0xAB' => [qw( PSK_DHE_WITH_AES_256_CCM_8      )], # from openssl
  'C,0x00,0xBF' => [qw( DH_anon_WITH_CAMELLIA_128_CBC_SHA256    )],
  'C,0x00,0xC5' => [qw( DH_anon_WITH_CAMELLIA_256_CBC_SHA256    )],
  'C,0xC0,0x03' => [qw( ECDH_ECDSA_WITH_3DES_EDE_CBC_SHA        )],
  'C,0xC0,0x08' => [qw( ECDHE_ECDSA_WITH_3DES_EDE_CBC_SHA       )],
  'C,0xC0,0x0D' => [qw( ECDH_RSA_WITH_3DES_EDE_CBC_SHA          )],
  'C,0xC0,0x12' => [qw( ECDHE_RSA_WITH_3DES_EDE_CBC_SHA         )],
  'C,0xC0,0x17' => [qw( ECDH_anon_WITH_3DES_EDE_CBC_SHA         )],
  'C,0xC0,0x23' => [qw( ECDHE_ECDSA_WITH_AES_128_CBC_SHA256     )],
  'C,0xC0,0x24' => [qw( ECDHE_ECDSA_WITH_AES_256_CBC_SHA384     )],
  'C,0xC0,0x25' => [qw( ECDH_ECDSA_WITH_AES_128_CBC_SHA256      )],
  'C,0xC0,0x26' => [qw( ECDH_ECDSA_WITH_AES_256_CBC_SHA384      )],
  'C,0xC0,0x27' => [qw( ECDHE_RSA_WITH_AES_128_CBC_SHA256       )],
  'C,0xC0,0x28' => [qw( ECDHE_RSA_WITH_AES_256_CBC_SHA384       )],
  'C,0xC0,0x29' => [qw( ECDH_RSA_WITH_AES_128_CBC_SHA256        )],
  'C,0xC0,0x2A' => [qw( ECDH_RSA_WITH_AES_256_CBC_SHA384        )],

    #!#----------+-------------------------------------+--------------------------+

); # %_cipher_alias

1;
